@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -59,7 +59,6 @@ static const char *browsers[][2] = {
   {"Raptr", "Game Systems"},
 
   /* Based on Internet Explorer */
-  {"America Online Browser", "Others"},
   {"Avant Browser", "Others"},
   /* Internet Explorer */
   {"IEMobile", "MSIE"},
@@ -67,7 +66,8 @@ static const char *browsers[][2] = {
   /* IE11 */
   {"Trident/7.0", "MSIE"},
   /* Microsoft Edge */
-  {"Edge", "MSIE"},
+  {"Edg", "Edge"},
+  {"Edge", "Edge"},
 
   /* Opera */
   {"Opera Mini", "Opera"},
@@ -93,10 +93,8 @@ static const char *browsers[][2] = {
   {"Firebird", "Others"},
   {"Galeon", "Others"},
   {"google-cloud-sdk", "Others"},
-  {"GranParadiso", "Others"},
   {"IBrowse", "Others"},
   {"K-Meleon", "Others"},
-  {"Kazehakase", "Others"},
   {"Konqueror", "Others"},
   {"Links", "Others"},
   {"Lynx", "Others"},
@@ -144,12 +142,17 @@ static const char *browsers[][2] = {
   /* Rebranded Firefox but is really unmodified
    * Firefox (Debian trademark policy) */
   {"Iceweasel", "Firefox"},
+  {"Focus", "Firefox"},
+  /* Klar is the name of Firefox Focus in the German market. */
+  {"Klar", "Firefox"},
   {"Firefox", "Firefox"},
 
   /* Based on Chromium */
-  {"Vivaldi", "Others"},
-  {"YaBrowser", "Others"},
-  {"Flock", "Others"},
+  {"BeakerBrowser", "Beaker"},
+  {"Brave", "Brave"},
+  {"Vivaldi", "Vivaldi"},
+  {"YaBrowser", "Yandex.Browser"},
+
   /* Chrome has to go before Safari */
   {"HeadlessChrome", "Chrome"},
   {"Chrome", "Chrome"},
@@ -157,6 +160,7 @@ static const char *browsers[][2] = {
 
   /* Crawlers/Bots (Possible Safari based) */
   {"AppleBot", "Crawlers"},
+  {"facebookexternalhit", "Crawlers"},
   {"Twitter", "Crawlers"},
 
   {"Safari", "Safari"},
@@ -183,6 +187,8 @@ static const char *browsers[][2] = {
   {"Python", "Crawlers"},
   {"LinkedIn", "Crawlers"},
   {"Microsoft-WebDAV", "Crawlers"},
+  {"DuckDuckGo-Favicons-Bot", "Crawlers"},
+  {"bingbot", "Crawlers"},
 
   /* Podcast fetchers */
   {"Downcast", "Podcasts"},
@@ -217,8 +223,7 @@ static const char *browsers[][2] = {
 
 /* Free all browser entries from our array of key/value pairs. */
 void
-free_browsers_hash (void)
-{
+free_browsers_hash (void) {
   size_t i;
   int j;
 
@@ -241,8 +246,7 @@ free_browsers_hash (void)
 }
 
 static int
-is_dup (char ***list, int len, const char *browser)
-{
+is_dup (char ***list, int len, const char *browser) {
   int i;
   /* check for dups */
   for (i = 0; i < len; ++i) {
@@ -257,8 +261,7 @@ is_dup (char ***list, int len, const char *browser)
  * On duplicate functions returns void.
  * Otherwise memory is mallo'd for our array entry. */
 static void
-set_browser (char ***list, int idx, const char *browser, const char *type)
-{
+set_browser (char ***list, int idx, const char *browser, const char *type) {
   list[idx] = xcalloc (2, sizeof (char *));
   list[idx][0] = xstrdup (browser);
   list[idx][1] = xstrdup (type);
@@ -266,8 +269,7 @@ set_browser (char ***list, int idx, const char *browser, const char *type)
 
 /* Parse the key/value pair from the browser list file. */
 static void
-parse_browser_token (char ***list, char *line, int n)
-{
+parse_browser_token (char ***list, char *line, int n) {
   char *val;
   size_t idx = 0;
 
@@ -301,8 +303,7 @@ parse_browser_token (char ***list, char *line, int n)
  * On error functions returns void.
  * Otherwise browser entries are put into the hash. */
 void
-parse_browsers_file (void)
-{
+parse_browsers_file (void) {
   char line[MAX_LINE_BROWSERS + 1];
   FILE *file;
   int n = 0;
@@ -342,8 +343,7 @@ parse_browsers_file (void)
  * On error or is not a crawler, 0 is returned.
  * If it is a crawler, 1 is returned . */
 int
-is_crawler (const char *agent)
-{
+is_crawler (const char *agent) {
   char type[BROWSER_TYPE_LEN];
   char *browser, *a;
 
@@ -361,8 +361,7 @@ is_crawler (const char *agent)
  *
  * On success, the opera string and version is returned. */
 static char *
-parse_opera (char *token)
-{
+parse_opera (char *token) {
   char *val = xmalloc (snprintf (NULL, 0, "Opera%s", token) + 1);
   sprintf (val, "Opera%s", token);
 
@@ -375,8 +374,7 @@ parse_opera (char *token)
  * On error when attempting to extract crawler, NULL is returned.
  * If a possible crawler string is matched, then possible bot is returned . */
 static char *
-parse_crawler (char *str, char *match, char *type)
-{
+parse_crawler (char *str, char *match, char *type) {
   char *ptr = NULL;
   int found = 0;
 
@@ -414,8 +412,7 @@ parse_crawler (char *str, char *match, char *type)
  * If no occurrences are found, NULL is returned.
  * If an occurrence is found, a pointer to the match is returned . */
 static char *
-check_http_crawler (const char *str)
-{
+check_http_crawler (const char *str) {
   char *match = NULL;
 
   /* e.g., compatible; bingbot/2.0; +http://www.bing.com/bingbot.htm */
@@ -441,8 +438,7 @@ check_http_crawler (const char *str)
  * If no match, the original match is returned.
  * Otherwise the parsed browser is returned. */
 static char *
-parse_browser (char *match, char *type, int i, char ***hash)
-{
+parse_browser (char *match, char *type, int i, char ***hash) {
   char *b = NULL, *ptr = NULL, *slh = NULL;
   size_t cnt = 0, space = 0;
 
@@ -489,8 +485,7 @@ parse_browser (char *match, char *type, int i, char ***hash)
  * On error, NULL is returned.
  * On success, a malloc'd  string containing the browser is returned. */
 char *
-verify_browser (char *str, char *type)
-{
+verify_browser (char *str, char *type) {
   char *match = NULL, *token = NULL;
   int i = 0;
   size_t j = 0;
@@ -505,8 +500,7 @@ verify_browser (char *str, char *type)
     return parse_browser (match, type, i, conf.user_browsers_hash);
   }
 
-  if ((match = check_http_crawler (str)) &&
-      (token = parse_crawler (str, match, type)))
+  if ((match = check_http_crawler (str)) && (token = parse_crawler (str, match, type)))
     return token;
 
   /* fallback to default browser list */
