@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -45,19 +45,15 @@
 
 #include "csv.h"
 
-#ifdef HAVE_LIBTOKYOCABINET
-#include "tcabdb.h"
-#else
-#include "gkhash.h"
-#endif
-
 #include "error.h"
+#include "gkhash.h"
 #include "ui.h"
 #include "util.h"
 
+struct tm *now_tm;
+
 /* Panel output */
-typedef struct GPanel_
-{
+typedef struct GPanel_ {
   GModule module;
   void (*render) (FILE * fp, GHolder * h, GPercTotals totals);
 } GPanel;
@@ -81,6 +77,7 @@ static GPanel paneling[] = {
   {KEYPHRASES      , print_csv_data} ,
   {STATUS_CODES    , print_csv_data} ,
   {REMOTE_USER     , print_csv_data} ,
+  {CACHE_STATUS    , print_csv_data} ,
 #ifdef HAVE_GEOLOCATION
   {GEO_LOCATION    , print_csv_data} ,
 #endif
@@ -92,8 +89,7 @@ static GPanel paneling[] = {
  * On error, or if not found, NULL is returned.
  * On success, the panel value is returned. */
 static GPanel *
-panel_lookup (GModule module)
-{
+panel_lookup (GModule module) {
   int i, num_panels = ARRAY_SIZE (paneling);
 
   for (i = 0; i < num_panels; i++) {
@@ -105,8 +101,7 @@ panel_lookup (GModule module)
 
 /* Iterate over the string and escape CSV output. */
 static void
-escape_cvs_output (FILE * fp, char *s)
-{
+escape_cvs_output (FILE * fp, char *s) {
   while (*s) {
     switch (*s) {
     case '"':
@@ -124,12 +119,11 @@ escape_cvs_output (FILE * fp, char *s)
  *
  * On success, outputs item value. */
 static void
-print_csv_metric_block (FILE * fp, GMetrics * nmetrics)
-{
+print_csv_metric_block (FILE * fp, GMetrics * nmetrics) {
   /* basic metrics */
-  fprintf (fp, "\"%d\",", nmetrics->hits);
+  fprintf (fp, "\"%" PRIu32 "\",", nmetrics->hits);
   fprintf (fp, "\"%4.2f%%\",", nmetrics->hits_perc);
-  fprintf (fp, "\"%d\",", nmetrics->visitors);
+  fprintf (fp, "\"%" PRIu32 "\",", nmetrics->visitors);
   fprintf (fp, "\"%4.2f%%\",", nmetrics->visitors_perc);
 
   /* bandwidth */
@@ -166,8 +160,7 @@ print_csv_metric_block (FILE * fp, GMetrics * nmetrics)
  * On error, it exits early.
  * On success, outputs item value. */
 static void
-print_csv_sub_items (FILE * fp, GHolder * h, int idx, GPercTotals totals)
-{
+print_csv_sub_items (FILE * fp, GHolder * h, int idx, GPercTotals totals) {
   GMetrics *nmetrics;
   GSubList *sub_list = h->items[idx].sub_list;
   GSubItem *iter;
@@ -194,8 +187,7 @@ print_csv_sub_items (FILE * fp, GHolder * h, int idx, GPercTotals totals)
  *
  * On success, outputs item value. */
 static void
-print_csv_data (FILE * fp, GHolder * h, GPercTotals totals)
-{
+print_csv_data (FILE * fp, GHolder * h, GPercTotals totals) {
   GMetrics *nmetrics;
   int i;
 
@@ -219,13 +211,12 @@ print_csv_data (FILE * fp, GHolder * h, GPercTotals totals)
 #pragma GCC diagnostic ignored "-Wformat-nonliteral"
 /* Output general statistics information. */
 static void
-print_csv_summary (FILE * fp, GLog * glog)
-{
+print_csv_summary (FILE * fp) {
   char now[DATE_TIME];
   char *source = NULL;
   const char *fmt;
   int i = 0, total = 0;
-  long long t = 0LL;
+  uint32_t t = 0;
 
   generate_time ();
   strftime (now, DATE_TIME, "%Y-%m-%d %H:%M:%S %z", now_tm);
@@ -236,21 +227,21 @@ print_csv_summary (FILE * fp, GLog * glog)
 
   /* total requests */
   fmt = "\"%d\",,\"%s\",,,,,,,,\"%d\",\"%s\"\r\n";
-  total = glog->processed;
+  total = ht_get_processed ();
   fprintf (fp, fmt, i++, GENER_ID, total, OVERALL_REQ);
 
   /* valid requests */
   fmt = "\"%d\",,\"%s\",,,,,,,,\"%d\",\"%s\"\r\n";
-  total = glog->valid;
+  total = ht_sum_valid ();
   fprintf (fp, fmt, i++, GENER_ID, total, OVERALL_VALID);
 
   /* invalid requests */
-  total = glog->invalid;
+  total = ht_get_invalid ();
   fprintf (fp, fmt, i++, GENER_ID, total, OVERALL_FAILED);
 
   /* generated time */
-  fmt = "\"%d\",,\"%s\",,,,,,,,\"%lld\",\"%s\"\r\n";
-  t = (long long) end_proc - start_proc;
+  fmt = "\"%d\",,\"%s\",,,,,,,,\"%u\",\"%s\"\r\n";
+  t = ht_get_processing_time ();
   fprintf (fp, fmt, i++, GENER_ID, t, OVERALL_GENTIME);
 
   /* visitors */
@@ -263,7 +254,7 @@ print_csv_summary (FILE * fp, GLog * glog)
   fprintf (fp, fmt, i++, GENER_ID, total, OVERALL_FILES);
 
   /* excluded hits */
-  total = glog->excluded_ip;
+  total = ht_get_excluded_ips ();
   fprintf (fp, fmt, i++, GENER_ID, total, OVERALL_EXCL_HITS);
 
   /* referrers */
@@ -280,12 +271,11 @@ print_csv_summary (FILE * fp, GLog * glog)
 
   /* log size */
   fmt = "\"%d\",,\"%s\",,,,,,,,\"%jd\",\"%s\"\r\n";
-  fprintf (fp, fmt, i++, GENER_ID, (intmax_t) get_log_sizes (),
-           OVERALL_LOGSIZE);
+  fprintf (fp, fmt, i++, GENER_ID, (intmax_t) get_log_sizes (), OVERALL_LOGSIZE);
 
   /* bandwidth */
   fmt = "\"%d\",,\"%s\",,,,,,,,\"%llu\",\"%s\"\r\n";
-  fprintf (fp, fmt, i++, GENER_ID, glog->resp_size, OVERALL_BANDWIDTH);
+  fprintf (fp, fmt, i++, GENER_ID, ht_sum_bw (), OVERALL_BANDWIDTH);
 
   /* log path */
   source = get_log_source_str (0);
@@ -298,8 +288,7 @@ print_csv_summary (FILE * fp, GLog * glog)
 
 /* Entry point to generate a a csv report writing it to the fp */
 void
-output_csv (GLog * glog, GHolder * holder, const char *filename)
-{
+output_csv (GHolder * holder, const char *filename) {
   GModule module;
   GPercTotals totals;
   const GPanel *panel = NULL;
@@ -311,7 +300,9 @@ output_csv (GLog * glog, GHolder * holder, const char *filename)
     FATAL ("Unable to open CSV file: %s.", strerror (errno));
 
   if (!conf.no_csv_summary)
-    print_csv_summary (fp, glog);
+    print_csv_summary (fp);
+
+  set_module_totals (&totals);
 
   FOREACH_MODULE (idx, module_list) {
     module = module_list[idx];
@@ -319,7 +310,6 @@ output_csv (GLog * glog, GHolder * holder, const char *filename)
     if (!(panel = panel_lookup (module)))
       continue;
 
-    set_module_totals (module, &totals);
     panel->render (fp, holder + module, totals);
   }
 
