@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,6 +32,7 @@
 #include <config.h>
 #endif
 
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -52,8 +53,7 @@ static GLog *log_data;
 
 /* Open a debug file whose name is specified in the given path. */
 void
-dbg_log_open (const char *path)
-{
+dbg_log_open (const char *path) {
   if (path != NULL) {
     log_file = fopen (path, "w");
     if (log_file == NULL)
@@ -63,8 +63,7 @@ dbg_log_open (const char *path)
 
 /* Close the debug file. */
 void
-dbg_log_close (void)
-{
+dbg_log_close (void) {
   if (log_file != NULL)
     fclose (log_file);
 }
@@ -72,8 +71,7 @@ dbg_log_close (void)
 /* Open the invalid requests log file whose name is specified in the
  * given path. */
 void
-invalid_log_open (const char *path)
-{
+invalid_log_open (const char *path) {
   if (path != NULL) {
     log_invalid = fopen (path, "w");
     if (log_invalid == NULL)
@@ -83,24 +81,21 @@ invalid_log_open (const char *path)
 
 /* Close the invalid requests log file. */
 void
-invalid_log_close (void)
-{
+invalid_log_close (void) {
   if (log_invalid != NULL)
     fclose (log_invalid);
 }
 
 /* Set current overall parsed log data. */
 void
-set_signal_data (void *p)
-{
+set_signal_data (void *p) {
   log_data = p;
 }
 
 /* Open the WebSocket access log file whose name is specified in the
  * given path. */
 int
-access_log_open (const char *path)
-{
+access_log_open (const char *path) {
   if (path == NULL)
     return 0;
 
@@ -116,8 +111,7 @@ access_log_open (const char *path)
 
 /* Close the WebSocket access log file. */
 void
-access_log_close (void)
-{
+access_log_close (void) {
   if (access_log != NULL)
     fclose (access_log);
 }
@@ -125,8 +119,7 @@ access_log_close (void)
 /* Dump to the standard output the values of the overall parsed log
  * data. */
 static void
-dump_struct (FILE * fp)
-{
+dump_struct (FILE * fp) {
   int pid = getpid ();
   if (!log_data)
     return;
@@ -137,14 +130,12 @@ dump_struct (FILE * fp)
   fprintf (fp, "==%d== Offset: %u\n", pid, log_data->offset);
   fprintf (fp, "==%d== Invalid data: %u\n", pid, log_data->invalid);
   fprintf (fp, "==%d== Piping: %d\n", pid, log_data->piping);
-  fprintf (fp, "==%d== Response size: %llu bytes\n", pid, log_data->resp_size);
   fprintf (fp, "==%d==\n", pid);
 }
 
 /* Custom SIGSEGV handler. */
 void
-sigsegv_handler (int sig)
-{
+sigsegv_handler (int sig) {
   FILE *fp = stderr;
   int pid = getpid ();
 
@@ -178,11 +169,9 @@ sigsegv_handler (int sig)
   exit (EXIT_FAILURE);
 }
 
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
 /* Write formatted debug log data to the logfile. */
 void
-dbg_fprintf (const char *fmt, ...)
-{
+dbg_fprintf (const char *fmt, ...) {
   va_list args;
 
   if (!log_file)
@@ -196,8 +185,7 @@ dbg_fprintf (const char *fmt, ...)
 
 /* Write formatted invalid requests log data to the logfile. */
 void
-invalid_fprintf (const char *fmt, ...)
-{
+invalid_fprintf (const char *fmt, ...) {
   va_list args;
 
   if (!log_invalid)
@@ -211,8 +199,7 @@ invalid_fprintf (const char *fmt, ...)
 
 /* Debug otuput */
 void
-dbg_printf (const char *fmt, ...)
-{
+dbg_printf (const char *fmt, ...) {
   va_list args;
   va_start (args, fmt);
   vfprintf (stderr, fmt, args);
@@ -221,8 +208,7 @@ dbg_printf (const char *fmt, ...)
 
 /* Write formatted access log data to the logfile. */
 void
-access_fprintf (const char *fmt, ...)
-{
+access_fprintf (const char *fmt, ...) {
   va_list args;
 
   if (!access_log)
@@ -233,5 +219,3 @@ access_fprintf (const char *fmt, ...)
   fflush (access_log);
   va_end (args);
 }
-
-#pragma GCC diagnostic warning "-Wformat-nonliteral"
