@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -37,15 +37,12 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <regex.h>
+#include <inttypes.h>
 
 #include "gdashboard.h"
 
-#ifdef HAVE_LIBTOKYOCABINET
-#include "tcabdb.h"
-#else
 #include "gkhash.h"
-#endif
-
+#include "gholder.h"
 #include "color.h"
 #include "error.h"
 #include "gstorage.h"
@@ -56,8 +53,7 @@ static GFind find_t;
 
 /* Reset find indices */
 void
-reset_find (void)
-{
+reset_find (void) {
   if (find_t.pattern != NULL && *find_t.pattern != '\0')
     free (find_t.pattern);
 
@@ -73,8 +69,7 @@ reset_find (void)
  *
  * On success, the newly allocated GDash is returned . */
 GDash *
-new_gdash (void)
-{
+new_gdash (void) {
   GDash *dash = xmalloc (sizeof (GDash));
   memset (dash, 0, sizeof *dash);
   dash->total_alloc = 0;
@@ -86,8 +81,7 @@ new_gdash (void)
  *
  * On success, the newly allocated GDashData is returned . */
 GDashData *
-new_gdata (uint32_t size)
-{
+new_gdata (uint32_t size) {
   GDashData *data = xcalloc (size, sizeof (GDashData));
 
   return data;
@@ -96,8 +90,7 @@ new_gdata (uint32_t size)
 /* Free memory allocated for a GDashData instance. Includes malloc'd
  * strings. */
 static void
-free_dashboard_data (GDashData item)
-{
+free_dashboard_data (GDashData item) {
   if (item.metrics == NULL)
     return;
 
@@ -117,8 +110,7 @@ free_dashboard_data (GDashData item)
 /* Free memory allocated for a GDash instance, and nested structure
  * data. */
 void
-free_dashboard (GDash * dash)
-{
+free_dashboard (GDash * dash) {
   GModule module;
   int j;
   size_t idx = 0;
@@ -139,8 +131,7 @@ free_dashboard (GDash * dash)
  * If not found, 0 is returned.
  * If found, the module number is returned . */
 static GModule
-get_find_current_module (GDash * dash, int offset)
-{
+get_find_current_module (GDash * dash, int offset) {
   GModule module;
   size_t idx = 0;
 
@@ -162,8 +153,7 @@ get_find_current_module (GDash * dash, int offset)
  *
  * On success, the number of rows is returned. */
 int
-get_num_collapsed_data_rows (void)
-{
+get_num_collapsed_data_rows (void) {
   /* The default number of rows is fixed */
   int size = DASH_COLLAPSED - DASH_NON_DATA;
   /* If no column names, then add the number of rows occupied by the
@@ -175,8 +165,7 @@ get_num_collapsed_data_rows (void)
  *
  * On success, the number of rows is returned. */
 int
-get_num_expanded_data_rows (void)
-{
+get_num_expanded_data_rows (void) {
   /* The default number of rows is fixed */
   int size = DASH_EXPANDED - DASH_NON_DATA;
   /* If no column names, then add the number of rows occupied by the
@@ -189,8 +178,7 @@ get_num_expanded_data_rows (void)
  *
  * On success, the Y position is returned. */
 static int
-get_data_pos_rows (void)
-{
+get_data_pos_rows (void) {
   return conf.no_column_names ? DASH_DATA_POS - DASH_COL_ROWS : DASH_DATA_POS;
 }
 
@@ -199,8 +187,7 @@ get_data_pos_rows (void)
  *
  * On success, the X position is returned. */
 static int
-get_xpos (void)
-{
+get_xpos (void) {
   return DASH_INIT_X;
 }
 
@@ -210,8 +197,7 @@ get_xpos (void)
  * On error, 1 is returned.
  * On success, 0 is returned. */
 int
-set_module_from_mouse_event (GScroll * gscroll, GDash * dash, int y)
-{
+set_module_from_mouse_event (GScroll * gscroll, GDash * dash, int y) {
   int module = 0;
   int offset = y - MAX_HEIGHT_HEADER - MAX_HEIGHT_FOOTER + 1;
   if (gscroll->expanded) {
@@ -238,8 +224,7 @@ set_module_from_mouse_event (GScroll * gscroll, GDash * dash, int y)
  * On error, NULL is returned.
  * On success, the newly allocated string is returned. */
 static char *
-render_child_node (const char *data)
-{
+render_child_node (const char *data) {
   char *buf;
   int len = 0;
 
@@ -267,8 +252,7 @@ render_child_node (const char *data)
  * On success, the newly allocated string representing the chart is
  * returned. */
 static char *
-get_bars (int n, int max, int x)
-{
+get_bars (int n, int max, int x) {
   int w, h;
   float len = 0.0;
 
@@ -282,10 +266,21 @@ get_bars (int n, int max, int x)
   return char_repeat (len, '|');
 }
 
+/* Get largest hits metric.
+ *
+ * On error, 0 is returned.
+ * On success, largest hits metric is returned. */
+static void
+set_max_metrics (GDashMeta * meta, GDashData * idata) {
+  if (meta->max_hits < idata->metrics->hits)
+    meta->max_hits = idata->metrics->hits;
+  if (meta->max_visitors < idata->metrics->visitors)
+    meta->max_visitors = idata->metrics->visitors;
+}
+
 /* Set largest hits metric (length of the integer). */
 static void
-set_max_hit_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_hit_len (GDashMeta * meta, GDashData * idata) {
   int vlen = intlen (idata->metrics->hits);
   int llen = strlen (MTRC_HITS_LBL);
 
@@ -300,8 +295,7 @@ set_max_hit_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_hit_perc_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_hit_perc_len (GDashMeta * meta, GDashData * idata) {
   int vlen = intlen (idata->metrics->hits_perc);
   int llen = strlen (MTRC_HITS_PERC_LBL);
 
@@ -316,8 +310,7 @@ set_max_hit_perc_len (GDashMeta * meta, GDashData * idata)
 
 /* Set largest hits metric (length of the integer). */
 static void
-set_max_visitors_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_visitors_len (GDashMeta * meta, GDashData * idata) {
   int vlen = intlen (idata->metrics->visitors);
   int llen = strlen (MTRC_VISITORS_SHORT_LBL);
 
@@ -332,8 +325,7 @@ set_max_visitors_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_visitors_perc_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_visitors_perc_len (GDashMeta * meta, GDashData * idata) {
   int vlen = intlen (idata->metrics->visitors_perc);
   int llen = strlen (MTRC_VISITORS_PERC_LBL);
 
@@ -348,8 +340,7 @@ set_max_visitors_perc_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_bw_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_bw_len (GDashMeta * meta, GDashData * idata) {
   int vlen = strlen (idata->metrics->bw.sbw);
   int llen = strlen (MTRC_BW_LBL);
 
@@ -364,8 +355,7 @@ set_max_bw_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_avgts_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_avgts_len (GDashMeta * meta, GDashData * idata) {
   int vlen = 0, llen = 0;
 
   if (!conf.serve_usecs || !idata->metrics->avgts.sts)
@@ -385,8 +375,7 @@ set_max_avgts_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_cumts_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_cumts_len (GDashMeta * meta, GDashData * idata) {
   int vlen = 0, llen = 0;
 
   if (!conf.serve_usecs || !idata->metrics->cumts.sts)
@@ -406,8 +395,7 @@ set_max_cumts_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_maxts_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_maxts_len (GDashMeta * meta, GDashData * idata) {
   int vlen = 0, llen = 0;
 
   if (!conf.serve_usecs || !idata->metrics->maxts.sts)
@@ -427,8 +415,7 @@ set_max_maxts_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_method_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_method_len (GDashMeta * meta, GDashData * idata) {
   int vlen = 0, llen = 0;
 
   if (!conf.append_method || !idata->metrics->method)
@@ -448,8 +435,7 @@ set_max_method_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_protocol_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_protocol_len (GDashMeta * meta, GDashData * idata) {
   int vlen = 0, llen = 0;
 
   if (!conf.append_protocol || !idata->metrics->protocol)
@@ -469,8 +455,7 @@ set_max_protocol_len (GDashMeta * meta, GDashData * idata)
 
 /* Get the percent integer length. */
 static void
-set_max_data_len (GDashMeta * meta, GDashData * idata)
-{
+set_max_data_len (GDashMeta * meta, GDashData * idata) {
   int vlen = 0, llen = 0;
 
   vlen = strlen (idata->metrics->data);
@@ -486,17 +471,7 @@ set_max_data_len (GDashMeta * meta, GDashData * idata)
 }
 
 static void
-set_max_values (GDashMeta * meta, GMetrics * metrics)
-{
-  if (metrics->hits > meta->max_hits)
-    meta->max_hits = metrics->hits;
-  if (metrics->visitors > meta->max_visitors)
-    meta->max_visitors = metrics->visitors;
-}
-
-static void
-set_metrics_len (GDashMeta * meta, GDashData * idata)
-{
+set_metrics_len (GDashMeta * meta, GDashData * idata) {
   /* integer-based length */
   set_max_hit_len (meta, idata);
   set_max_hit_perc_len (meta, idata);
@@ -516,8 +491,7 @@ set_metrics_len (GDashMeta * meta, GDashData * idata)
 
 /* Render host's panel selected row */
 static void
-render_data_hosts (WINDOW * win, GDashRender render, char *value, int x)
-{
+render_data_hosts (WINDOW * win, GDashRender render, char *value, int x) {
   char *padded_data;
 
   padded_data = left_pad_str (value, x);
@@ -530,15 +504,12 @@ render_data_hosts (WINDOW * win, GDashRender render, char *value, int x)
  * On error, '---' placeholder is returned.
  * On success, the formatted date is returned. */
 static char *
-set_visitors_date (const char *value)
-{
-  return get_visitors_date (value, conf.spec_date_time_num_format,
-                            conf.spec_date_time_format);
+set_visitors_date (const char *value) {
+  return get_visitors_date (value, conf.spec_date_time_num_format, conf.spec_date_time_format);
 }
 
 static char *
-get_fixed_fmt_width (int w, char type)
-{
+get_fixed_fmt_width (int w, char type) {
   char *fmt = xmalloc (snprintf (NULL, 0, "%%%d%c", w, type) + 1);
   sprintf (fmt, "%%%d%c", w, type);
 
@@ -547,9 +518,7 @@ get_fixed_fmt_width (int w, char type)
 
 /* Render the 'total' label on each panel */
 static void
-render_total_label (WINDOW * win, GDashModule * data, int y,
-                    GColors * (*func) (void))
-{
+render_total_label (WINDOW * win, GDashModule * data, int y, GColors * (*func) (void)) {
   char *s;
   int win_h, win_w, total, ht_size;
 
@@ -567,8 +536,7 @@ render_total_label (WINDOW * win, GDashModule * data, int y,
 
 /* Render panel bar graph */
 static void
-render_bars (GDashModule * data, GDashRender render, int *x)
-{
+render_bars (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color (COLOR_BARS);
   WINDOW *win = render.win;
   char *bar;
@@ -587,8 +555,7 @@ render_bars (GDashModule * data, GDashRender render, int *x)
 
 /* Render the data metric for each panel */
 static void
-render_data (GDashModule * data, GDashRender render, int *x)
-{
+render_data (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_DATA, data->module);
   WINDOW *win = render.win;
 
@@ -624,8 +591,7 @@ render_data (GDashModule * data, GDashRender render, int *x)
  * On error, no method is rendered and it returns.
  * On success, method is rendered. */
 static void
-render_method (GDashModule * data, GDashRender render, int *x)
-{
+render_method (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_MTHD, data->module);
   WINDOW *win = render.win;
 
@@ -653,8 +619,7 @@ render_method (GDashModule * data, GDashRender render, int *x)
  * On error, no protocol is rendered and it returns.
  * On success, protocol is rendered. */
 static void
-render_proto (GDashModule * data, GDashRender render, int *x)
-{
+render_proto (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_PROT, data->module);
   WINDOW *win = render.win;
 
@@ -679,8 +644,7 @@ render_proto (GDashModule * data, GDashRender render, int *x)
 
 /* Render the average time served metric for each panel */
 static void
-render_avgts (GDashModule * data, GDashRender render, int *x)
-{
+render_avgts (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_AVGTS, data->module);
   WINDOW *win = render.win;
 
@@ -706,8 +670,7 @@ out:
 
 /* Render the cumulative time served metric for each panel */
 static void
-render_cumts (GDashModule * data, GDashRender render, int *x)
-{
+render_cumts (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_CUMTS, data->module);
   WINDOW *win = render.win;
 
@@ -733,8 +696,7 @@ out:
 
 /* Render the maximum time served metric for each panel */
 static void
-render_maxts (GDashModule * data, GDashRender render, int *x)
-{
+render_maxts (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_MAXTS, data->module);
   WINDOW *win = render.win;
 
@@ -760,8 +722,7 @@ out:
 
 /* Render the bandwidth metric for each panel */
 static void
-render_bw (GDashModule * data, GDashRender render, int *x)
-{
+render_bw (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_BW, data->module);
   WINDOW *win = render.win;
 
@@ -789,8 +750,7 @@ out:
 
 /* Render a percent metric */
 static void
-render_percent (GDashRender render, GColors * color, float perc, int len, int x)
-{
+render_percent (GDashRender render, GColors * color, float perc, int len, int x) {
   WINDOW *win = render.win;
   char *percent;
   int y = render.y, w = render.w, sel = render.sel;
@@ -810,8 +770,7 @@ render_percent (GDashRender render, GColors * color, float perc, int len, int x)
 
 /* Render the hits percent metric for each panel */
 static void
-render_hits_percent (GDashModule * data, GDashRender render, int *x)
-{
+render_hits_percent (GDashModule * data, GDashRender render, int *x) {
   GColorItem item = COLOR_MTRC_HITS_PERC;
   GColors *color;
   int l = data->meta.hits_perc_len + 3, idx = render.idx;
@@ -831,8 +790,7 @@ out:
 
 /* Render the visitors percent metric for each panel */
 static void
-render_visitors_percent (GDashModule * data, GDashRender render, int *x)
-{
+render_visitors_percent (GDashModule * data, GDashRender render, int *x) {
   GColorItem item = COLOR_MTRC_VISITORS_PERC;
   GColors *color;
   int l = data->meta.visitors_perc_len + 3, idx = render.idx;
@@ -852,8 +810,7 @@ out:
 
 /* Render the hits metric for each panel */
 static void
-render_hits (GDashModule * data, GDashRender render, int *x)
-{
+render_hits (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_HITS, data->module);
   WINDOW *win = render.win;
 
@@ -872,7 +829,7 @@ render_hits (GDashModule * data, GDashRender render, int *x)
   } else {
     /* regular state */
     wattron (win, color->attr | COLOR_PAIR (color->pair->idx));
-    mvwprintw (win, y, *x, "%*d", len, data->data[idx].metrics->hits);
+    mvwprintw (win, y, *x, "%*" PRIu32 "", len, data->data[idx].metrics->hits);
     wattroff (win, color->attr | COLOR_PAIR (color->pair->idx));
   }
 
@@ -882,8 +839,7 @@ out:
 
 /* Render the visitors metric for each panel */
 static void
-render_visitors (GDashModule * data, GDashRender render, int *x)
-{
+render_visitors (GDashModule * data, GDashRender render, int *x) {
   GColors *color = get_color_by_item_module (COLOR_MTRC_VISITORS, data->module);
   WINDOW *win = render.win;
 
@@ -902,7 +858,7 @@ render_visitors (GDashModule * data, GDashRender render, int *x)
   } else {
     /* regular state */
     wattron (win, color->attr | COLOR_PAIR (color->pair->idx));
-    mvwprintw (win, y, *x, "%*d", len, data->data[idx].metrics->visitors);
+    mvwprintw (win, y, *x, "%*" PRIu32 "", len, data->data[idx].metrics->visitors);
     wattroff (win, color->attr | COLOR_PAIR (color->pair->idx));
   }
 
@@ -912,8 +868,7 @@ out:
 
 /* Render the header row for each panel */
 static void
-render_header (WINDOW * win, GDashModule * data, GModule cur_module, int *y)
-{
+render_header (WINDOW * win, GDashModule * data, GModule cur_module, int *y) {
   GColors *(*func) (void);
   char ind;
   char *hd;
@@ -939,8 +894,7 @@ render_header (WINDOW * win, GDashModule * data, GModule cur_module, int *y)
 
 /* Render the description row for each panel */
 static void
-render_description (WINDOW * win, GDashModule * data, int *y)
-{
+render_description (WINDOW * win, GDashModule * data, int *y) {
   int w, h;
 
   getmaxyx (win, h, w);
@@ -956,8 +910,7 @@ render_description (WINDOW * win, GDashModule * data, int *y)
 /* Render available metrics per panel.
  * ###TODO: Have the abilitity to display metrics in specific order */
 static void
-render_metrics (GDashModule * data, GDashRender render, int expanded)
-{
+render_metrics (GDashModule * data, GDashRender render, int expanded) {
   int x = get_xpos ();
   GModule module = data->module;
   const GOutput *output = output_lookup (module);
@@ -1000,9 +953,7 @@ render_metrics (GDashModule * data, GDashRender render, int expanded)
 
 /* Render a dashboard row. */
 static void
-render_data_line (WINDOW * win, GDashModule * data, int *y, int j,
-                  GScroll * gscroll)
-{
+render_data_line (WINDOW * win, GDashModule * data, int *y, int j, GScroll * gscroll) {
   GDashRender render;
   GModule module = data->module;
   int expanded = 0, sel = 0;
@@ -1033,16 +984,13 @@ out:
 
 /* Render a dashed line underneath the metric label. */
 static void
-print_horizontal_dash (WINDOW * win, int y, int x, int len)
-{
+print_horizontal_dash (WINDOW * win, int y, int x, int len) {
   mvwprintw (win, y, x, "%.*s", len, "----------------");
 }
 
 /* Render left-aligned column label. */
 static void
-lprint_col (WINDOW * win, int y, int *x, int len, const char *fmt,
-            const char *str)
-{
+lprint_col (WINDOW * win, int y, int *x, int len, const char *fmt, const char *str) {
   GColors *color = get_color (COLOR_PANEL_COLS);
 
   wattron (win, color->attr | COLOR_PAIR (color->pair->idx));
@@ -1055,9 +1003,7 @@ lprint_col (WINDOW * win, int y, int *x, int len, const char *fmt,
 
 /* Render right-aligned column label. */
 static void
-rprint_col (WINDOW * win, int y, int *x, int len, const char *fmt,
-            const char *str)
-{
+rprint_col (WINDOW * win, int y, int *x, int len, const char *fmt, const char *str) {
   GColors *color = get_color (COLOR_PANEL_COLS);
 
   wattron (win, color->attr | COLOR_PAIR (color->pair->idx));
@@ -1071,8 +1017,7 @@ rprint_col (WINDOW * win, int y, int *x, int len, const char *fmt,
 /* Render column names for available metrics.
  * ###TODO: Have the abilitity to display metrics in specific order */
 static void
-render_cols (WINDOW * win, GDashModule * data, int *y)
-{
+render_cols (WINDOW * win, GDashModule * data, int *y) {
   GModule module = data->module;
   const GOutput *output = output_lookup (module);
   int x = get_xpos ();
@@ -1084,16 +1029,13 @@ render_cols (WINDOW * win, GDashModule * data, int *y)
     lprint_col (win, *y, &x, data->meta.hits_len, "%s", MTRC_HITS_LBL);
 
   if (output->percent)
-    rprint_col (win, *y, &x, data->meta.hits_perc_len + 4, "%*s",
-                MTRC_HITS_PERC_LBL);
+    rprint_col (win, *y, &x, data->meta.hits_perc_len + 4, "%*s", MTRC_HITS_PERC_LBL);
 
   if (output->visitors)
-    rprint_col (win, *y, &x, data->meta.visitors_len, "%*s",
-                MTRC_VISITORS_SHORT_LBL);
+    rprint_col (win, *y, &x, data->meta.visitors_len, "%*s", MTRC_VISITORS_SHORT_LBL);
 
   if (output->percent)
-    rprint_col (win, *y, &x, data->meta.visitors_perc_len + 4, "%*s",
-                MTRC_VISITORS_PERC_LBL);
+    rprint_col (win, *y, &x, data->meta.visitors_perc_len + 4, "%*s", MTRC_VISITORS_PERC_LBL);
 
   if (output->bw && conf.bandwidth)
     rprint_col (win, *y, &x, data->meta.bw_len, "%*s", MTRC_BW_LBL);
@@ -1108,8 +1050,7 @@ render_cols (WINDOW * win, GDashModule * data, int *y)
     rprint_col (win, *y, &x, DASH_SRV_TM_LEN, "%*s", MTRC_MAXTS_LBL);
 
   if (output->method && conf.append_method)
-    lprint_col (win, *y, &x, data->meta.method_len, "%s",
-                MTRC_METHODS_SHORT_LBL);
+    lprint_col (win, *y, &x, data->meta.method_len, "%s", MTRC_METHODS_SHORT_LBL);
 
   if (output->protocol && conf.append_protocol)
     lprint_col (win, *y, &x, 8, "%s", MTRC_PROTOCOLS_SHORT_LBL);
@@ -1121,8 +1062,7 @@ render_cols (WINDOW * win, GDashModule * data, int *y)
 /* Iterate over all dashboard data and render its content. */
 static void
 render_content (WINDOW * win, GDashModule * data, int *y, int *offset,
-                int *total, GScroll * gscroll)
-{
+                int *total, GScroll * gscroll) {
   GModule module = data->module;
   int i, j, size, h, w, data_pos = get_data_pos_rows ();
 
@@ -1164,8 +1104,7 @@ render_content (WINDOW * win, GDashModule * data, int *y, int *offset,
 
 /* Entry point to render the terminal dashboard. */
 void
-display_content (WINDOW * win, GDash * dash, GScroll * gscroll)
-{
+display_content (WINDOW * win, GDash * dash, GScroll * gscroll) {
   GModule module;
   int j = 0;
   size_t idx = 0;
@@ -1195,8 +1134,7 @@ display_content (WINDOW * win, GDash * dash, GScroll * gscroll)
 
 /* Reset the scroll and offset fields for each panel/module. */
 void
-reset_scroll_offsets (GScroll * gscroll)
-{
+reset_scroll_offsets (GScroll * gscroll) {
   GModule module;
   size_t idx = 0;
 
@@ -1213,8 +1151,7 @@ reset_scroll_offsets (GScroll * gscroll)
  * If unable to compile, an error as described in <regex.h>.
  * Upon successful completion, function returns 0. */
 static int
-regexp_init (regex_t * regex, const char *pattern)
-{
+regexp_init (regex_t * regex, const char *pattern) {
   int y, x, rc;
   char buf[REGEX_ERROR];
 
@@ -1232,8 +1169,7 @@ regexp_init (regex_t * regex, const char *pattern)
 
 /* Set the dashboard scroll and offset based on the search index. */
 static void
-perform_find_dash_scroll (GScroll * gscroll, GModule module)
-{
+perform_find_dash_scroll (GScroll * gscroll, GModule module) {
   int *scrll, *offset;
   int exp_size = get_num_expanded_data_rows ();
 
@@ -1259,8 +1195,7 @@ perform_find_dash_scroll (GScroll * gscroll, GModule module)
  * If not found, the GFind structure is reset and 1 is returned.
  * If found, a GFind structure is set and 0 is returned. */
 static int
-find_next_sub_item (GSubList * sub_list, regex_t * regex)
-{
+find_next_sub_item (GSubList * sub_list, regex_t * regex) {
   GSubItem *iter;
   int i = 0, rc;
 
@@ -1292,8 +1227,7 @@ out:
  * On error or if not found, 1 is returned.
  * On success or if found, a GFind structure is set and 0 is returned. */
 int
-perform_next_find (GHolder * h, GScroll * gscroll)
-{
+perform_next_find (GHolder * h, GScroll * gscroll) {
   GModule module;
   GSubList *sub_list;
   regex_t regex;
@@ -1369,8 +1303,7 @@ out:
  * On error or if no query is set, 1 is returned.
  * On success, the dialog is rendered and 0 is returned. */
 int
-render_find_dialog (WINDOW * main_win, GScroll * gscroll)
-{
+render_find_dialog (WINDOW * main_win, GScroll * gscroll) {
   int y, x, valid = 1;
   int w = FIND_DLG_WIDTH;
   int h = FIND_DLG_HEIGHT;
@@ -1404,8 +1337,7 @@ render_find_dialog (WINDOW * main_win, GScroll * gscroll)
 
 static void
 set_dash_metrics (GDash ** dash, GMetrics * metrics, GModule module,
-                  int is_subitem)
-{
+                  GPercTotals totals, int is_subitem) {
   GDashData *idata = NULL;
   GDashMeta *meta = NULL;
   char *data = NULL;
@@ -1423,14 +1355,10 @@ set_dash_metrics (GDash ** dash, GMetrics * metrics, GModule module,
 
   data = is_subitem ? render_child_node (metrics->data) : metrics->data;
 
-  /* set maximum values so far for hits/visitors */
-  set_max_values (meta, metrics);
-
   idata->metrics->hits = metrics->hits;
-  idata->metrics->hits_perc = get_percentage (meta->max_hits, metrics->hits);
+  idata->metrics->hits_perc = get_percentage (totals.hits, metrics->hits);
   idata->metrics->visitors = metrics->visitors;
-  idata->metrics->visitors_perc =
-    get_percentage (meta->max_visitors, metrics->visitors);
+  idata->metrics->visitors_perc = get_percentage (totals.visitors, metrics->visitors);
   idata->metrics->bw.sbw = filesize_str (metrics->bw.nbw);
   idata->metrics->data = xstrdup (data);
 
@@ -1451,6 +1379,7 @@ out:
     free (data);
 
   set_metrics_len (meta, idata);
+  set_max_metrics (meta, idata);
 
   (*idx)++;
 }
@@ -1460,8 +1389,8 @@ out:
  * If no items on the sub list, the function returns.
  * On success, sub list data is set into the dashboard structure. */
 static void
-add_sub_item_to_dash (GDash ** dash, GHolderItem item, GModule module, int *i)
-{
+add_sub_item_to_dash (GDash ** dash, GHolderItem item, GModule module, GPercTotals totals,
+                      int *i) {
   GSubList *sub_list = item.sub_list;
   GSubItem *iter;
 
@@ -1469,7 +1398,7 @@ add_sub_item_to_dash (GDash ** dash, GHolderItem item, GModule module, int *i)
     return;
 
   for (iter = sub_list->head; iter; iter = iter->next, (*i)++) {
-    set_dash_metrics (dash, iter->metrics, module, 1);
+    set_dash_metrics (dash, iter->metrics, module, totals, 1);
   }
 }
 
@@ -1477,17 +1406,16 @@ add_sub_item_to_dash (GDash ** dash, GHolderItem item, GModule module, int *i)
  *
  * On success, data is set into the dashboard structure. */
 static void
-add_item_to_dash (GDash ** dash, GHolderItem item, GModule module)
-{
-  set_dash_metrics (dash, item.metrics, module, 0);
+add_item_to_dash (GDash ** dash, GHolderItem item, GModule module, GPercTotals totals) {
+  set_dash_metrics (dash, item.metrics, module, totals, 0);
 }
 
 /* Load holder's data into the dashboard structure. */
 void
-load_data_to_dash (GHolder * h, GDash * dash, GModule module, GScroll * gscroll)
-{
+load_data_to_dash (GHolder * h, GDash * dash, GModule module, GScroll * gscroll) {
   int alloc_size = 0;
   int i, j;
+  GPercTotals totals;
 
   alloc_size = dash->module[module].alloc_data;
   if (gscroll->expanded && module == gscroll->current)
@@ -1498,13 +1426,15 @@ load_data_to_dash (GHolder * h, GDash * dash, GModule module, GScroll * gscroll)
   dash->module[module].holder_size = h->holder_size;
   memset (&dash->module[module].meta, 0, sizeof (GDashData));
 
+  set_module_totals (&totals);
+
   for (i = 0, j = 0; i < alloc_size; i++) {
     if (h->items[j].metrics->data == NULL)
       continue;
 
-    add_item_to_dash (&dash, h->items[j], module);
+    add_item_to_dash (&dash, h->items[j], module, totals);
     if (gscroll->expanded && module == gscroll->current && h->sub_items_size)
-      add_sub_item_to_dash (&dash, h->items[j], module, &i);
+      add_sub_item_to_dash (&dash, h->items[j], module, totals, &i);
     j++;
   }
 }
