@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,16 +33,14 @@
 #define H_SIZE     1025
 #define QUEUE_SIZE 400
 
-typedef struct GDnsThread_
-{
+typedef struct GDnsThread_ {
   pthread_cond_t not_empty;     /* not empty queue condition */
   pthread_cond_t not_full;      /* not full queue condition */
   pthread_mutex_t mutex;
   pthread_t thread;
 } GDnsThread;
 
-typedef struct GDnsQueue_
-{
+typedef struct GDnsQueue_ {
   int head;                     /* index to head of queue */
   int tail;                     /* index to tail of queue */
   int size;                     /* queue size */
