@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,72 +32,64 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#ifdef HAVE_LIBTOKYOCABINET
-#include "tcabdb.h"
-#else
-#include "gkhash.h"
-#endif
-
-#ifdef HAVE_GEOLOCATION
-#include "geoip1.h"
-#endif
-
 #include "gholder.h"
 
 #include "error.h"
 #include "gdns.h"
+#include "gkhash.h"
 #include "util.h"
 #include "xmalloc.h"
 
-typedef struct GPanel_
-{
+#ifdef HAVE_GEOLOCATION
+#include "geoip1.h"
+#endif
+
+typedef struct GPanel_ {
   GModule module;
-  void (*insert) (GRawDataItem item, GHolder * h, GRawDataType type,
-                  const struct GPanel_ *);
+  void (*insert) (GRawDataItem item, GHolder * h, datatype type, const struct GPanel_ *);
   void (*holder_callback) (GHolder * h);
-  void (*lookup) (GRawDataItem item);
 } GPanel;
 
-static void add_data_to_holder (GRawDataItem item, GHolder * h,
-                                GRawDataType type, const GPanel * panel);
-static void add_host_to_holder (GRawDataItem item, GHolder * h,
-                                GRawDataType type, const GPanel * panel);
-static void add_root_to_holder (GRawDataItem item, GHolder * h,
-                                GRawDataType type, const GPanel * panel);
-static void add_host_child_to_holder (GHolder * h);
 
 /* *INDENT-OFF* */
+static void add_data_to_holder (GRawDataItem item, GHolder * h, datatype type, const GPanel * panel);
+static void add_host_to_holder (GRawDataItem item, GHolder * h, datatype type, const GPanel * panel);
+static void add_root_to_holder (GRawDataItem item, GHolder * h, datatype type, const GPanel * panel);
+static void add_host_child_to_holder (GHolder * h);
+
 static GPanel paneling[] = {
-  {VISITORS        , add_data_to_holder, NULL} ,
-  {REQUESTS        , add_data_to_holder, NULL} ,
-  {REQUESTS_STATIC , add_data_to_holder, NULL} ,
-  {NOT_FOUND       , add_data_to_holder, NULL} ,
-  {HOSTS           , add_host_to_holder, add_host_child_to_holder} ,
-  {OS              , add_root_to_holder, NULL} ,
-  {BROWSERS        , add_root_to_holder, NULL} ,
-  {VISIT_TIMES     , add_data_to_holder, NULL} ,
-  {VIRTUAL_HOSTS   , add_data_to_holder, NULL} ,
-  {REFERRERS       , add_data_to_holder, NULL} ,
-  {REFERRING_SITES , add_data_to_holder, NULL} ,
-  {KEYPHRASES      , add_data_to_holder, NULL} ,
-  {STATUS_CODES    , add_root_to_holder, NULL} ,
-  {REMOTE_USER     , add_data_to_holder, NULL} ,
+  {VISITORS        , add_data_to_holder , NULL},
+  {REQUESTS        , add_data_to_holder , NULL},
+  {REQUESTS_STATIC , add_data_to_holder , NULL},
+  {NOT_FOUND       , add_data_to_holder , NULL},
+  {HOSTS           , add_host_to_holder , add_host_child_to_holder} ,
+  {OS              , add_root_to_holder , NULL},
+  {BROWSERS        , add_root_to_holder , NULL},
+  {VISIT_TIMES     , add_data_to_holder , NULL},
+  {VIRTUAL_HOSTS   , add_data_to_holder , NULL},
+  {REFERRERS       , add_data_to_holder , NULL},
+  {REFERRING_SITES , add_data_to_holder , NULL},
+  {KEYPHRASES      , add_data_to_holder , NULL},
+  {STATUS_CODES    , add_root_to_holder , NULL},
+  {REMOTE_USER     , add_data_to_holder , NULL},
+  {CACHE_STATUS    , add_data_to_holder , NULL},
 #ifdef HAVE_GEOLOCATION
-  {GEO_LOCATION    , add_root_to_holder, NULL} ,
+  {GEO_LOCATION    , add_root_to_holder , NULL},
 #endif
 };
 /* *INDENT-ON* */
 
+
 /* Get a panel from the GPanel structure given a module.
  *
  * On error, or if not found, NULL is returned.
  * On success, the panel value is returned. */
 static GPanel *
-panel_lookup (GModule module)
-{
+panel_lookup (GModule module) {
   int i, num_panels = ARRAY_SIZE (paneling);
 
   for (i = 0; i < num_panels; i++) {
@@ -111,8 +103,7 @@ panel_lookup (GModule module)
  *
  * On success, the newly allocated GHolder is returned . */
 GHolder *
-new_gholder (uint32_t size)
-{
+new_gholder (uint32_t size) {
   GHolder *holder = xmalloc (size * sizeof (GHolder));
   memset (holder, 0, size * sizeof *holder);
 
@@ -123,8 +114,7 @@ new_gholder (uint32_t size)
  *
  * On success, the newly allocated GHolderItem is returned . */
 static GHolderItem *
-new_gholder_item (uint32_t size)
-{
+new_gholder_item (uint32_t size) {
   GHolderItem *item = xcalloc (size, sizeof (GHolderItem));
 
   return item;
@@ -134,8 +124,7 @@ new_gholder_item (uint32_t size)
  *
  * On success, the newly allocated GSubList is returned . */
 static GSubList *
-new_gsublist (void)
-{
+new_gsublist (void) {
   GSubList *sub_list = xmalloc (sizeof (GSubList));
   sub_list->head = NULL;
   sub_list->tail = NULL;
@@ -148,8 +137,7 @@ new_gsublist (void)
  *
  * On success, the newly allocated GSubItem is returned . */
 static GSubItem *
-new_gsubitem (GModule module, GMetrics * nmetrics)
-{
+new_gsubitem (GModule module, GMetrics * nmetrics) {
   GSubItem *sub_item = xmalloc (sizeof (GSubItem));
 
   sub_item->metrics = nmetrics;
@@ -162,8 +150,7 @@ new_gsubitem (GModule module, GMetrics * nmetrics)
 
 /* Add an item to the end of a given sub list. */
 static void
-add_sub_item_back (GSubList * sub_list, GModule module, GMetrics * nmetrics)
-{
+add_sub_item_back (GSubList * sub_list, GModule module, GMetrics * nmetrics) {
   GSubItem *sub_item = new_gsubitem (module, nmetrics);
   if (sub_list->tail) {
     sub_list->tail->next = sub_item;
@@ -178,8 +165,7 @@ add_sub_item_back (GSubList * sub_list, GModule module, GMetrics * nmetrics)
 
 /* Delete the entire given sub list. */
 static void
-delete_sub_list (GSubList * sub_list)
-{
+delete_sub_list (GSubList * sub_list) {
   GSubItem *item = NULL;
   GSubItem *next = NULL;
 
@@ -202,8 +188,7 @@ clear:
 
 /* Free malloc'd holder fields. */
 static void
-free_holder_data (GHolderItem item)
-{
+free_holder_data (GHolderItem item) {
   if (item.sub_list != NULL)
     delete_sub_list (item.sub_list);
   if (item.metrics->data != NULL)
@@ -218,8 +203,7 @@ free_holder_data (GHolderItem item)
 
 /* Free all memory allocated in holder for a given module. */
 void
-free_holder_by_module (GHolder ** holder, GModule module)
-{
+free_holder_by_module (GHolder ** holder, GModule module) {
   int j;
 
   if ((*holder) == NULL)
@@ -237,8 +221,7 @@ free_holder_by_module (GHolder ** holder, GModule module)
 
 /* Free all memory allocated in holder for all modules. */
 void
-free_holder (GHolder ** holder)
-{
+free_holder (GHolder ** holder) {
   GModule module;
   int j;
   size_t idx = 0;
@@ -263,8 +246,7 @@ free_holder (GHolder ** holder)
  * If the key does not exist, -1 is returned.
  * On success, the key in holder is returned . */
 static int
-get_item_idx_in_holder (GHolder * holder, const char *k)
-{
+get_item_idx_in_holder (GHolder * holder, const char *k) {
   int i;
   if (holder == NULL)
     return KEY_NOT_FOUND;
@@ -284,8 +266,7 @@ get_item_idx_in_holder (GHolder * holder, const char *k)
 /* Copy linked-list items to an array, sort, and move them back to the
  * list. Should be faster than sorting the list */
 static void
-sort_sub_list (GHolder * h, GSort sort)
-{
+sort_sub_list (GHolder * h, GSort sort) {
   GHolderItem *arr;
   GSubItem *iter;
   GSubList *sub_list;
@@ -333,8 +314,7 @@ sort_sub_list (GHolder * h, GSort sort)
  *
  * On success, the data field/metric is set. */
 static int
-set_host_child_metrics (char *data, uint8_t id, GMetrics ** nmetrics)
-{
+set_host_child_metrics (char *data, uint8_t id, GMetrics ** nmetrics) {
   GMetrics *metrics;
 
   metrics = new_gmetrics ();
@@ -349,8 +329,7 @@ set_host_child_metrics (char *data, uint8_t id, GMetrics ** nmetrics)
  *
  * On success, the host panel data is set. */
 static void
-set_host_sub_list (GHolder * h, GSubList * sub_list)
-{
+set_host_sub_list (GHolder * h, GSubList * sub_list) {
   GMetrics *nmetrics;
 #ifdef HAVE_GEOLOCATION
   char city[CITY_LEN] = "";
@@ -387,7 +366,7 @@ set_host_sub_list (GHolder * h, GSubList * sub_list)
 #endif
 
   /* hostname */
-  if (conf.enable_html_resolver && conf.output_stdout) {
+  if (conf.enable_html_resolver && conf.output_stdout && !conf.no_ip_validation) {
     hostname = reverse_ip (host);
     set_host_child_metrics (hostname, MTRC_ID_HOSTNAME, &nmetrics);
     add_sub_item_back (sub_list, h->module, nmetrics);
@@ -401,8 +380,7 @@ set_host_sub_list (GHolder * h, GSubList * sub_list)
  *
  * On success, the host panel data is set. */
 static void
-add_host_child_to_holder (GHolder * h)
-{
+add_host_child_to_holder (GHolder * h) {
   GMetrics *nmetrics;
   GSubList *sub_list = new_gsublist ();
 
@@ -438,33 +416,32 @@ add_host_child_to_holder (GHolder * h)
  * On error, no values are set and 1 is returned.
  * On success, the data and hits values are set and 0 is returned. */
 static int
-set_data_hits_keys (GModule module, GRawDataItem item, GRawDataType type,
-                    char **data, int *hits)
-{
-  if (type == INTEGER) {
-    if (!(*data = ht_get_datamap (module, item.key)))
+map_data (GModule module, GRawDataItem item, datatype type, char **data, uint32_t * hits) {
+  switch (type) {
+  case U32:
+    if (!(*data = ht_get_datamap (module, item.nkey)))
       return 1;
-    *hits = item.value.ivalue;
-  } else if (type == STRING) {
-    if (!(*hits = ht_get_hits (module, item.key)))
+    *hits = item.hits;
+    break;
+  case STR:
+    if (!(*hits = ht_get_hits (module, item.nkey)))
       return 1;
-    *data = xstrdup (item.value.svalue);
+    *data = xstrdup (item.data);
+    break;
   }
   return 0;
 }
 
 /* Given a data item, store it into a holder structure. */
 static void
-set_data_holder_metrics (GRawDataItem item, GHolder * h, char *data, int hits)
-{
-  char *method = NULL, *protocol = NULL;
-  int visitors = 0;
+set_single_metrics (GRawDataItem item, GHolder * h, char *data, uint32_t hits) {
+  uint32_t visitors = 0;
   uint64_t bw = 0, cumts = 0, maxts = 0;
 
-  bw = ht_get_bw (h->module, item.key);
-  cumts = ht_get_cumts (h->module, item.key);
-  maxts = ht_get_maxts (h->module, item.key);
-  visitors = ht_get_visitors (h->module, item.key);
+  bw = ht_get_bw (h->module, item.nkey);
+  cumts = ht_get_cumts (h->module, item.nkey);
+  maxts = ht_get_maxts (h->module, item.nkey);
+  visitors = ht_get_visitors (h->module, item.nkey);
 
   h->items[h->idx].metrics = new_gmetrics ();
   h->items[h->idx].metrics->hits = hits;
@@ -475,23 +452,41 @@ set_data_holder_metrics (GRawDataItem item, GHolder * h, char *data, int hits)
   h->items[h->idx].metrics->cumts.nts = cumts;
   h->items[h->idx].metrics->maxts.nts = maxts;
 
+  if (bw && !conf.bandwidth)
+    conf.bandwidth = 1;
+  if (cumts && !conf.serve_usecs)
+    conf.serve_usecs = 1;
+
   if (conf.append_method) {
-    method = ht_get_method (h->module, item.key);
-    h->items[h->idx].metrics->method = method;
+    h->items[h->idx].metrics->method = ht_get_method (h->module, item.nkey);
   }
 
   if (conf.append_protocol) {
-    protocol = ht_get_protocol (h->module, item.key);
-    h->items[h->idx].metrics->protocol = protocol;
+    h->items[h->idx].metrics->protocol = ht_get_protocol (h->module, item.nkey);
   }
 }
 
+/* Set all panel data. This will set data for panels that do not
+ * contain sub items. A function pointer is used for post data set. */
+static void
+add_data_to_holder (GRawDataItem item, GHolder * h, datatype type, const GPanel * panel) {
+  char *data = NULL;
+  uint32_t hits = 0;
+
+  if (map_data (h->module, item, type, &data, &hits) == 1)
+    return;
+
+  set_single_metrics (item, h, data, hits);
+  if (panel->holder_callback)
+    panel->holder_callback (h);
+
+  h->idx++;
+}
+
 /* A wrapper to set a host item */
 static void
-set_host (GRawDataItem item, GHolder * h, const GPanel * panel, char *data,
-          int hits)
-{
-  set_data_holder_metrics (item, h, xstrdup (data), hits);
+set_host (GRawDataItem item, GHolder * h, const GPanel * panel, char *data, uint32_t hits) {
+  set_single_metrics (item, h, xstrdup (data), hits);
   if (panel->holder_callback)
     panel->holder_callback (h);
   h->idx++;
@@ -500,32 +495,11 @@ set_host (GRawDataItem item, GHolder * h, const GPanel * panel, char *data,
 /* Set all panel data. This will set data for panels that do not
  * contain sub items. A function pointer is used for post data set. */
 static void
-add_data_to_holder (GRawDataItem item, GHolder * h, GRawDataType type,
-                    const GPanel * panel)
-{
-  char *data = NULL;
-  int hits = 0;
-
-  if (set_data_hits_keys (h->module, item, type, &data, &hits) == 1)
-    return;
-
-  set_data_holder_metrics (item, h, data, hits);
-  if (panel->holder_callback)
-    panel->holder_callback (h);
-
-  h->idx++;
-}
-
-/* Set all panel data. This will set data for panels that do not
- * contain sub items. A function pointer is used for post data set. */
-static void
-add_host_to_holder (GRawDataItem item, GHolder * h, GRawDataType type,
-                    const GPanel * panel)
-{
+add_host_to_holder (GRawDataItem item, GHolder * h, datatype type, const GPanel * panel) {
   char buf4[INET_ADDRSTRLEN];
   char buf6[INET6_ADDRSTRLEN];
   char *data = NULL;
-  int hits = 0;
+  uint32_t hits = 0;
   unsigned i;
 
   struct in6_addr addr6, mask6, nwork6;
@@ -534,7 +508,7 @@ add_host_to_holder (GRawDataItem item, GHolder * h, GRawDataType type,
   const char *m4 = "255.255.255.0";
   const char *m6 = "ffff:ffff:ffff:ffff:0000:0000:0000:0000";
 
-  if (set_data_hits_keys (h->module, item, type, &data, &hits) == 1)
+  if (map_data (h->module, item, type, &data, &hits) == 1)
     return;
 
   if (!conf.anonymize_ip) {
@@ -570,21 +544,19 @@ add_host_to_holder (GRawDataItem item, GHolder * h, GRawDataType type,
 
 /* Set all root panel data. This will set the root nodes. */
 static int
-set_root_metrics (GRawDataItem item, GRawDataType type, GModule module,
-                  GMetrics ** nmetrics)
-{
+set_root_metrics (GRawDataItem item, GModule module, datatype type, GMetrics ** nmetrics) {
   GMetrics *metrics;
   char *data = NULL;
   uint64_t bw = 0, cumts = 0, maxts = 0;
-  int hits = 0, visitors = 0;
+  uint32_t hits = 0, visitors = 0;
 
-  if (set_data_hits_keys (module, item, type, &data, &hits) == 1)
+  if (map_data (module, item, type, &data, &hits) == 1)
     return 1;
 
-  bw = ht_get_bw (module, item.key);
-  cumts = ht_get_cumts (module, item.key);
-  maxts = ht_get_maxts (module, item.key);
-  visitors = ht_get_visitors (module, item.key);
+  bw = ht_get_bw (module, item.nkey);
+  cumts = ht_get_cumts (module, item.nkey);
+  maxts = ht_get_maxts (module, item.nkey);
+  visitors = ht_get_visitors (module, item.nkey);
 
   metrics = new_gmetrics ();
   metrics->avgts.nts = cumts / hits;
@@ -601,18 +573,17 @@ set_root_metrics (GRawDataItem item, GRawDataType type, GModule module,
 
 /* Set all root panel data, including sub list items. */
 static void
-add_root_to_holder (GRawDataItem item, GHolder * h, GRawDataType type,
-                    GO_UNUSED const GPanel * panel)
-{
+add_root_to_holder (GRawDataItem item, GHolder * h, datatype type,
+                    GO_UNUSED const GPanel * panel) {
   GSubList *sub_list;
   GMetrics *metrics, *nmetrics;
   char *root = NULL;
   int root_idx = KEY_NOT_FOUND, idx = 0;
 
-  if (set_root_metrics (item, type, h->module, &nmetrics) == 1)
+  if (set_root_metrics (item, h->module, type, &nmetrics) == 1)
     return;
 
-  if (!(root = (ht_get_root (h->module, item.key))))
+  if (!(root = ht_get_root (h->module, item.nkey)))
     return;
 
   /* add data as a child node into holder */
@@ -642,6 +613,7 @@ add_root_to_holder (GRawDataItem item, GHolder * h, GRawDataType type,
   h->items[idx].metrics->visitors += nmetrics->visitors;
   h->items[idx].metrics->avgts.nts =
     h->items[idx].metrics->cumts.nts / h->items[idx].metrics->hits;
+
   if (nmetrics->maxts.nts > h->items[idx].metrics->maxts.nts)
     h->items[idx].metrics->maxts.nts = nmetrics->maxts.nts;
 
@@ -650,10 +622,13 @@ add_root_to_holder (GRawDataItem item, GHolder * h, GRawDataType type,
 
 /* Load raw data into our holder structure */
 void
-load_holder_data (GRawData * raw_data, GHolder * h, GModule module, GSort sort)
-{
-  int i, size = 0, max_choices = get_max_choices ();
+load_holder_data (GRawData * raw_data, GHolder * h, GModule module, GSort sort) {
+  clock_t begin = clock ();
+
+  int i;
+  uint32_t size = 0, max_choices = get_max_choices ();
   const GPanel *panel = panel_lookup (module);
+  double taken;
 
   size = raw_data->size;
   h->holder_size = size > max_choices ? max_choices : size;
@@ -670,4 +645,7 @@ load_holder_data (GRawData * raw_data, GHolder * h, GModule module, GSort sort)
   if (h->sub_items_size)
     sort_sub_list (h, sort);
   free_raw_data (raw_data);
+
+  taken = (double) (clock () - begin) / CLOCKS_PER_SEC;
+  LOG_DEBUG (("== %d\t\t\t%f\n", module, taken));
 }
