@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -35,35 +35,60 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef HAVE_LIBTOKYOCABINET
-#include "tcabdb.h"
-#else
 #include "gkhash.h"
-#endif
-
 #include "gstorage.h"
-
+#include "commons.h"
 #include "error.h"
+#include "util.h"
 #include "xmalloc.h"
 
 /* Allocate memory for a new GMetrics instance.
  *
  * On success, the newly allocated GMetrics is returned . */
 GMetrics *
-new_gmetrics (void)
-{
+new_gmetrics (void) {
   GMetrics *metrics = xcalloc (1, sizeof (GMetrics));
 
   return metrics;
 }
 
-/* Allocate space off the heap to store an int.
+/* Get the module string value given a metric enum value.
+ *
+ * On error, NULL is returned.
+ * On success, the string module value is returned. */
+char *
+get_mtr_str (GSMetric metric) {
+  /* String modules to enumerated modules */
+  GEnum enum_metrics[] = {
+    {"MTRC_KEYMAP", MTRC_KEYMAP},
+    {"MTRC_ROOTMAP", MTRC_ROOTMAP},
+    {"MTRC_DATAMAP", MTRC_DATAMAP},
+    {"MTRC_UNIQMAP", MTRC_UNIQMAP},
+    {"MTRC_ROOT", MTRC_ROOT},
+    {"MTRC_HITS", MTRC_HITS},
+    {"MTRC_VISITORS", MTRC_VISITORS},
+    {"MTRC_BW", MTRC_BW},
+    {"MTRC_CUMTS", MTRC_CUMTS},
+    {"MTRC_MAXTS", MTRC_MAXTS},
+    {"MTRC_METHODS", MTRC_METHODS},
+    {"MTRC_PROTOCOLS", MTRC_PROTOCOLS},
+    {"MTRC_AGENTS", MTRC_AGENTS},
+    {"MTRC_METADATA", MTRC_METADATA},
+    {"MTRC_UNIQUE_KEYS", MTRC_UNIQUE_KEYS},
+    {"MTRC_AGENT_KEYS", MTRC_AGENT_KEYS},
+    {"MTRC_AGENT_VALS", MTRC_AGENT_VALS},
+    {"MTRC_CNT_VALID", MTRC_CNT_VALID},
+    {"MTRC_CNT_BW", MTRC_CNT_BW},
+  };
+  return enum2str (enum_metrics, ARRAY_SIZE (enum_metrics), metric);
+}
+
+/* Allocate space off the heap to store a uint32_t.
  *
  * On success, the newly allocated pointer is returned . */
-int *
-int2ptr (int val)
-{
-  int *ptr = xmalloc (sizeof (int));
+uint32_t *
+i322ptr (uint32_t val) {
+  uint32_t *ptr = xmalloc (sizeof (uint32_t));
   *ptr = val;
 
   return ptr;
@@ -73,8 +98,7 @@ int2ptr (int val)
  *
  * On success, the newly allocated pointer is returned . */
 uint64_t *
-uint642ptr (uint64_t val)
-{
+uint642ptr (uint64_t val) {
   uint64_t *ptr = xmalloc (sizeof (uint64_t));
   *ptr = val;
 
@@ -83,19 +107,17 @@ uint642ptr (uint64_t val)
 
 /* Set the module totals to calculate percentages. */
 void
-set_module_totals (GModule module, GPercTotals * totals)
-{
-  totals->bw = ht_get_meta_data (module, "bytes");
-  totals->hits = ht_get_meta_data (module, "hits");
-  totals->visitors = ht_get_meta_data (module, "visitors");
+set_module_totals (GPercTotals * totals) {
+  totals->bw = ht_sum_bw ();
+  totals->hits = ht_sum_valid ();
+  totals->visitors = ht_get_size_uniqmap (VISITORS);
 }
 
 /* Set numeric metrics for each request given raw data.
  *
  * On success, numeric metrics are set into the given structure. */
 void
-set_data_metrics (GMetrics * ometrics, GMetrics ** nmetrics, GPercTotals totals)
-{
+set_data_metrics (GMetrics * ometrics, GMetrics ** nmetrics, GPercTotals totals) {
   GMetrics *metrics;
 
   /* determine percentages for certain fields */
