@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -31,13 +31,14 @@
 #define GSTORAGE_H_INCLUDED
 
 #include "commons.h"
+#include "parser.h"
 
 /* Total number of storage metrics (GSMetric) */
-#define GSMTRC_TOTAL 14
+#define GSMTRC_TOTAL 19
+#define DB_PATH "/tmp"
 
 /* Enumerated Storage Metrics */
-typedef enum GSMetric_
-{
+typedef enum GSMetric_ {
   MTRC_KEYMAP,
   MTRC_ROOTMAP,
   MTRC_DATAMAP,
@@ -52,17 +53,20 @@ typedef enum GSMetric_
   MTRC_PROTOCOLS,
   MTRC_AGENTS,
   MTRC_METADATA,
+  MTRC_UNIQUE_KEYS,
+  MTRC_AGENT_KEYS,
+  MTRC_AGENT_VALS,
+  MTRC_CNT_VALID,
+  MTRC_CNT_BW,
 } GSMetric;
 
 GMetrics *new_gmetrics (void);
 
-int *int2ptr (int val);
+uint32_t *i322ptr (uint32_t val);
 uint64_t *uint642ptr (uint64_t val);
 
-void *get_storage_metric_by_module (GModule module, GSMetric metric);
-void *get_storage_metric (GModule module, GSMetric metric);
-void set_data_metrics (GMetrics * ometrics, GMetrics ** nmetrics,
-                       GPercTotals totals);
-void set_module_totals (GModule module, GPercTotals * totals);
+char *get_mtr_str (GSMetric metric);
+void set_module_totals (GPercTotals * totals);
+void set_data_metrics (GMetrics * ometrics, GMetrics ** nmetrics, GPercTotals totals);
 
 #endif // for #ifndef GSTORAGE_H
