@@ -434,8 +434,7 @@ static const double __ac_HASH_UPPER = 0.77;
   @return       The hash value
  */
 static kh_inline khint_t
-__ac_X31_hash_string (const char *s)
-{
+__ac_X31_hash_string (const char *s) {
   khint_t h = (khint_t) * s;
   if (h)
     for (++s; *s; ++s)
@@ -455,8 +454,7 @@ __ac_X31_hash_string (const char *s)
 #define kh_str_hash_equal(a, b) (strcmp(a, b) == 0)
 
 static kh_inline khint_t
-__ac_Wang_hash (khint_t key)
-{
+__ac_Wang_hash (khint_t key) {
   key += ~(key << 15);
   key ^= (key >> 10);
   key += (key << 3);
