@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -138,6 +138,13 @@
 #define REMOTE_USER_LABEL              \
   N_("Remote User")
 
+#define CACHE_STATUS_HEAD               \
+  N_("The cache status of the object served")
+#define CACHE_STATUS_DESC               \
+  N_("Data sorted by hits [, avgts, cumts, maxts]")
+#define CACHE_STATUS_LABEL              \
+  N_("Cache Status")
+
 #define NOT_FOUND_HEAD                 \
   N_("Not Found URLs (404s)")
 #define NOT_FOUND_DESC                 \
@@ -250,12 +257,8 @@
   _("[UP/DOWN] to scroll - [q] to quit")
 
 /* Storage Built-in Option */
-#define BUILT_WITH_TCBTREE             \
-  _("Built using Tokyo Cabinet on-disk B+ Tree.")
-#define BUILT_WITH_TCMEMHASH           \
-  _("Built using Tokyo Cabinet in-memory hash database.")
 #define BUILT_WITH_DEFHASH             \
-  _("Built using the default in-memory hash database.")
+  _("In-Memory with On-Disk Persitance Storage.")
 
 /* Common UI Errors */
 #define ERR_FORMAT_HEADER              \
@@ -328,6 +331,8 @@
   N_("Horizontal")
 #define HTML_REPORT_NAV_VER            \
   N_("Vertical")
+#define HTML_REPORT_NAV_WIDE           \
+  N_("WideScreen")
 #define HTML_REPORT_NAV_FILE_OPTS      \
   N_("File Options")
 #define HTML_REPORT_NAV_EXPORT_JSON    \
@@ -441,6 +446,8 @@
   N_("416 - Requested Range Not Satisfiable: Cannot supply that portion")
 #define STATUS_CODE_417               \
   N_("417 - Expectation Failed")
+#define STATUS_CODE_418               \
+  N_("418 - I’m a teapot")
 #define STATUS_CODE_421               \
   N_("421 - Misdirected Request")
 #define STATUS_CODE_422               \
