@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,8 +33,7 @@
 #define OPESYS_TYPE_LEN  10
 
 /* Each OS contains the number of hits and the OS's type */
-typedef struct GOpeSys_
-{
+typedef struct GOpeSys_ {
   char os_type[OPESYS_TYPE_LEN];
   int hits;
 } GOpeSys;
