@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -38,11 +38,6 @@
 #include <getopt.h>
 #include <errno.h>
 
-#ifdef HAVE_LIBTOKYOCABINET
-#include "tcabdb.h"
-#include "tcbtdb.h"
-#endif
-
 #ifdef HAVE_LIBGEOIP
 #include <GeoIP.h>
 #endif
@@ -52,6 +47,7 @@
 #include "error.h"
 #include "labels.h"
 #include "util.h"
+
 #include "xmalloc.h"
 
 static char short_options[] = "f:e:p:o:l:H:M:S:b:"
@@ -84,55 +80,61 @@ struct option long_opts[] = {
   {"version"              , no_argument       , 0 , 'V' } ,
   {"with-mouse"           , no_argument       , 0 , 'm' } ,
   {"with-output-resolver" , no_argument       , 0 , 'd' } ,
-  {"444-as-404"           , no_argument       , 0 ,  0  } ,
-  {"4xx-to-unique-count"  , no_argument       , 0 ,  0  } ,
-  {"anonymize-ip"         , no_argument       , 0 ,  0  } ,
-  {"addr"                 , required_argument , 0 ,  0  } ,
-  {"all-static-files"     , no_argument       , 0 ,  0  } ,
-  {"color"                , required_argument , 0 ,  0  } ,
-  {"color-scheme"         , required_argument , 0 ,  0  } ,
-  {"crawlers-only"        , no_argument       , 0 ,  0  } ,
-  {"daemonize"            , no_argument       , 0 ,  0  } ,
-  {"date-format"          , required_argument , 0 ,  0  } ,
-  {"date-spec"            , required_argument , 0 ,  0  } ,
-  {"dcf"                  , no_argument       , 0 ,  0  } ,
-  {"double-decode"        , no_argument       , 0 ,  0  } ,
-  {"enable-panel"         , required_argument , 0 ,  0  } ,
-  {"fifo-in"              , required_argument , 0 ,  0  } ,
-  {"fifo-out"             , required_argument , 0 ,  0  } ,
-  {"hide-referer"         , required_argument , 0 ,  0  } ,
-  {"hour-spec"            , required_argument , 0 ,  0  } ,
-  {"html-custom-css"      , required_argument , 0 ,  0  } ,
-  {"html-custom-js"       , required_argument , 0 ,  0  } ,
-  {"html-prefs"           , required_argument , 0 ,  0  } ,
-  {"html-report-title"    , required_argument , 0 ,  0  } ,
-  {"ignore-crawlers"      , no_argument       , 0 ,  0  } ,
-  {"ignore-statics"       , required_argument , 0 ,  0  } ,
-  {"ignore-panel"         , required_argument , 0 ,  0  } ,
-  {"ignore-referer"       , required_argument , 0 ,  0  } ,
-  {"ignore-status"        , required_argument , 0 ,  0  } ,
-  {"invalid-requests"     , required_argument , 0 ,  0  } ,
-  {"json-pretty-print"    , no_argument       , 0 ,  0  } ,
-  {"log-format"           , required_argument , 0 ,  0  } ,
-  {"max-items"            , required_argument , 0 ,  0  } ,
-  {"no-color"             , no_argument       , 0 ,  0  } ,
-  {"no-column-names"      , no_argument       , 0 ,  0  } ,
-  {"no-csv-summary"       , no_argument       , 0 ,  0  } ,
-  {"no-global-config"     , no_argument       , 0 ,  0  } ,
-  {"no-html-last-updated" , no_argument       , 0 ,  0  } ,
-  {"no-parsing-spinner"   , no_argument       , 0 ,  0  } ,
-  {"no-progress"          , no_argument       , 0 ,  0  } ,
-  {"no-tab-scroll"        , no_argument       , 0 ,  0  } ,
-  {"num-tests"            , required_argument , 0 ,  0  } ,
-  {"origin"               , required_argument , 0 ,  0  } ,
-  {"output"               , required_argument , 0 ,  0  } ,
-  {"pid-file"             , required_argument , 0 ,  0  } ,
-  {"port"                 , required_argument , 0 ,  0  } ,
-  {"process-and-exit"     , no_argument       , 0 ,  0  } ,
-  {"real-os"              , no_argument       , 0 ,  0  } ,
-  {"real-time-html"       , no_argument       , 0 ,  0  } ,
-  {"sort-panel"           , required_argument , 0 ,  0  } ,
-  {"static-file"          , required_argument , 0 ,  0  } ,
+  {"444-as-404"           , no_argument       , 0 , 0  }  ,
+  {"4xx-to-unique-count"  , no_argument       , 0 , 0  }  ,
+  {"addr"                 , required_argument , 0 , 0  }  ,
+  {"all-static-files"     , no_argument       , 0 , 0  }  ,
+  {"anonymize-ip"         , no_argument       , 0 , 0  }  ,
+  {"color"                , required_argument , 0 , 0  }  ,
+  {"color-scheme"         , required_argument , 0 , 0  }  ,
+  {"crawlers-only"        , no_argument       , 0 , 0  }  ,
+  {"daemonize"            , no_argument       , 0 , 0  }  ,
+  {"date-format"          , required_argument , 0 , 0  }  ,
+  {"date-spec"            , required_argument , 0 , 0  }  ,
+  {"db-path"              , required_argument , 0 , 0  }  ,
+  {"dcf"                  , no_argument       , 0 , 0  }  ,
+  {"double-decode"        , no_argument       , 0 , 0  }  ,
+  {"enable-panel"         , required_argument , 0 , 0  }  ,
+  {"fifo-in"              , required_argument , 0 , 0  }  ,
+  {"fifo-out"             , required_argument , 0 , 0  }  ,
+  {"hide-referer"         , required_argument , 0 , 0  }  ,
+  {"hour-spec"            , required_argument , 0 , 0  }  ,
+  {"html-custom-css"      , required_argument , 0 , 0  }  ,
+  {"html-custom-js"       , required_argument , 0 , 0  }  ,
+  {"html-prefs"           , required_argument , 0 , 0  }  ,
+  {"html-report-title"    , required_argument , 0 , 0  }  ,
+  {"ignore-crawlers"      , no_argument       , 0 , 0  }  ,
+  {"ignore-panel"         , required_argument , 0 , 0  }  ,
+  {"ignore-referer"       , required_argument , 0 , 0  }  ,
+  {"ignore-statics"       , required_argument , 0 , 0  }  ,
+  {"ignore-status"        , required_argument , 0 , 0  }  ,
+  {"invalid-requests"     , required_argument , 0 , 0  }  ,
+  {"json-pretty-print"    , no_argument       , 0 , 0  }  ,
+  {"keep-last"            , required_argument , 0 , 0  }  ,
+  {"log-format"           , required_argument , 0 , 0  }  ,
+  {"max-items"            , required_argument , 0 , 0  }  ,
+  {"no-color"             , no_argument       , 0 , 0  }  ,
+  {"no-column-names"      , no_argument       , 0 , 0  }  ,
+  {"no-csv-summary"       , no_argument       , 0 , 0  }  ,
+  {"no-global-config"     , no_argument       , 0 , 0  }  ,
+  {"no-html-last-updated" , no_argument       , 0 , 0  }  ,
+  {"no-ip-validation"     , no_argument       , 0 , 0  }  ,
+  {"no-parsing-spinner"   , no_argument       , 0 , 0  }  ,
+  {"no-progress"          , no_argument       , 0 , 0  }  ,
+  {"no-tab-scroll"        , no_argument       , 0 , 0  }  ,
+  {"num-tests"            , required_argument , 0 , 0  }  ,
+  {"origin"               , required_argument , 0 , 0  }  ,
+  {"output"               , required_argument , 0 , 0  }  ,
+  {"persist"              , no_argument       , 0 , 0  }  ,
+  {"pid-file"             , required_argument , 0 , 0  }  ,
+  {"port"                 , required_argument , 0 , 0  }  ,
+  {"process-and-exit"     , no_argument       , 0 , 0  }  ,
+  {"real-os"              , no_argument       , 0 , 0  }  ,
+  {"real-time-html"       , no_argument       , 0 , 0  }  ,
+  {"restore"              , no_argument       , 0 , 0  }  ,
+  {"sort-panel"           , required_argument , 0 , 0  }  ,
+  {"static-file"          , required_argument , 0 , 0  }  ,
+  {"user-name"            , required_argument , 0 , 0  }  ,
 #ifdef HAVE_LIBSSL
   {"ssl-cert"             , required_argument , 0 ,  0  } ,
   {"ssl-key"              , required_argument , 0 ,  0  } ,
@@ -141,22 +143,6 @@ struct option long_opts[] = {
   {"ws-url"               , required_argument , 0 ,  0  } ,
 #ifdef HAVE_GEOLOCATION
   {"geoip-database"       , required_argument , 0 ,  0  } ,
-#endif
-#ifdef HAVE_LIBGEOIP
-  {"geoip-city-data"      , required_argument , 0 ,  0  } ,
-#endif
-#ifdef TCB_BTREE
-  {"accumulated-time"     , no_argument       , 0 ,  0  } ,
-  {"cache-lcnum"          , required_argument , 0 ,  0  } ,
-  {"cache-ncnum"          , required_argument , 0 ,  0  } ,
-  {"compression"          , required_argument , 0 ,  0  } ,
-  {"db-path"              , required_argument , 0 ,  0  } ,
-  {"keep-db-files"        , no_argument       , 0 ,  0  } ,
-  {"load-from-disk"       , no_argument       , 0 ,  0  } ,
-  {"tune-bnum"            , required_argument , 0 ,  0  } ,
-  {"tune-lmemb"           , required_argument , 0 ,  0  } ,
-  {"tune-nmemb"           , required_argument , 0 ,  0  } ,
-  {"xmmap"                , required_argument , 0 ,  0  } ,
 #endif
   {0, 0, 0, 0}
 };
@@ -173,27 +159,24 @@ cmd_help (void)
 
   printf (
   /* Log & Date Format Options */
-  "Log & Date Format Options\n\n"
+  CYN "LOG & DATE FORMAT OPTIONS\n\n" RESET
   "  --date-format=<dateformat>      - Specify log date format. e.g., %%d/%%b/%%Y\n"
-  "  --log-format=<logformat>        - Specify log format. Inner quotes need to be\n"
-  "                                    escaped, or use single quotes.\n"
+  "  --log-format=<logformat>        - Specify log format. Inner quotes need escaping, or use single quotes.\n"
   "  --time-format=<timeformat>      - Specify log time format. e.g., %%H:%%M:%%S\n\n"
-
+  "\n"
   /* User Interface Options */
-  "User Interface Options\n\n"
+  CYN "USER INTERFACE OPTIONS\n\n" RESET
   "  -c --config-dialog              - Prompt log/date/time configuration window.\n"
   "  -i --hl-header                  - Color highlight active panel.\n"
   "  -m --with-mouse                 - Enable mouse support on main dashboard.\n"
-  "  --color=<fg:bg[attrs, PANEL]>   - Specify custom colors. See manpage for more\n"
-  "                                    details and options.\n"
+  "  --color=<fg:bg[attrs, PANEL]>   - Specify custom colors. See manpage for more details.\n"
   "  --color-scheme=<1|2|3>          - Schemes: 1 => Grey, 2 => Green, 3 => Monokai.\n"
   "  --html-custom-css=<path.css>    - Specify a custom CSS file in the HTML report.\n"
   "  --html-custom-js=<path.js>      - Specify a custom JS file in the HTML report.\n"
   "  --html-prefs=<json_obj>         - Set default HTML report preferences.\n"
   "  --html-report-title=<title>     - Set HTML report page title and header.\n"
   "  --json-pretty-print             - Format JSON output w/ tabs & newlines.\n"
-  "  --max-items                     - Maximum number of items to show per panel.\n"
-  "                                    See man page for limits.\n"
+  "  --max-items                     - Maximum number of items to show per panel. See man page for limits.\n"
   "  --no-color                      - Disable colored output.\n"
   "  --no-column-names               - Don't write column names in term output.\n"
   "  --no-csv-summary                - Disable summary metrics on the CSV output.\n"
@@ -202,139 +185,100 @@ cmd_help (void)
   "  --no-progress                   - Disable progress metrics.\n"
   "  --no-tab-scroll                 - Disable scrolling through panels on TAB.\n"
   "\n"
-
+  ""
   /* Server Options */
-  "Server Options\n\n"
+  CYN "SERVER OPTIONS\n\n" RESET
   "  --addr=<addr>                   - Specify IP address to bind server to.\n"
   "  --daemonize                     - Run as daemon (if --real-time-html enabled).\n"
   "  --fifo-in=<path>                - Path to read named pipe (FIFO).\n"
   "  --fifo-out=<path>               - Path to write named pipe (FIFO).\n"
-  "  --origin=<addr>                 - Ensure clients send the specified origin header\n"
-  "                                    upon the WebSocket handshake.\n"
+  "  --origin=<addr>                 - Ensure clients send this origin header upon the WebSocket handshake.\n"
   "  --pid-file=<path>               - Write PID to a file when --daemonize is used.\n"
   "  --port=<port>                   - Specify the port to use.\n"
   "  --real-time-html                - Enable real-time HTML output.\n"
   "  --ssl-cert=<cert.crt>           - Path to TLS/SSL certificate.\n"
   "  --ssl-key=<priv.key>            - Path to TLS/SSL private key.\n"
+  "  --user-name=<username>          - Run as the specified user.\n"
   "  --ws-url=<url>                  - URL to which the WebSocket server responds.\n"
   "\n"
-
+  ""
   /* File Options */
-  "File Options\n\n"
+  CYN "FILE OPTIONS\n\n" RESET
   "  -                               - The log file to parse is read from stdin.\n"
   "  -f --log-file=<filename>        - Path to input log file.\n"
-  "  -S --log-size=<number>          - Specify the log size, useful when piping in logs.\n"
-  "  -l --debug-file=<filename>      - Send all debug messages to the specified\n"
-  "                                    file.\n"
+  "  -l --debug-file=<filename>      - Send all debug messages to the specified file.\n"
   "  -p --config-file=<filename>     - Custom configuration file.\n"
+  "  -S --log-size=<number>          - Specify the log size, useful when piping in logs.\n"
   "  --invalid-requests=<filename>   - Log invalid requests to the specified file.\n"
   "  --no-global-config              - Don't load global configuration file.\n"
   "\n"
-
+  ""
   /* Parse Options */
-  "Parse Options\n\n"
+  CYN "PARSE OPTIONS\n\n" RESET
   "  -a --agent-list                 - Enable a list of user-agents by host.\n"
   "  -b --browsers-file=<path>       - Use additional custom list of browsers.\n"
   "  -d --with-output-resolver       - Enable IP resolver on HTML|JSON output.\n"
-  "  -e --exclude-ip=<IP>            - Exclude one or multiple IPv4/6. Allows IP\n"
-  "                                    ranges e.g. 192.168.0.1-192.168.0.10\n"
+  "  -e --exclude-ip=<IP>            - Exclude one or multiple IPv4/6. Allows IP ranges\n"
+  "                                    e.g. 192.168.0.1-192.168.0.10\n"
   "  -H --http-protocol=<yes|no>     - Set/unset HTTP request protocol if found.\n"
   "  -M --http-method=<yes|no>       - Set/unset HTTP request method if found.\n"
   "  -o --output=file.html|json|csv  - Output either an HTML, JSON or a CSV file.\n"
-  "  -q --no-query-string            - Ignore request's query string. Removing the\n"
-  "                                    query string can greatly decrease memory\n"
-  "                                    consumption.\n"
+  "  -q --no-query-string            - Strip request's query string. This can decrease memory consumption.\n"
   "  -r --no-term-resolver           - Disable IP resolver on terminal output.\n"
   "  --444-as-404                    - Treat non-standard status code 444 as 404.\n"
-  "  --4xx-to-unique-count           - Add 4xx client errors to the unique visitors\n"
-  "                                    count.\n"
-#ifdef TCB_BTREE
-  "  --accumulated-time              - Store accumulated time from parsing day-by-day logs.\n"
-#endif
-  "  --anonymize-ip                  - Anonymize IP addresses before outputting to report.\n"
+  "  --4xx-to-unique-count           - Add 4xx client errors to the unique visitors count.\n"
   "  --all-static-files              - Include static files with a query string.\n"
+  "  --anonymize-ip                  - Anonymize IP addresses before outputting to report.\n"
   "  --crawlers-only                 - Parse and display only crawlers.\n"
-  "  --date-spec=<date|hr>           - Date specificity. Possible values: `date`\n"
-  "                                    (default), or `hr`.\n"
+  "  --date-spec=<date|hr>           - Date specificity. Possible values: `date` (default), or `hr`.\n"
   "  --double-decode                 - Decode double-encoded values.\n"
   "  --enable-panel=<PANEL>          - Enable parsing/displaying the given panel.\n"
-  "  --hide-referer=<NEEDLE>         - Hide a referer but still count it. Wild cards\n"
-  "                                    are allowed. i.e., *.bing.com\n"
-  "  --hour-spec=<hr|min>            - Hour specificity. Possible values: `hr`\n"
-  "                                    (default), or `min` (tenth of a min).\n"
+  "  --hide-referer=<NEEDLE>         - Hide a referer but still count it. Wild cards are allowed.\n"
+  "                                    i.e., *.bing.com\n"
+  "  --hour-spec=<hr|min>            - Hour specificity. Possible values: `hr` (default),\n"
+  "                                    or `min` (tenth of a min).\n"
   "  --ignore-crawlers               - Ignore crawlers.\n"
   "  --ignore-panel=<PANEL>          - Ignore parsing/displaying the given panel.\n"
-  "  --ignore-referer=<NEEDLE>       - Ignore a referer from being counted. Wild cards\n"
-  "                                    are allowed. i.e., *.bing.com\n"
+  "  --ignore-referer=<NEEDLE>       - Ignore a referer from being counted. Wild cards are allowed.\n"
+  "                                    i.e., *.bing.com\n"
   "  --ignore-statics=<req|panel>    - Ignore static requests.\n"
   "                                    req => Ignore from valid requests.\n"
   "                                    panel => Ignore from valid requests and panels.\n"
   "  --ignore-status=<CODE>          - Ignore parsing the given status code.\n"
+  "  --keep-last=<NDAYS>             - Keep the last NDAYS in storage.\n"
   "  --num-tests=<number>            - Number of lines to test. >= 0 (10 default)\n"
+  "  --persist                       - Persist data to disk on exit to the given --db-path or to /tmp.\n"
   "  --process-and-exit              - Parse log and exit without outputting data.\n"
-  "  --real-os                       - Display real OS names. e.g, Windows XP, Snow\n"
-  "                                    Leopard.\n"
-  "  --sort-panel=PANEL,METRIC,ORDER - Sort panel on initial load. For example:\n"
-  "                                    --sort-panel=VISITORS,BY_HITS,ASC. See\n"
-  "                                    manpage for a list of panels/fields.\n"
-  "  --static-file=<extension>       - Add static file extension. e.g.: .mp3.\n"
-  "                                    Extensions are case sensitive.\n"
+  "  --real-os                       - Display real OS names. e.g, Windows XP, Snow Leopard.\n"
+  "  --restore                       - Restore data from disk from the given --db-path or from /tmp.\n"
+  "  --sort-panel=PANEL,METRIC,ORDER - Sort panel on initial load. e.g., --sort-panel=VISITORS,BY_HITS,ASC.\n"
+  "                                    See manpage for a list of panels/fields.\n"
+  "  --static-file=<extension>       - Add static file extension. e.g.: .mp3. Extensions are case sensitive.\n"
   "\n"
 
 /* GeoIP Options */
 #ifdef HAVE_GEOLOCATION
-  "GeoIP Options\n\n"
+  CYN "GEOIP OPTIONS\n\n" RESET
 #ifdef HAVE_LIBGEOIP
-  "  -g --std-geoip                  - Standard GeoIP database for less memory\n"
-  "                                    consumption.\n"
+  "  -g --std-geoip                  - Standard GeoIP database for less memory consumption.\n"
 #endif
-  "  --geoip-database=<path>         - Specify path to GeoIP database file. i.e.,\n"
-  "                                    GeoLiteCity.dat, GeoIPv6.dat ...\n"
+  "  --geoip-database=<path>         - Specify path to GeoIP database file.\n"
+  "                                    i.e., GeoLiteCity.dat, GeoIPv6.dat ...\n"
   "\n"
 #endif
 
-/* On-Disk Database Options */
-#ifdef TCB_BTREE
-  "On-Disk Database Options\n\n"
-  "  --keep-db-files                 - Persist parsed data into disk.\n"
-  "  --load-from-disk                - Load previously stored data from disk.\n"
-  "  --db-path=<path>                - Path of the database file. Default [%s]\n"
-  "  --cache-lcnum=<number>          - Max number of leaf nodes to be cached. Default\n"
-  "                                    [%d]\n"
-  "  --cache-ncnum=<number>          - Max number of non-leaf nodes to be cached.\n"
-  "                                    Default [%d]\n"
-  "  --tune-bnum=<number>            - Number of elements of the bucket array. Default\n"
-  "                                    [%d]\n"
-  "  --tune-lmemb=<number>           - Number of members in each leaf page. Default\n"
-  "                                    [%d]\n"
-  "  --tune-nmemb=<number>           - Number of members in each non-leaf page.\n"
-  "                                    Default [%d]\n"
-  "  --xmmap=<number>                - Set the size in bytes of the extra mapped\n"
-  "                                    memory. Default [%d]\n"
-#if defined(HAVE_ZLIB) || defined(HAVE_BZ2)
-  "  --compression=<zlib|bz2>        - Specifies that each page is compressed with\n"
-  "                                    ZLIB|BZ2 encoding.\n"
-  "\n"
-#endif
-#endif
-
 /* Other Options */
-  "Other Options\n\n"
+  CYN "OTHER OPTIONS\n\n" RESET
   "  -h --help                       - This help.\n"
+  "  -s --storage                    - Display current storage method. e.g., Hash.\n"
   "  -V --version                    - Display version information and exit.\n"
-  "  -s --storage                    - Display current storage method. e.g., B+\n"
-  "                                    Tree, Hash.\n"
-  "  --dcf                           - Display the path of the default config\n"
-  "                                    file when `-p` is not used.\n"
+  "  --dcf                           - Display the path of the default config file when `-p` is not used.\n"
   "\n"
 
   "%s `man goaccess`.\n\n"
   "%s: http://goaccess.io\n"
   "GoAccess Copyright (C) 2009-2017 by Gerardo Orellana"
   "\n\n"
-#ifdef TCB_BTREE
-  , TC_DBPATH, TC_MMAP, TC_LCNUM, TC_NCNUM, TC_LMEMB, TC_NMEMB, TC_BNUM
-#endif
   , INFO_HELP_EXAMPLES, INFO_MORE_INFO
   );
   exit (EXIT_FAILURE);
@@ -344,16 +288,14 @@ cmd_help (void)
 /* Push a command line option to the given array if within bounds and if it's
  * not in the array. */
 static void
-set_array_opt (const char *oarg, const char *arr[], int *size, int max)
-{
+set_array_opt (const char *oarg, const char *arr[], int *size, int max) {
   if (str_inarray (oarg, arr, *size) < 0 && *size < max)
     arr[(*size)++] = oarg;
 }
 
 /* Parse command line long options. */
 static void
-parse_long_opt (const char *name, const char *oarg)
-{
+parse_long_opt (const char *name, const char *oarg) {
   if (!strcmp ("no-global-config", name))
     return;
 
@@ -457,6 +399,9 @@ parse_long_opt (const char *name, const char *oarg)
   if (!strcmp ("daemonize", name))
     conf.daemonize = 1;
 
+  if (!strcmp ("user-name", name))
+    conf.username = oarg;
+
   /* WebSocket origin */
   if (!strcmp ("origin", name))
     conf.origin = oarg;
@@ -478,6 +423,14 @@ parse_long_opt (const char *name, const char *oarg)
   if (!strcmp ("real-time-html", name))
     conf.real_time_html = 1;
 
+  /* persist data to disk */
+  if (!strcmp ("persist", name))
+    conf.persist = 1;
+
+  /* restore data from disk */
+  if (!strcmp ("restore", name))
+    conf.restore = 1;
+
   /* TLS/SSL certificate */
   if (!strcmp ("ssl-cert", name))
     conf.sslcert = oarg;
@@ -500,8 +453,7 @@ parse_long_opt (const char *name, const char *oarg)
 
   /* output file */
   if (!strcmp ("output", name))
-    set_array_opt (oarg, conf.output_formats, &conf.output_format_idx,
-                   MAX_OUTFORMATS);
+    set_array_opt (oarg, conf.output_formats, &conf.output_format_idx, MAX_OUTFORMATS);
 
   /* PARSE OPTIONS
    * ========================= */
@@ -517,10 +469,6 @@ parse_long_opt (const char *name, const char *oarg)
   if (!strcmp ("anonymize-ip", name))
     conf.anonymize_ip = 1;
 
-  /* store accumulated time in tcb */
-  if (!strcmp ("accumulated-time", name))
-    conf.store_accumulated_time = 1;
-
   /* all static files */
   if (!strcmp ("all-static-files", name))
     conf.all_static_files = 1;
@@ -539,8 +487,7 @@ parse_long_opt (const char *name, const char *oarg)
 
   /* enable panel */
   if (!strcmp ("enable-panel", name))
-    set_array_opt (oarg, conf.enable_panels, &conf.enable_panel_idx,
-                   TOTAL_MODULES);
+    set_array_opt (oarg, conf.enable_panels, &conf.enable_panel_idx, TOTAL_MODULES);
 
   /* hour specificity */
   if (!strcmp ("hour-spec", name) && !strcmp (oarg, "min"))
@@ -552,23 +499,23 @@ parse_long_opt (const char *name, const char *oarg)
 
   /* ignore panel */
   if (!strcmp ("ignore-panel", name))
-    set_array_opt (oarg, conf.ignore_panels, &conf.ignore_panel_idx,
-                   TOTAL_MODULES);
+    set_array_opt (oarg, conf.ignore_panels, &conf.ignore_panel_idx, TOTAL_MODULES);
 
   /* ignore referer */
   if (!strcmp ("ignore-referer", name))
-    set_array_opt (oarg, conf.ignore_referers, &conf.ignore_referer_idx,
-                   MAX_IGNORE_REF);
+    set_array_opt (oarg, conf.ignore_referers, &conf.ignore_referer_idx, MAX_IGNORE_REF);
+
+  /* client IP validation */
+  if (!strcmp ("no-ip-validation", name))
+    conf.no_ip_validation = 1;
 
   /* hide referer from report (e.g. within same site) */
   if (!strcmp ("hide-referer", name))
-    set_array_opt (oarg, conf.hide_referers, &conf.hide_referer_idx,
-                   MAX_IGNORE_REF);
+    set_array_opt (oarg, conf.hide_referers, &conf.hide_referer_idx, MAX_IGNORE_REF);
 
   /* ignore status code */
   if (!strcmp ("ignore-status", name))
-    set_array_opt (oarg, conf.ignore_status, &conf.ignore_status_idx,
-                   MAX_IGNORE_STATUS);
+    set_array_opt (oarg, conf.ignore_status, &conf.ignore_status_idx, MAX_IGNORE_STATUS);
 
   /* ignore static requests */
   if (!strcmp ("ignore-statics", name)) {
@@ -589,6 +536,19 @@ parse_long_opt (const char *name, const char *oarg)
     conf.num_tests = tests >= 0 ? tests : 0;
   }
 
+  /* number of days to keep in storage */
+  if (!strcmp ("keep-last", name)) {
+    char *sEnd;
+    int keeplast = strtol (oarg, &sEnd, 10);
+    if (oarg == sEnd || *sEnd != '\0' || errno == ERANGE)
+      return;
+    conf.keep_last = keeplast >= 0 ? keeplast : 0;
+  }
+
+  /* specifies the path of the database file */
+  if (!strcmp ("db-path", name))
+    conf.db_path = oarg;
+
   /* process and exit */
   if (!strcmp ("process-and-exit", name))
     conf.process_and_exit = 1;
@@ -605,66 +565,15 @@ parse_long_opt (const char *name, const char *oarg)
   if (!strcmp ("static-file", name) && conf.static_file_idx < MAX_EXTENSIONS) {
     if (conf.static_file_max_len < strlen (oarg))
       conf.static_file_max_len = strlen (oarg);
-    set_array_opt (oarg, conf.static_files, &conf.static_file_idx,
-                   MAX_EXTENSIONS);
+    set_array_opt (oarg, conf.static_files, &conf.static_file_idx, MAX_EXTENSIONS);
   }
 
   /* GEOIP OPTIONS
    * ========================= */
   /* specifies the path of the GeoIP City database file */
-  if (!strcmp ("geoip-city-data", name) || !strcmp ("geoip-database", name))
+  if (!strcmp ("geoip-database", name))
     conf.geoip_database = oarg;
 
-  /* BTREE OPTIONS
-   * ========================= */
-  /* keep database files */
-  if (!strcmp ("keep-db-files", name))
-    conf.keep_db_files = 1;
-
-  /* load data from disk */
-  if (!strcmp ("load-from-disk", name))
-    conf.load_from_disk = 1;
-
-  /* specifies the path of the database file */
-  if (!strcmp ("db-path", name))
-    conf.db_path = oarg;
-
-  /* specifies the maximum number of leaf nodes to be cached */
-  if (!strcmp ("cache-lcnum", name))
-    conf.cache_lcnum = atoi (oarg);
-
-  /* specifies the maximum number of non-leaf nodes to be cached */
-  if (!strcmp ("cache-ncnum", name))
-    conf.cache_ncnum = atoi (oarg);
-
-  /* number of elements of the bucket array */
-  if (!strcmp ("tune-bnum", name))
-    conf.tune_bnum = atoi (oarg);
-
-  /* number of members in each non-leaf page */
-  if (!strcmp ("tune-nmemb", name))
-    conf.tune_nmemb = atoi (oarg);
-
-  /* number of members in each leaf page */
-  if (!strcmp ("tune-lmemb", name))
-    conf.tune_lmemb = atoi (oarg);
-
-  /* set the size in bytes of the extra mapped memory */
-  if (!strcmp ("xmmap", name))
-    conf.xmmap = atoi (oarg);
-
-  /* specifies that each page is compressed with X encoding */
-  if (!strcmp ("compression", name)) {
-#ifdef HAVE_ZLIB
-    if (!strcmp ("zlib", oarg))
-      conf.compression = TC_ZLIB;
-#endif
-#ifdef HAVE_BZ2
-    if (!strcmp ("bz2", oarg))
-      conf.compression = TC_BZ2;
-#endif
-  }
-
   /* default config file --dwf */
   if (!strcmp ("dcf", name)) {
     display_default_config_file ();
@@ -675,8 +584,7 @@ parse_long_opt (const char *name, const char *oarg)
 /* Determine if the '--no-global-config' command line option needs to be
  * enabled or not. */
 void
-verify_global_config (int argc, char **argv)
-{
+verify_global_config (int argc, char **argv) {
   int o, idx = 0;
 
   conf.load_global_config = 1;
@@ -703,8 +611,7 @@ verify_global_config (int argc, char **argv)
 
 /* Attempt to add - to the array of filenames if it hasn't been added it yet. */
 void
-add_dash_filename (void)
-{
+add_dash_filename (void) {
   int i;
   // pre-scan for '-' and don't add if already exists: github.com/allinurl/goaccess/issues/907
   for (i = 0; i < conf.filenames_idx; ++i) {
@@ -720,8 +627,7 @@ add_dash_filename (void)
 
 /* Read the user's supplied command line options. */
 void
-read_option_args (int argc, char **argv)
-{
+read_option_args (int argc, char **argv) {
   int o, idx = 0;
 
 #ifdef HAVE_LIBGEOIP
