@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -40,13 +40,8 @@
 
 #include "output.h"
 
-#ifdef HAVE_LIBTOKYOCABINET
-#include "tcabdb.h"
-#else
-#include "gkhash.h"
-#endif
-
 #include "error.h"
+#include "gkhash.h"
 #include "gwsocket.h"
 #include "json.h"
 #include "settings.h"
@@ -74,65 +69,69 @@ static void print_host_metrics (FILE * fp, const GHTML * def, int sp);
 /* *INDENT-OFF* */
 static GHTML htmldef[] = {
   {VISITORS, 1, print_metrics, {
-    {CHART_AREASPLINE, hits_visitors_plot, 1, 1} ,
-    {CHART_AREASPLINE, hits_bw_plot, 1, 1} ,
+    {CHART_AREASPLINE, hits_visitors_plot, 1, 1, NULL, NULL} ,
+    {CHART_AREASPLINE, hits_bw_plot, 1, 1, NULL, NULL} ,
   }},
   {REQUESTS, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_req_plot, 0, 0},
-    {CHART_VBAR, hits_bw_req_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_req_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_req_plot, 0, 0, NULL, NULL},
   }},
   {REQUESTS_STATIC, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_req_plot, 0, 0},
-    {CHART_VBAR, hits_bw_req_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_req_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_req_plot, 0, 0, NULL, NULL},
   }},
   {NOT_FOUND, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_req_plot, 0, 0},
-    {CHART_VBAR, hits_bw_req_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_req_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_req_plot, 0, 0, NULL, NULL},
   }},
   {HOSTS, 1, print_host_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 0},
-    {CHART_VBAR, hits_bw_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 0, NULL, NULL},
   }},
   {OS, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 1},
-    {CHART_VBAR, hits_bw_plot, 0, 1},
+    {CHART_VBAR, hits_visitors_plot, 0, 1, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 1, NULL, NULL},
   }},
   {BROWSERS, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 1},
-    {CHART_VBAR, hits_bw_plot, 0, 1},
+    {CHART_VBAR, hits_visitors_plot, 0, 1, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 1, NULL, NULL},
   }},
   {VISIT_TIMES, 1, print_metrics, {
-    {CHART_AREASPLINE, hits_visitors_plot, 0, 1},
-    {CHART_AREASPLINE, hits_bw_plot, 0, 1},
+    {CHART_AREASPLINE, hits_visitors_plot, 0, 1, NULL, NULL},
+    {CHART_AREASPLINE, hits_bw_plot, 0, 1, NULL, NULL},
   }},
   {VIRTUAL_HOSTS, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 0},
-    {CHART_VBAR, hits_bw_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 0, NULL, NULL},
   }},
   {REFERRERS, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 0},
-    {CHART_VBAR, hits_bw_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 0, NULL, NULL},
   }},
   {REFERRING_SITES, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 0},
-    {CHART_VBAR, hits_bw_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 0, NULL, NULL},
   }},
   {KEYPHRASES, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 0},
-    {CHART_VBAR, hits_bw_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 0, NULL, NULL},
   }},
   {STATUS_CODES, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 1},
-    {CHART_VBAR, hits_bw_plot, 0, 1},
+    {CHART_VBAR, hits_visitors_plot, 0, 1, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 1, NULL, NULL},
   }},
   {REMOTE_USER, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 0},
-    {CHART_VBAR, hits_bw_plot, 0, 0},
+    {CHART_VBAR, hits_visitors_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 0, NULL, NULL},
+  }},
+  {CACHE_STATUS, 1, print_metrics, {
+    {CHART_VBAR, hits_visitors_plot, 0, 0, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 0, NULL, NULL},
   }},
 #ifdef HAVE_GEOLOCATION
   {GEO_LOCATION, 1, print_metrics, {
-    {CHART_VBAR, hits_visitors_plot, 0, 1},
-    {CHART_VBAR, hits_bw_plot, 0, 1},
+    {CHART_VBAR, hits_visitors_plot, 0, 1, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 1, NULL, NULL},
   }},
 #endif
 };
@@ -145,8 +144,7 @@ static int nlines = 0;
  *
  * On success, the chart type string is returned. */
 static const char *
-chart2str (GChartType type)
-{
+chart2str (GChartType type) {
   static const char *strings[] = { "null", "bar", "area-spline" };
   return strings[type];
 }
@@ -156,8 +154,7 @@ chart2str (GChartType type)
  * If not found, NULL is returned.
  * On success, panel data is returned . */
 static GHTML *
-panel_lookup (GModule module)
-{
+panel_lookup (GModule module) {
   int i, num_panels = ARRAY_SIZE (htmldef);
 
   for (i = 0; i < num_panels; i++) {
@@ -169,8 +166,7 @@ panel_lookup (GModule module)
 
 /* Sanitize output with html entities for special chars */
 static void
-clean_output (FILE * fp, char *s)
-{
+clean_output (FILE * fp, const char *s) {
   if (!s) {
     LOG_DEBUG (("NULL data on clean_output.\n"));
     return;
@@ -206,13 +202,11 @@ clean_output (FILE * fp, char *s)
 
 /* Set the HTML document title and the generated date/time */
 static void
-print_html_title (FILE * fp)
-{
-  const char *title =
-    conf.html_report_title ? conf.html_report_title : HTML_REPORT_TITLE;
+print_html_title (FILE * fp) {
+  const char *title = conf.html_report_title ? conf.html_report_title : HTML_REPORT_TITLE;
 
   fprintf (fp, "<title>");
-  clean_output (fp, (char *) title);
+  clean_output (fp, title);
   fprintf (fp, "</title>");
 }
 
@@ -232,11 +226,21 @@ print_html_header (FILE * fp)
   "<meta name='viewport' content='width=device-width, initial-scale=1'>"
   "<meta name='robots' content='noindex, nofollow'>", _(DOC_LANG));
 
+  /* Output base64 encoded goaccess favicon.ico*/
+  fprintf (fp, "<link rel='icon' href='data:image/x-icon;base64,AAABAAEA"
+  "EBAQAAEABAAoAQAAFgAAACgAAAAQAAAAIAAAAAEABAAAAAAAgAAAAAAAAAAAAAAAEAAAA"
+  "AAAAADGxsYAWFhYABwcHABfAP8A/9dfAADXrwAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
+  "AAAAAAAAAAAAAAAAAAAAAAIiIiIiIiIiIjMlUkQgAiIiIiIiIiIiIiIzJVJEIAAAIiIiI"
+  "iIiIiIiMyVSRCAAIiIiIiIiIiIiIRERERERERERERERERERERIiIiIiIiIiIgACVVUiIi"
+  "IiIiIiIiIiIiIAAlVVIiIiIiIiIiIiIiIhEREREREREREREREREREREAAAAAAAAAAAAAA"
+  "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
+  "AA' type='image/x-icon' />");
+
   print_html_title (fp);
 
-  fprintf (fp, "<style>%s</style>", fa_css);
-  fprintf (fp, "<style>%s</style>", bootstrap_css);
-  fprintf (fp, "<style>%s</style>", app_css);
+  fprintf (fp, "<style>%.*s</style>", fa_css_length, fa_css);
+  fprintf (fp, "<style>%.*s</style>", bootstrap_css_length, bootstrap_css);
+  fprintf (fp, "<style>%.*s</style>", app_css_length, app_css);
   /* load custom CSS file, if any */
   if (conf.html_custom_css)
     fprintf (fp, "<link rel='stylesheet' href='%s'>", conf.html_custom_css);
@@ -268,7 +272,7 @@ print_html_body (FILE * fp, const char *now)
   "</span>"
   "</h4>"
   "</div>"
-  "<h1>"
+  "<h1 class='h-dashboard'>"
   "<span class='hidden-xs hidden-sm'>"
   "<i class='fa fa-tachometer'></i> %s"
   "</span>"
@@ -288,7 +292,7 @@ print_html_body (FILE * fp, const char *now)
   "<div class='wrap-panels'></div>"
   "</div>", conf.html_report_title ? conf.html_report_title : "");
 
-  fprintf (fp, "%s", tpls);
+  fprintf (fp, "%.*s", tpls_length, tpls);
 }
 
 /* Output all the document footer elements such as script and closing
@@ -296,10 +300,10 @@ print_html_body (FILE * fp, const char *now)
 static void
 print_html_footer (FILE * fp)
 {
-  fprintf (fp, "<script>%s</script>", d3_js);
-  fprintf (fp, "<script>%s</script>", hogan_js);
-  fprintf (fp, "<script>%s</script>", app_js);
-  fprintf (fp, "<script>%s</script>", charts_js);
+  fprintf (fp, "<script>%.*s</script>", d3_js_length, d3_js);
+  fprintf (fp, "<script>%.*s</script>", hogan_js_length, hogan_js);
+  fprintf (fp, "<script>%.*s</script>", app_js_length, app_js);
+  fprintf (fp, "<script>%.*s</script>", charts_js_length, charts_js);
 
   /* load custom JS file, if any */
   if (conf.html_custom_js)
@@ -316,8 +320,7 @@ static const GChartDef ChartDefStopper = { NULL, NULL };
  *
  * The number of chart definitions is returned . */
 static int
-get_chartdef_cnt (GChart * chart)
-{
+get_chartdef_cnt (GChart * chart) {
   GChartDef *def = chart->def;
 
   while (memcmp (def, &ChartDefStopper, sizeof ChartDefStopper))
@@ -328,8 +331,7 @@ get_chartdef_cnt (GChart * chart)
 
 /* Output the given JSON chart axis definition for the given panel. */
 static void
-print_d3_chart_def_axis (FILE * fp, GChart * chart, size_t cnt, int isp)
-{
+print_d3_chart_def_axis (FILE * fp, GChart * chart, size_t cnt, int isp) {
   GChartDef *def = chart->def;
   size_t j = 0;
 
@@ -343,8 +345,7 @@ print_d3_chart_def_axis (FILE * fp, GChart * chart, size_t cnt, int isp)
 
 /* Output the given JSON chart definition for the given panel. */
 static void
-print_d3_chart_def (FILE * fp, GChart * chart, size_t n, int sp)
-{
+print_d3_chart_def (FILE * fp, GChart * chart, size_t n, int sp) {
   size_t i = 0, cnt = 0;
   int isp = 0;
 
@@ -362,8 +363,7 @@ print_d3_chart_def (FILE * fp, GChart * chart, size_t n, int sp)
 }
 
 static void
-print_plot_def (FILE * fp, const GHTMLPlot plot, GChart * chart, int n, int sp)
-{
+print_plot_def (FILE * fp, const GHTMLPlot plot, GChart * chart, int n, int sp) {
   int isp = 0, iisp = 0;
 
   /* use tabs to prettify output */
@@ -386,8 +386,7 @@ print_plot_def (FILE * fp, const GHTMLPlot plot, GChart * chart, int n, int sp)
 
 /* Output D3.js hits/visitors plot definitions. */
 static void
-hits_visitors_plot (FILE * fp, GHTMLPlot plot, int sp)
-{
+hits_visitors_plot (FILE * fp, GHTMLPlot plot, int sp) {
   /* *INDENT-OFF* */
   GChart def[] = {
     {"y0", (GChartDef[]) {
@@ -406,8 +405,7 @@ hits_visitors_plot (FILE * fp, GHTMLPlot plot, int sp)
 
 /* Output D3.js hits/visitors plot definitions. */
 static void
-hits_visitors_req_plot (FILE * fp, GHTMLPlot plot, int sp)
-{
+hits_visitors_req_plot (FILE * fp, GHTMLPlot plot, int sp) {
   /* *INDENT-OFF* */
   GChart def[] = {
     {"x", (GChartDef[]) {
@@ -429,8 +427,7 @@ hits_visitors_req_plot (FILE * fp, GHTMLPlot plot, int sp)
 
 /* Output C3.js bandwidth plot definitions. */
 static void
-hits_bw_plot (FILE * fp, GHTMLPlot plot, int sp)
-{
+hits_bw_plot (FILE * fp, GHTMLPlot plot, int sp) {
   /* *INDENT-OFF* */
   GChart def[] = {
     {"y0", (GChartDef[]) {
@@ -449,8 +446,7 @@ hits_bw_plot (FILE * fp, GHTMLPlot plot, int sp)
 
 /* Output C3.js bandwidth plot definitions. */
 static void
-hits_bw_req_plot (FILE * fp, GHTMLPlot plot, int sp)
-{
+hits_bw_req_plot (FILE * fp, GHTMLPlot plot, int sp) {
   /* *INDENT-OFF* */
   GChart def[] = {
     {"x", (GChartDef[]) {
@@ -472,11 +468,10 @@ hits_bw_req_plot (FILE * fp, GHTMLPlot plot, int sp)
 
 /* Output JSON data definitions. */
 static void
-print_json_data (FILE * fp, GLog * glog, GHolder * holder)
-{
+print_json_data (FILE * fp, GHolder * holder) {
   char *json = NULL;
 
-  if ((json = get_json (glog, holder, 1)) == NULL)
+  if ((json = get_json (holder, 1)) == NULL)
     return;
 
   fprintf (fp, "<script type='text/javascript'>");
@@ -488,8 +483,7 @@ print_json_data (FILE * fp, GLog * glog, GHolder * holder)
 
 /* Output WebSocket connection definition. */
 static void
-print_conn_def (FILE * fp)
-{
+print_conn_def (FILE * fp) {
   int sp = 0;
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -511,8 +505,7 @@ print_conn_def (FILE * fp)
 
 /* Output JSON per panel metric definitions. */
 static void
-print_def_metric (FILE * fp, const GDefMetric def, int sp)
-{
+print_def_metric (FILE * fp, const GDefMetric def, int sp) {
   int isp = 0;
 
   /* use tabs to prettify output */
@@ -539,8 +532,7 @@ print_def_metric (FILE * fp, const GDefMetric def, int sp)
 
 /* Output JSON metric definition block. */
 static void
-print_def_block (FILE * fp, const GDefMetric def, int sp, int last)
-{
+print_def_block (FILE * fp, const GDefMetric def, int sp, int last) {
   fpopen_obj (fp, sp);
   print_def_metric (fp, def, sp);
   fpclose_obj (fp, sp, last);
@@ -548,8 +540,7 @@ print_def_block (FILE * fp, const GDefMetric def, int sp, int last)
 
 /* Output JSON overall requests definition block. */
 static void
-print_def_overall_requests (FILE * fp, int sp)
-{
+print_def_overall_requests (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_REQUESTS,
     .datatype = "numeric",
@@ -562,8 +553,7 @@ print_def_overall_requests (FILE * fp, int sp)
 
 /* Output JSON overall valid requests definition block. */
 static void
-print_def_overall_valid_reqs (FILE * fp, int sp)
-{
+print_def_overall_valid_reqs (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_VALID,
     .datatype = "numeric",
@@ -576,8 +566,7 @@ print_def_overall_valid_reqs (FILE * fp, int sp)
 
 /* Output JSON overall invalid requests definition block. */
 static void
-print_def_overall_invalid_reqs (FILE * fp, int sp)
-{
+print_def_overall_invalid_reqs (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_FAILED,
     .datatype = "numeric",
@@ -590,8 +579,7 @@ print_def_overall_invalid_reqs (FILE * fp, int sp)
 
 /* Output JSON process time definition block. */
 static void
-print_def_overall_processed_time (FILE * fp, int sp)
-{
+print_def_overall_processed_time (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_GEN_TIME,
     .datatype = "secs",
@@ -604,8 +592,7 @@ print_def_overall_processed_time (FILE * fp, int sp)
 
 /* Output JSON overall visitors definition block. */
 static void
-print_def_overall_visitors (FILE * fp, int sp)
-{
+print_def_overall_visitors (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_UNIQUE_VISITORS,
     .datatype = "numeric",
@@ -618,8 +605,7 @@ print_def_overall_visitors (FILE * fp, int sp)
 
 /* Output JSON overall files definition block. */
 static void
-print_def_overall_files (FILE * fp, int sp)
-{
+print_def_overall_files (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_UNIQUE_FILES,
     .datatype = "numeric",
@@ -631,8 +617,7 @@ print_def_overall_files (FILE * fp, int sp)
 
 /* Output JSON overall excluded requests definition block. */
 static void
-print_def_overall_excluded (FILE * fp, int sp)
-{
+print_def_overall_excluded (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_EXCLUDE_IP,
     .datatype = "numeric",
@@ -644,8 +629,7 @@ print_def_overall_excluded (FILE * fp, int sp)
 
 /* Output JSON overall referrers definition block. */
 static void
-print_def_overall_refs (FILE * fp, int sp)
-{
+print_def_overall_refs (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_REFERRER,
     .datatype = "numeric",
@@ -657,8 +641,7 @@ print_def_overall_refs (FILE * fp, int sp)
 
 /* Output JSON overall not found definition block. */
 static void
-print_def_overall_notfound (FILE * fp, int sp)
-{
+print_def_overall_notfound (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_UNIQUE404,
     .datatype = "numeric",
@@ -670,8 +653,7 @@ print_def_overall_notfound (FILE * fp, int sp)
 
 /* Output JSON overall static files definition block. */
 static void
-print_def_overall_static_files (FILE * fp, int sp)
-{
+print_def_overall_static_files (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_STATIC_FILES,
     .datatype = "numeric",
@@ -683,8 +665,7 @@ print_def_overall_static_files (FILE * fp, int sp)
 
 /* Output JSON log size definition block. */
 static void
-print_def_overall_log_size (FILE * fp, int sp)
-{
+print_def_overall_log_size (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_LOG,
     .datatype = "bytes",
@@ -696,8 +677,7 @@ print_def_overall_log_size (FILE * fp, int sp)
 
 /* Output JSON overall bandwidth definition block. */
 static void
-print_def_overall_bandwidth (FILE * fp, int sp)
-{
+print_def_overall_bandwidth (FILE * fp, int sp) {
   GDefMetric def = {
     .lbl = T_BW,
     .datatype = "bytes",
@@ -709,8 +689,7 @@ print_def_overall_bandwidth (FILE * fp, int sp)
 
 /* Output JSON hits definition block. */
 static void
-print_def_hits (FILE * fp, int sp)
-{
+print_def_hits (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "hits",
     .lbl = MTRC_HITS_LBL,
@@ -723,8 +702,7 @@ print_def_hits (FILE * fp, int sp)
 
 /* Output JSON visitors definition block. */
 static void
-print_def_visitors (FILE * fp, int sp)
-{
+print_def_visitors (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "visitors",
     .lbl = MTRC_VISITORS_LBL,
@@ -737,8 +715,7 @@ print_def_visitors (FILE * fp, int sp)
 
 /* Output JSON bandwidth definition block. */
 static void
-print_def_bw (FILE * fp, int sp)
-{
+print_def_bw (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "bytes",
     .lbl = MTRC_BW_LBL,
@@ -755,8 +732,7 @@ print_def_bw (FILE * fp, int sp)
 
 /* Output JSON Avg. T.S. definition block. */
 static void
-print_def_avgts (FILE * fp, int sp)
-{
+print_def_avgts (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "avgts",
     .lbl = MTRC_AVGTS_LBL,
@@ -773,8 +749,7 @@ print_def_avgts (FILE * fp, int sp)
 
 /* Output JSON Cum. T.S. definition block. */
 static void
-print_def_cumts (FILE * fp, int sp)
-{
+print_def_cumts (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "cumts",
     .lbl = MTRC_CUMTS_LBL,
@@ -791,8 +766,7 @@ print_def_cumts (FILE * fp, int sp)
 
 /* Output JSON Max. T.S. definition block. */
 static void
-print_def_maxts (FILE * fp, int sp)
-{
+print_def_maxts (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "maxts",
     .lbl = MTRC_MAXTS_LBL,
@@ -808,8 +782,7 @@ print_def_maxts (FILE * fp, int sp)
 
 /* Output JSON method definition block. */
 static void
-print_def_method (FILE * fp, int sp)
-{
+print_def_method (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "method",
     .lbl = MTRC_METHODS_LBL,
@@ -825,8 +798,7 @@ print_def_method (FILE * fp, int sp)
 
 /* Output JSON protocol definition block. */
 static void
-print_def_protocol (FILE * fp, int sp)
-{
+print_def_protocol (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "protocol",
     .lbl = MTRC_PROTOCOLS_LBL,
@@ -842,8 +814,7 @@ print_def_protocol (FILE * fp, int sp)
 
 /* Output JSON city definition block. */
 static void
-print_def_city (FILE * fp, int sp)
-{
+print_def_city (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "city",
     .lbl = MTRC_CITY_LBL,
@@ -858,8 +829,7 @@ print_def_city (FILE * fp, int sp)
 
 /* Output JSON country definition block. */
 static void
-print_def_country (FILE * fp, int sp)
-{
+print_def_country (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "country",
     .lbl = MTRC_COUNTRY_LBL,
@@ -874,8 +844,7 @@ print_def_country (FILE * fp, int sp)
 
 /* Output JSON hostname definition block. */
 static void
-print_def_hostname (FILE * fp, int sp)
-{
+print_def_hostname (FILE * fp, int sp) {
   GDefMetric def = {
     .datakey = "hostname",
     .lbl = MTRC_HOSTNAME_LBL,
@@ -891,8 +860,7 @@ print_def_hostname (FILE * fp, int sp)
 
 /* Output JSON data definition block. */
 static void
-print_def_data (FILE * fp, GModule module, int sp)
-{
+print_def_data (FILE * fp, GModule module, int sp) {
   GDefMetric def = {
     .cname = "trunc",
     .cwidth = "100%",
@@ -911,8 +879,7 @@ print_def_data (FILE * fp, GModule module, int sp)
  *
  * The number of plots for the given panel is returned. */
 static int
-count_plot_fp (const GHTML * def)
-{
+count_plot_fp (const GHTML * def) {
   int i = 0;
   for (i = 0; def->chart[i].plot != 0; ++i);
   return i;
@@ -920,8 +887,7 @@ count_plot_fp (const GHTML * def)
 
 /* Entry function to output JSON plot definition block. */
 static void
-print_def_plot (FILE * fp, const GHTML * def, int sp)
-{
+print_def_plot (FILE * fp, const GHTML * def, int sp) {
   int i, isp = 0, n = count_plot_fp (def);
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -940,8 +906,7 @@ print_def_plot (FILE * fp, const GHTML * def, int sp)
 
 /* Output JSON host panel definitions. */
 static void
-print_host_metrics (FILE * fp, const GHTML * def, int sp)
-{
+print_host_metrics (FILE * fp, const GHTML * def, int sp) {
   const GOutput *output = output_lookup (def->module);
 
   print_def_hits (fp, sp);
@@ -965,8 +930,7 @@ print_host_metrics (FILE * fp, const GHTML * def, int sp)
 
 /* Output JSON panel definitions. */
 static void
-print_metrics (FILE * fp, const GHTML * def, int sp)
-{
+print_metrics (FILE * fp, const GHTML * def, int sp) {
   const GOutput *output = output_lookup (def->module);
 
   print_def_hits (fp, sp);
@@ -986,8 +950,7 @@ print_metrics (FILE * fp, const GHTML * def, int sp)
 
 /* Entry point to output JSON metric definitions. */
 static void
-print_def_metrics (FILE * fp, const GHTML * def, int sp)
-{
+print_def_metrics (FILE * fp, const GHTML * def, int sp) {
   int isp = 0;
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -1003,8 +966,7 @@ print_def_metrics (FILE * fp, const GHTML * def, int sp)
 
 /* Output panel header and description metadata definitions. */
 static void
-print_def_meta (FILE * fp, const char *head, const char *desc, int sp)
-{
+print_def_meta (FILE * fp, const char *head, const char *desc, int sp) {
   int isp = 0;
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -1016,8 +978,7 @@ print_def_meta (FILE * fp, const char *head, const char *desc, int sp)
 
 /* Output panel sort metadata definitions. */
 static void
-print_def_sort (FILE * fp, const GHTML * def, int sp)
-{
+print_def_sort (FILE * fp, const GHTML * def, int sp) {
   GSort sort = module_sort[def->module];
   int isp = 0;
   /* use tabs to prettify output */
@@ -1034,8 +995,7 @@ print_def_sort (FILE * fp, const GHTML * def, int sp)
 
 /* Output panel metadata definitions. */
 static void
-print_panel_def_meta (FILE * fp, const GHTML * def, int sp)
-{
+print_panel_def_meta (FILE * fp, const GHTML * def, int sp) {
   const char *desc = module_to_desc (def->module);
   const char *head = module_to_head (def->module);
   const char *id = module_to_id (def->module);
@@ -1057,8 +1017,7 @@ print_panel_def_meta (FILE * fp, const GHTML * def, int sp)
 
 /* Output definitions for the given panel. */
 static void
-print_json_def (FILE * fp, const GHTML * def)
-{
+print_json_def (FILE * fp, const GHTML * def) {
   int sp = 0;
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -1071,14 +1030,12 @@ print_json_def (FILE * fp, const GHTML * def)
   /* output close panel attribute */
   fpclose_obj (fp, sp, 1);
 
-  fpjson (fp, (def->module != TOTAL_MODULES - 1) ? ",%.*s" : "%.*s", nlines,
-          NL);
+  fpjson (fp, (def->module != TOTAL_MODULES - 1) ? ",%.*s" : "%.*s", nlines, NL);
 }
 
 /* Output overall definitions. */
 static void
-print_def_summary (FILE * fp, int sp)
-{
+print_def_summary (FILE * fp, int sp) {
   int isp = 0, iisp = 0;
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -1106,8 +1063,7 @@ print_def_summary (FILE * fp, int sp)
 
 /* Cheap JSON internationalisation (i18n) - report labels */
 static void
-print_json_i18n_def (FILE * fp)
-{
+print_json_i18n_def (FILE * fp) {
   int sp = 0;
   size_t i = 0;
 
@@ -1127,6 +1083,7 @@ print_json_i18n_def (FILE * fp)
     {"layout"         , HTML_REPORT_NAV_LAYOUT}         ,
     {"horizontal"     , HTML_REPORT_NAV_HOR}            ,
     {"vertical"       , HTML_REPORT_NAV_VER}            ,
+    {"wide"           , HTML_REPORT_NAV_WIDE}           ,
     {"file_opts"      , HTML_REPORT_NAV_FILE_OPTS}      ,
     {"export_json"    , HTML_REPORT_NAV_EXPORT_JSON}    ,
     {"panel_opts"     , HTML_REPORT_PANEL_PANEL_OPTS}   ,
@@ -1159,8 +1116,7 @@ print_json_i18n_def (FILE * fp)
 
 /* Output definitions for the given panel. */
 static void
-print_json_def_summary (FILE * fp)
-{
+print_json_def_summary (FILE * fp) {
   int sp = 0;
 
   /* use tabs to prettify output */
@@ -1177,8 +1133,7 @@ print_json_def_summary (FILE * fp)
 
 /* Entry point to output definitions for all panels. */
 static void
-print_json_defs (FILE * fp)
-{
+print_json_defs (FILE * fp) {
   const GHTML *def;
   size_t idx = 0;
 
@@ -1206,8 +1161,7 @@ print_json_defs (FILE * fp)
 
 /* entry point to generate a report writing it to the fp */
 void
-output_html (GLog * glog, GHolder * holder, const char *filename)
-{
+output_html (GHolder * holder, const char *filename) {
   FILE *fp;
   char now[DATE_TIME];
 
@@ -1231,7 +1185,7 @@ output_html (GLog * glog, GHolder * holder, const char *filename)
 
   print_html_body (fp, now);
   print_json_defs (fp);
-  print_json_data (fp, glog, holder);
+  print_json_data (fp, holder);
   print_conn_def (fp);
 
   print_html_footer (fp);
