@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -39,6 +39,7 @@
 #define LINE_LEN        23
 #define ERROR_LEN       255
 #define REF_SITE_LEN    511     /* maximum length of a referring site */
+#define CACHE_STATUS_LEN 7
 
 #define SPEC_TOKN_SET   0x1
 #define SPEC_TOKN_NUL   0x2
@@ -46,10 +47,10 @@
 #define SPEC_SFMT_MIS   0x4
 
 #include "commons.h"
+#include "gslist.h"
 
 /* Log properties. Note: This is per line parsed */
-typedef struct GLogItem_
-{
+typedef struct GLogItem_ {
   char *agent;
   char *browser;
   char *browser_type;
@@ -71,12 +72,15 @@ typedef struct GLogItem_
   char *uniq_key;
   char *vhost;
   char *userid;
+  char *cache_status;
 
   char site[REF_SITE_LEN + 1];
 
   uint64_t resp_size;
   uint64_t serve_time;
 
+  uint32_t numdate;
+  int ignorelevel;
   int type_ip;
   int is_404;
   int is_static;
@@ -84,19 +88,20 @@ typedef struct GLogItem_
   int agent_nkey;
 
   char *errstr;
+  struct tm dt;
 } GLogItem;
 
 /* Overall parsed log properties */
-typedef struct GLog_
-{
-  unsigned int excluded_ip;
+typedef struct GLog_ {
   unsigned int invalid;
   unsigned int offset;
   unsigned int processed;
-  unsigned int valid;
-  unsigned long long resp_size;
+  unsigned short restored;
   unsigned short load_from_disk_only;
   unsigned short piping;
+  uint32_t read;                /* lines read/parsed */
+  uint32_t inode;
+
   GLogItem *items;
 
   unsigned short log_erridx;
@@ -106,29 +111,25 @@ typedef struct GLog_
 } GLog;
 
 /* Raw data field type */
-typedef enum
-{
-  INTEGER,
-  STRING
-} GRawDataType;
+typedef enum {
+  U32,
+  STR
+} datatype;
 
 /* Raw Data extracted from table stores */
-typedef struct GRawDataItem_
-{
-  int key;
-  union
-  {
-    char *svalue;
-    int ivalue;
-  } value;
+typedef struct GRawDataItem_ {
+  uint32_t nkey;
+  union {
+    const char *data;
+    uint32_t hits;
+  };
 } GRawDataItem;
 
 /* Raw Data per module */
-typedef struct GRawData_
-{
+typedef struct GRawData_ {
   GRawDataItem *items;          /* data */
   GModule module;               /* current module */
-  GRawDataType type;            /* raw data items type */
+  datatype type;
   int idx;                      /* first level index */
   int size;                     /* total num of items on ht */
 } GRawData;
@@ -136,38 +137,38 @@ typedef struct GRawData_
 /* Each record contains a data value, i.e., Windows XP, and it may contain a
  * root value, i.e., Windows, and a unique key which is the combination of
  * date, IP and user agent */
-typedef struct GKeyData_
-{
+typedef struct GKeyData_ {
   void *data;
   void *data_key;
-  int data_nkey;
+  uint32_t data_nkey;
+  uint32_t cdnkey;              /* cache data nkey */
 
   void *root;
   void *root_key;
-  int root_nkey;
+  uint32_t root_nkey;
+  uint32_t crnkey;              /* cache root nkey */
 
   void *uniq_key;
-  int uniq_nkey;
+  uint32_t uniq_nkey;
+
+  uint32_t numdate;
 } GKeyData;
 
-typedef struct GParse_
-{
+typedef struct GParse_ {
   GModule module;
   int (*key_data) (GKeyData * kdata, GLogItem * logitem);
 
   /* data field */
-  void (*datamap) (int data_nkey, const char *data, GModule module);
-  void (*rootmap) (int root_nkey, const char *root, GModule module);
-
-  /* metrics */
-  void (*hits) (int data_nkey, GModule module);
-  void (*visitor) (int uniq_nkey, GModule module);
-  void (*bw) (int data_nkey, uint64_t size, GModule module);
-  void (*cumts) (int data_nkey, uint64_t ts, GModule module);
-  void (*maxts) (int data_nkey, uint64_t ts, GModule module);
-  void (*method) (int data_nkey, const char *method, GModule module);
-  void (*protocol) (int data_nkey, const char *proto, GModule module);
-  void (*agent) (int data_nkey, int agent_nkey, GModule module);
+  void (*datamap) (GModule module, GKeyData * kdata);
+  void (*rootmap) (GModule module, GKeyData * kdata);
+  void (*hits) (GModule module, GKeyData * kdata);
+  void (*visitor) (GModule module, GKeyData * kdata);
+  void (*bw) (GModule module, GKeyData * kdata, uint64_t size);
+  void (*cumts) (GModule module, GKeyData * kdata, uint64_t ts);
+  void (*maxts) (GModule module, GKeyData * kdata, uint64_t ts);
+  void (*method) (GModule module, GKeyData * kdata, const char *data);
+  void (*protocol) (GModule module, GKeyData * kdata, const char *data);
+  void (*agent) (GModule module, GKeyData * kdata, uint32_t agent_nkey);
 } GParse;
 
 char *fgetline (FILE * fp);
