@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -69,7 +69,7 @@ static const GPreConfLog logs = {
   "%d %t %^ %m %U %q %^ %^ %h %u %R %s %^ %^ %L",               /* W3C */
   "%d\\t%t\\t%^\\t%b\\t%h\\t%m\\t%^\\t%r\\t%s\\t%R\\t%u\\t%^",  /* CloudFront */
   "\"%x\",\"%h\",%^,%^,\"%m\",\"%U\",\"%s\",%^,\"%b\",\"%D\",%^,\"%R\",\"%u\"", /* Cloud Storage */
-  "%dT%t.%^ %^ %h:%^ %^ %T %^ %^ %^ %s %^ %b \"%r\" \"%u\"",    /* AWS Elastic Load Balancing */
+  "%^ %dT%t.%^ %v %h:%^ %^ %T %^ %^ %s %^ %b %^ \"%r\" \"%u\" %^",    /* AWS Elastic Load Balancing */
   "%^ %^ %^ %v %^: %x.%^ %~%L %h %^/%s %b %m %U",               /* Squid Native */
   "%^ %v [%d:%t %^] %h %^\"%r\" %s %^ %b %^ %L %^ \"%R\" \"%u\"", /* Amazon S3 */
 };
@@ -100,8 +100,7 @@ static const char *ignore_cmd_opts[] = {
  * If needs to be ignored, 1 is returned.
  * If not within the list of ignored command line options, 0 is returned. */
 static int
-in_ignore_cmd_opts (const char *val)
-{
+in_ignore_cmd_opts (const char *val) {
   size_t i;
   for (i = 0; i < ARRAY_SIZE (ignore_cmd_opts); i++) {
     if (strstr (val, ignore_cmd_opts[i]) != NULL)
@@ -118,9 +117,8 @@ in_ignore_cmd_opts (const char *val)
  *
  * On success, the path to the configuration file is returned. */
 char *
-get_config_file_path (void)
-{
-  char *upath = NULL, *rpath = NULL;
+get_config_file_path (void) {
+  char *upath = NULL, *gpath = NULL, *rpath = NULL;
 
   /* determine which config file to open, default or custom */
   if (conf.iconfigfile != NULL) {
@@ -130,31 +128,33 @@ get_config_file_path (void)
     return rpath;
   }
 
-  /* attempt to use the user's config file */
+  /* first attempt to use the user's config file, e.g., ~/.goaccessrc */
   upath = get_home ();
-  rpath = realpath (upath, NULL);
-  if (upath) {
+  /* failure, e.g. if the file does not exist */
+  if ((rpath = realpath (upath, NULL)) != NULL) {
     free (upath);
+    return rpath;
   }
+  LOG_DEBUG (("Unable to find user's config file %s %s", upath, strerror (errno)));
+  free (upath);
 
-  /* otherwise, fallback to global config file */
-  if (rpath == NULL && conf.load_global_config) {
-    upath = get_global_config ();
-    rpath = realpath (upath, NULL);
-    if (upath) {
-      free (upath);
-    }
+  /* otherwise, fallback to global config file, e.g.,%sysconfdir%/goaccess.conf */
+  gpath = get_global_config ();
+  if ((rpath = realpath (gpath, NULL)) != NULL && conf.load_global_config) {
+    free (gpath);
+    return rpath;
   }
+  LOG_DEBUG (("Unable to find global config file %s %s", gpath, strerror (errno)));
+  free (gpath);
 
-  return rpath;
+  return NULL;
 }
 
 /* Use predefined static files when no config file is used. Note that
  * the order in which are listed is from the most to the least common
  * (most cases). */
 void
-set_default_static_files (void)
-{
+set_default_static_files (void) {
   size_t i;
   const char *exts[] = {
     ".css",
@@ -207,8 +207,7 @@ set_default_static_files (void)
 
 /* Clean malloc'd log/date/time escaped formats. */
 void
-free_formats (void)
-{
+free_formats (void) {
   free (conf.log_format);
   free (conf.date_format);
   free (conf.date_num_format);
@@ -219,8 +218,7 @@ free_formats (void)
 
 /* Clean malloc'd command line arguments. */
 void
-free_cmd_args (void)
-{
+free_cmd_args (void) {
   int i;
   if (nargc == 0)
     return;
@@ -232,8 +230,7 @@ free_cmd_args (void)
 
 /* Append extra value to argv */
 static void
-append_to_argv (int *argc, char ***argv, char *val)
-{
+append_to_argv (int *argc, char ***argv, char *val) {
   char **_argv = xrealloc (*argv, (*argc + 2) * sizeof (*_argv));
   _argv[*argc] = val;
   _argv[*argc + 1] = (char *) '\0';
@@ -247,8 +244,7 @@ append_to_argv (int *argc, char ***argv, char *val)
  * On success, 0 is returned and config file enabled options are appended to
  * argv. */
 int
-parse_conf_file (int *argc, char ***argv)
-{
+parse_conf_file (int *argc, char ***argv) {
   char line[MAX_LINE_CONF + 1];
   char *path = NULL, *val, *opt, *p;
   FILE *file;
@@ -333,8 +329,7 @@ parse_conf_file (int *argc, char ***argv)
  * On error, -1 is returned.
  * On success, the enumerated format is returned. */
 static int
-get_log_format_item_enum (const char *str)
-{
+get_log_format_item_enum (const char *str) {
   return str2enum (LOGTYPE, ARRAY_SIZE (LOGTYPE), str);
 }
 
@@ -344,10 +339,9 @@ get_log_format_item_enum (const char *str)
  * On error, -1 is returned.
  * On success, the index of the matched item is returned. */
 size_t
-get_selected_format_idx (void)
-{
+get_selected_format_idx (void) {
   if (conf.log_format == NULL)
-    return -1;
+    return (size_t) -1;
   if (strcmp (conf.log_format, logs.common) == 0)
     return COMMON;
   else if (strcmp (conf.log_format, logs.vcommon) == 0)
@@ -369,7 +363,7 @@ get_selected_format_idx (void)
   else if (strcmp (conf.log_format, logs.awss3) == 0)
     return AWSS3;
   else
-    return -1;
+    return (size_t) -1;
 }
 
 /* Determine the selected log format from the config file or command line
@@ -378,8 +372,7 @@ get_selected_format_idx (void)
  * On error, NULL is returned.
  * On success, an allocated string containing the log format is returned. */
 char *
-get_selected_format_str (size_t idx)
-{
+get_selected_format_str (size_t idx) {
   char *fmt = NULL;
   switch (idx) {
   case COMMON:
@@ -423,8 +416,7 @@ get_selected_format_str (size_t idx)
  * On error, NULL is returned.
  * On success, an allocated string containing the date format is returned. */
 char *
-get_selected_date_str (size_t idx)
-{
+get_selected_date_str (size_t idx) {
   char *fmt = NULL;
   switch (idx) {
   case COMMON:
@@ -456,8 +448,7 @@ get_selected_date_str (size_t idx)
  * On error, NULL is returned.
  * On success, an allocated string containing the time format is returned. */
 char *
-get_selected_time_str (size_t idx)
-{
+get_selected_time_str (size_t idx) {
   char *fmt = NULL;
   switch (idx) {
   case AWSELB:
@@ -484,8 +475,7 @@ get_selected_time_str (size_t idx)
 /* Determine if the log/date/time were set, otherwise exit the program
  * execution. */
 const char *
-verify_formats (void)
-{
+verify_formats (void) {
   if (conf.time_format == NULL || *conf.time_format == '\0')
     return ERR_FORMAT_NO_TIME_FMT;
 
@@ -501,8 +491,7 @@ verify_formats (void)
 /* A wrapper function to concat the given specificity to the date
  * format. */
 static char *
-append_spec_date_format (const char *date_format, const char *spec_format)
-{
+append_spec_date_format (const char *date_format, const char *spec_format) {
   char *s = xmalloc (snprintf (NULL, 0, "%s%s", date_format, spec_format) + 1);
   sprintf (s, "%s%s", date_format, spec_format);
 
@@ -516,8 +505,7 @@ append_spec_date_format (const char *date_format, const char *spec_format)
  * On success, a clean format containing only date/time specifiers is
  * returned. */
 static char *
-clean_date_time_format (const char *format)
-{
+clean_date_time_format (const char *format) {
   char *fmt = NULL, *pr = NULL, *pw = NULL;
   int special = 0;
 
@@ -544,8 +532,7 @@ clean_date_time_format (const char *format)
  *
  * If it is, 1 is returned, otherwise, 0 is returned. */
 static int
-is_date_abbreviated (const char *fdate)
-{
+is_date_abbreviated (const char *fdate) {
   if (strpbrk (fdate, "cDF"))
     return 1;
 
@@ -558,8 +545,7 @@ is_date_abbreviated (const char *fdate)
  * On success, a clean format containing only time specifiers is
  * returned. */
 static char *
-set_format_time (void)
-{
+set_format_time (void) {
   char *ftime = NULL;
 
   if (has_timestamp (conf.date_format) || !strcmp ("%T", conf.time_format))
@@ -576,8 +562,7 @@ set_format_time (void)
  * On success, a clean format containing only date specifiers is
  * returned. */
 static char *
-set_format_date (void)
-{
+set_format_date (void) {
   char *fdate = NULL;
 
   if (has_timestamp (conf.date_format))
@@ -594,8 +579,7 @@ set_format_date (void)
  *
  * On success, the numeric date time specificity format is set. */
 static void
-set_spec_date_time_num_format (void)
-{
+set_spec_date_time_num_format (void) {
   char *buf = NULL, *tf = set_format_time ();
   const char *df = conf.date_num_format;
 
@@ -615,8 +599,7 @@ set_spec_date_time_num_format (void)
  *
  * On success, the human readable date time specificity format is set. */
 static void
-set_spec_date_time_format (void)
-{
+set_spec_date_time_format (void) {
   char *buf = NULL;
   const char *fmt = conf.spec_date_time_num_format;
   int buflen = 0, flen = 0;
@@ -646,8 +629,7 @@ set_spec_date_time_format (void)
  * On success, the numeric date format as Ymd is set and 0 is
  * returned. */
 static int
-set_date_num_format (void)
-{
+set_date_num_format (void) {
   char *fdate = NULL, *buf = NULL;
   int buflen = 0, flen = 0;
 
@@ -680,8 +662,7 @@ set_date_num_format (void)
 /* If specificity is supplied, then determine which value we need to
  * append to the date format. */
 void
-set_spec_date_format (void)
-{
+set_spec_date_format (void) {
   if (verify_formats ())
     return;
 
@@ -702,8 +683,7 @@ set_spec_date_format (void)
  * argument. The supplied optarg can be either an actual format string
  * or the enumerated value such as VCOMBINED */
 void
-set_date_format_str (const char *oarg)
-{
+set_date_format_str (const char *oarg) {
   char *fmt = NULL;
   int type = get_log_format_item_enum (oarg);
 
@@ -730,8 +710,7 @@ set_date_format_str (const char *oarg)
  * argument. The supplied optarg can be either an actual format string
  * or the enumerated value such as VCOMBINED */
 void
-set_time_format_str (const char *oarg)
-{
+set_time_format_str (const char *oarg) {
   char *fmt = NULL;
   int type = get_log_format_item_enum (oarg);
 
@@ -758,8 +737,7 @@ set_time_format_str (const char *oarg)
  * The supplied optarg can be either an actual format string or the
  * enumerated value such as VCOMBINED */
 void
-set_log_format_str (const char *oarg)
-{
+set_log_format_str (const char *oarg) {
   char *fmt = NULL;
   int type = get_log_format_item_enum (oarg);
 
