@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -74,6 +74,8 @@ const int sort_choices[][SORT_MAX_OPTS] = {
   {SORT_BY_HITS, SORT_BY_VISITORS, SORT_BY_DATA, SORT_BY_BW, SORT_BY_AVGTS, SORT_BY_CUMTS, SORT_BY_MAXTS, -1},
   /* REMOTE_USER */
   {SORT_BY_HITS, SORT_BY_VISITORS, SORT_BY_DATA, SORT_BY_BW, SORT_BY_AVGTS, SORT_BY_CUMTS, SORT_BY_MAXTS, -1},
+  /* CACHE_STATUS */
+  {SORT_BY_HITS, SORT_BY_VISITORS, SORT_BY_DATA, SORT_BY_BW, SORT_BY_AVGTS, SORT_BY_CUMTS, SORT_BY_MAXTS, -1},
 #ifdef HAVE_GEOLOCATION
   /* GEO_LOCATION */
   {SORT_BY_HITS, SORT_BY_VISITORS, SORT_BY_DATA, SORT_BY_BW, SORT_BY_AVGTS, SORT_BY_CUMTS, SORT_BY_MAXTS, -1},
@@ -112,6 +114,7 @@ GSort module_sort[TOTAL_MODULES] = {
   {KEYPHRASES          , SORT_BY_HITS , SORT_DESC } ,
   {STATUS_CODES        , SORT_BY_HITS , SORT_DESC } ,
   {REMOTE_USER         , SORT_BY_HITS , SORT_DESC } ,
+  {CACHE_STATUS        , SORT_BY_HITS , SORT_DESC } ,
 #ifdef HAVE_GEOLOCATION
   {GEO_LOCATION        , SORT_BY_HITS , SORT_DESC } ,
 #endif
@@ -120,15 +123,13 @@ GSort module_sort[TOTAL_MODULES] = {
 
 /* Sort an array of strings ascending */
 int
-strcmp_asc (const void *a, const void *b)
-{
-  return strcmp (*((char **) a), *((char **) b));
+strcmp_asc (const void *a, const void *b) {
+  return strcmp (*((char *const *) a), *((char *const *) b));
 }
 
 /* Sort 'data' metric ascending */
 static int
-cmp_data_asc (const void *a, const void *b)
-{
+cmp_data_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
   return strcmp (ia->metrics->data, ib->metrics->data);
@@ -136,8 +137,7 @@ cmp_data_asc (const void *a, const void *b)
 
 /* Sort 'data' metric descending */
 static int
-cmp_data_desc (const void *a, const void *b)
-{
+cmp_data_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
   return strcmp (ib->metrics->data, ia->metrics->data);
@@ -145,8 +145,7 @@ cmp_data_desc (const void *a, const void *b)
 
 /* Sort 'hits' metric descending */
 static int
-cmp_num_desc (const void *a, const void *b)
-{
+cmp_num_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -158,8 +157,7 @@ cmp_num_desc (const void *a, const void *b)
 
 /* Sort 'hits' metric ascending */
 static int
-cmp_num_asc (const void *a, const void *b)
-{
+cmp_num_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -171,8 +169,7 @@ cmp_num_asc (const void *a, const void *b)
 
 /* Sort 'visitors' metric descending */
 static int
-cmp_vis_desc (const void *a, const void *b)
-{
+cmp_vis_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -184,8 +181,7 @@ cmp_vis_desc (const void *a, const void *b)
 
 /* Sort 'visitors' metric ascending */
 static int
-cmp_vis_asc (const void *a, const void *b)
-{
+cmp_vis_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -197,31 +193,28 @@ cmp_vis_asc (const void *a, const void *b)
 
 /* Sort GRawDataItem value descending */
 static int
-cmp_raw_num_desc (const void *a, const void *b)
-{
+cmp_raw_num_desc (const void *a, const void *b) {
   const GRawDataItem *ia = a;
   const GRawDataItem *ib = b;
 
-  int va = ia->value.ivalue;
-  int vb = ib->value.ivalue;
+  int va = ia->hits;
+  int vb = ib->hits;
 
   return (va < vb) - (va > vb);
 }
 
 /* Sort GRawDataItem value descending */
 static int
-cmp_raw_str_desc (const void *a, const void *b)
-{
+cmp_raw_str_desc (const void *a, const void *b) {
   const GRawDataItem *ia = a;
   const GRawDataItem *ib = b;
 
-  return strcmp (ib->value.svalue, ia->value.svalue);
+  return strcmp (ib->data, ia->data);
 }
 
 /* Sort 'bandwidth' metric descending */
 static int
-cmp_bw_desc (const void *a, const void *b)
-{
+cmp_bw_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -233,8 +226,7 @@ cmp_bw_desc (const void *a, const void *b)
 
 /* Sort 'bandwidth' metric ascending */
 static int
-cmp_bw_asc (const void *a, const void *b)
-{
+cmp_bw_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -246,8 +238,7 @@ cmp_bw_asc (const void *a, const void *b)
 
 /* Sort 'avgts' metric descending */
 static int
-cmp_avgts_desc (const void *a, const void *b)
-{
+cmp_avgts_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -259,8 +250,7 @@ cmp_avgts_desc (const void *a, const void *b)
 
 /* Sort 'avgts' metric ascending */
 static int
-cmp_avgts_asc (const void *a, const void *b)
-{
+cmp_avgts_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -272,8 +262,7 @@ cmp_avgts_asc (const void *a, const void *b)
 
 /* Sort 'cumts' metric descending */
 static int
-cmp_cumts_desc (const void *a, const void *b)
-{
+cmp_cumts_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -285,8 +274,7 @@ cmp_cumts_desc (const void *a, const void *b)
 
 /* Sort 'cumts' metric ascending */
 static int
-cmp_cumts_asc (const void *a, const void *b)
-{
+cmp_cumts_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -298,8 +286,7 @@ cmp_cumts_asc (const void *a, const void *b)
 
 /* Sort 'maxts' metric descending */
 static int
-cmp_maxts_desc (const void *a, const void *b)
-{
+cmp_maxts_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -311,8 +298,7 @@ cmp_maxts_desc (const void *a, const void *b)
 
 /* Sort 'maxts' metric ascending */
 static int
-cmp_maxts_asc (const void *a, const void *b)
-{
+cmp_maxts_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
 
@@ -324,8 +310,7 @@ cmp_maxts_asc (const void *a, const void *b)
 
 /* Sort 'protocol' metric ascending */
 static int
-cmp_proto_asc (const void *a, const void *b)
-{
+cmp_proto_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
   return strcmp (ia->metrics->protocol, ib->metrics->protocol);
@@ -333,8 +318,7 @@ cmp_proto_asc (const void *a, const void *b)
 
 /* Sort 'protocol' metric descending */
 static int
-cmp_proto_desc (const void *a, const void *b)
-{
+cmp_proto_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
   return strcmp (ib->metrics->protocol, ia->metrics->protocol);
@@ -342,8 +326,7 @@ cmp_proto_desc (const void *a, const void *b)
 
 /* Sort 'method' metric ascending */
 static int
-cmp_mthd_asc (const void *a, const void *b)
-{
+cmp_mthd_asc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
   return strcmp (ia->metrics->method, ib->metrics->method);
@@ -351,20 +334,26 @@ cmp_mthd_asc (const void *a, const void *b)
 
 /* Sort 'method' metric descending */
 static int
-cmp_mthd_desc (const void *a, const void *b)
-{
+cmp_mthd_desc (const void *a, const void *b) {
   const GHolderItem *ia = a;
   const GHolderItem *ib = b;
   return strcmp (ib->metrics->method, ia->metrics->method);
 }
 
+/* Sort 'hits' metric ascending */
+int
+cmp_ui32_asc (const void *a, const void *b) {
+  const uint32_t *ia = (const uint32_t *) a;    // casting pointer types
+  const uint32_t *ib = (const uint32_t *) b;
+  return *ia - *ib;
+}
+
 /* Given a string sort field, get the enum field value.
  *
  * On error, -1 is returned.
  * On success, the enumerated field value is returned. */
 int
-get_sort_field_enum (const char *str)
-{
+get_sort_field_enum (const char *str) {
   return str2enum (FIELD, ARRAY_SIZE (FIELD), str);
 }
 
@@ -373,8 +362,7 @@ get_sort_field_enum (const char *str)
  * On error, -1 is returned.
  * On success, the enumerated order value is returned. */
 int
-get_sort_order_enum (const char *str)
-{
+get_sort_order_enum (const char *str) {
   return str2enum (ORDER, ARRAY_SIZE (ORDER), str);
 }
 
@@ -382,8 +370,7 @@ get_sort_order_enum (const char *str)
  *
  * The string corresponding to the enumerated order value is returned. */
 const char *
-get_sort_order_str (GSortOrder order)
-{
+get_sort_order_str (GSortOrder order) {
   return ORDER[order].str;
 }
 
@@ -391,8 +378,7 @@ get_sort_order_str (GSortOrder order)
  *
  * The string corresponding to the enumerated field value is returned. */
 const char *
-get_sort_field_str (GSortField field)
-{
+get_sort_field_str (GSortField field) {
   return FIELD[field].str;
 }
 
@@ -400,8 +386,7 @@ get_sort_field_str (GSortField field)
  *
  * The key corresponding to the enumerated field value is returned. */
 const char *
-get_sort_field_key (GSortField field)
-{
+get_sort_field_key (GSortField field) {
   static const char *field2key[][2] = {
     {"BY_HITS", "hits"},
     {"BY_VISITORS", "visitors"},
@@ -422,8 +407,7 @@ get_sort_field_key (GSortField field)
  * On error, function returns.
  * On success, panel metrics are sorted. */
 void
-set_initial_sort (const char *smod, const char *sfield, const char *ssort)
-{
+set_initial_sort (const char *smod, const char *sfield, const char *ssort) {
   int module, field, order;
   if ((module = get_module_enum (smod)) == -1)
     return;
@@ -444,8 +428,7 @@ set_initial_sort (const char *smod, const char *sfield, const char *ssort)
  * On error or if metric can't be sorted, 0 is returned.
  * On success, 1 is returned. */
 int
-can_sort_module (GModule module, int field)
-{
+can_sort_module (GModule module, int field) {
   int i, can_sort = 0;
   for (i = 0; -1 != sort_choices[module][i]; i++) {
     if (sort_choices[module][i] != field)
@@ -475,14 +458,11 @@ can_sort_module (GModule module, int field)
  * On error, function returns.
  * On success, panel metrics are sorted. */
 void
-parse_initial_sort (void)
-{
+parse_initial_sort (void) {
   int i;
   char module[SORT_MODULE_LEN], field[SORT_FIELD_LEN], order[SORT_ORDER_LEN];
   for (i = 0; i < conf.sort_panel_idx; ++i) {
-    if (sscanf
-        (conf.sort_panels[i], "%15[^','],%11[^','],%4s", module, field,
-         order) != 3)
+    if (sscanf (conf.sort_panels[i], "%15[^','],%11[^','],%4s", module, field, order) != 3)
       continue;
     set_initial_sort (module, field, order);
   }
@@ -490,8 +470,7 @@ parse_initial_sort (void)
 
 /* Apply user defined sort */
 void
-sort_holder_items (GHolderItem * items, int size, GSort sort)
-{
+sort_holder_items (GHolderItem * items, int size, GSort sort) {
   switch (sort.field) {
   case SORT_BY_HITS:
     if (sort.sort == SORT_DESC)
@@ -555,8 +534,7 @@ sort_holder_items (GHolderItem * items, int size, GSort sort)
  *
  * On success, raw data sorted in a descending order. */
 GRawData *
-sort_raw_num_data (GRawData * raw_data, int ht_size)
-{
+sort_raw_num_data (GRawData * raw_data, int ht_size) {
   qsort (raw_data->items, ht_size, sizeof *(raw_data->items), cmp_raw_num_desc);
   return raw_data;
 }
@@ -565,8 +543,7 @@ sort_raw_num_data (GRawData * raw_data, int ht_size)
  *
  * On success, raw data sorted in a descending order. */
 GRawData *
-sort_raw_str_data (GRawData * raw_data, int ht_size)
-{
+sort_raw_str_data (GRawData * raw_data, int ht_size) {
   qsort (raw_data->items, ht_size, sizeof *(raw_data->items), cmp_raw_str_desc);
   return raw_data;
 }
