@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -58,14 +58,9 @@
 
 #include "ui.h"
 
-#ifdef HAVE_LIBTOKYOCABINET
-#include "tcabdb.h"
-#else
-#include "gkhash.h"
-#endif
-
 #include "color.h"
 #include "error.h"
+#include "gkhash.h"
 #include "gmenu.h"
 #include "goaccess.h"
 #include "util.h"
@@ -88,6 +83,7 @@ static GOutput outputting[] = {
   {KEYPHRASES      , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
   {STATUS_CODES    , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
   {REMOTE_USER     , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
+  {CACHE_STATUS    , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
 #ifdef HAVE_GEOLOCATION
   {GEO_LOCATION    , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
 #endif
@@ -95,8 +91,7 @@ static GOutput outputting[] = {
 /* *INDENT-ON* */
 
 /* Structure to display overall statistics */
-typedef struct Field_
-{
+typedef struct Field_ {
   const char *field;
   /* char due to log, bw, log_file */
   char *value;
@@ -110,8 +105,7 @@ typedef struct Field_
  * On error, or if not found, NULL is returned.
  * On success, the panel value is returned. */
 GOutput *
-output_lookup (GModule module)
-{
+output_lookup (GModule module) {
   int i, num_panels = ARRAY_SIZE (outputting);
 
   for (i = 0; i < num_panels; i++) {
@@ -123,8 +117,7 @@ output_lookup (GModule module)
 
 /* Initialize curses colors */
 void
-init_colors (int force)
-{
+init_colors (int force) {
   /* use default foreground/background colors */
   use_default_colors ();
   /* first set a default normal color */
@@ -135,8 +128,7 @@ init_colors (int force)
 
 /* Ncurses' window handling */
 void
-set_input_opts (void)
-{
+set_input_opts (void) {
   initscr ();
   clear ();
   noecho ();
@@ -153,8 +145,7 @@ set_input_opts (void)
 
 /* Deletes the given window, freeing all memory associated with it. */
 void
-close_win (WINDOW * w)
-{
+close_win (WINDOW * w) {
   if (w == NULL)
     return;
   wclear (w);
@@ -165,28 +156,29 @@ close_win (WINDOW * w)
 /* Get the current calendar time as a value of type time_t and convert
  * time_t to tm as local time */
 void
-generate_time (void)
-{
+generate_time (void) {
   timestamp = time (NULL);
   now_tm = localtime (&timestamp);
 }
 
 /* Set the loading spinner as ended and manage the mutex locking. */
 void
-end_spinner (void)
-{
+end_spinner (void) {
   if (conf.no_parsing_spinner)
     return;
 
   pthread_mutex_lock (&parsing_spinner->mutex);
   parsing_spinner->state = SPN_END;
   pthread_mutex_unlock (&parsing_spinner->mutex);
+  if (!parsing_spinner->curses) {
+    // wait for the ui_spinner thread to finish
+    usleep (SPIN_UPDATE_INTERVAL);
+  }
 }
 
 /* Set background colors to all windows. */
 void
-set_wbkgd (WINDOW * main_win, WINDOW * header_win)
-{
+set_wbkgd (WINDOW * main_win, WINDOW * header_win) {
   GColors *color = get_color (COLOR_BG);
 
   /* background colors */
@@ -200,8 +192,7 @@ set_wbkgd (WINDOW * main_win, WINDOW * header_win)
  * each of them. e.g., background color, enable the reading of
  * function keys. */
 void
-init_windows (WINDOW ** header_win, WINDOW ** main_win)
-{
+init_windows (WINDOW ** header_win, WINDOW ** main_win) {
   int row = 0, col = 0;
 
   /* init standard screen */
@@ -227,8 +218,7 @@ init_windows (WINDOW ** header_win, WINDOW ** main_win)
 /* Draw a generic header with the ability to set a custom text to it. */
 void
 draw_header (WINDOW * win, const char *s, const char *fmt, int y, int x, int w,
-             GColors * (*func) (void))
-{
+             GColors * (*func) (void)) {
   GColors *color = (*func) ();
   char *buf;
 
@@ -247,8 +237,7 @@ draw_header (WINDOW * win, const char *s, const char *fmt, int y, int x, int w,
 
 /* Determine the actual size of the main window. */
 void
-term_size (WINDOW * main_win, int *main_win_height)
-{
+term_size (WINDOW * main_win, int *main_win_height) {
   int term_h = 0, term_w = 0;
 
   getmaxyx (stdscr, term_h, term_w);
@@ -262,8 +251,7 @@ term_size (WINDOW * main_win, int *main_win_height)
  *
  * On success, a string containing the label name is returned. */
 const char *
-module_to_label (GModule module)
-{
+module_to_label (GModule module) {
   static const char *modules[] = {
     VISITORS_LABEL,
     REQUESTS_LABEL,
@@ -279,6 +267,7 @@ module_to_label (GModule module)
     KEYPHRASES_LABEL,
     STATUS_CODES_LABEL,
     REMOTE_USER_LABEL,
+    CACHE_STATUS_LABEL,
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_LABEL,
 #endif
@@ -291,8 +280,7 @@ module_to_label (GModule module)
  *
  * On success, a string containing the label id is returned. */
 const char *
-module_to_id (GModule module)
-{
+module_to_id (GModule module) {
   static const char *modules[] = {
     VISITORS_ID,
     REQUESTS_ID,
@@ -308,6 +296,7 @@ module_to_id (GModule module)
     KEYPHRASES_ID,
     STATUS_CODES_ID,
     REMOTE_USER_ID,
+    CACHE_STATUS_ID,
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_ID,
 #endif
@@ -320,8 +309,7 @@ module_to_id (GModule module)
  *
  * On success, a string containing the label header is returned. */
 const char *
-module_to_head (GModule module)
-{
+module_to_head (GModule module) {
   static const char *modules[] = {
     VISITORS_HEAD,
     REQUESTS_HEAD,
@@ -337,6 +325,7 @@ module_to_head (GModule module)
     KEYPHRASES_HEAD,
     STATUS_CODES_HEAD,
     REMOTE_USER_HEAD,
+    CACHE_STATUS_HEAD,
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_HEAD,
 #endif
@@ -353,8 +342,7 @@ module_to_head (GModule module)
  *
  * On success, a string containing the label description is returned. */
 const char *
-module_to_desc (GModule module)
-{
+module_to_desc (GModule module) {
   static const char *modules[] = {
     VISITORS_DESC,
     REQUESTS_DESC,
@@ -370,6 +358,7 @@ module_to_desc (GModule module)
     KEYPHRASES_DESC,
     STATUS_CODES_DESC,
     REMOTE_USER_DESC,
+    CACHE_STATUS_DESC,
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_DESC,
 #endif
@@ -380,8 +369,7 @@ module_to_desc (GModule module)
 
 /* Rerender the header window to reflect active module. */
 void
-update_active_module (WINDOW * header_win, GModule current)
-{
+update_active_module (WINDOW * header_win, GModule current) {
   GColors *color = get_color (COLOR_ACTIVE_LABEL);
   const char *module = module_to_label (current);
   int col = getmaxx (stdscr);
@@ -402,9 +390,7 @@ update_active_module (WINDOW * header_win, GModule current)
 
 /* Print out (terminal) an overall field label. e.g., 'Processed Time' */
 static void
-render_overall_field (WINDOW * win, const char *s, int y, int x,
-                      GColors * color)
-{
+render_overall_field (WINDOW * win, const char *s, int y, int x, GColors * color) {
   wattron (win, color->attr | COLOR_PAIR (color->pair->idx));
   mvwprintw (win, y, x, "%s", s);
   wattroff (win, color->attr | COLOR_PAIR (color->pair->idx));
@@ -412,9 +398,7 @@ render_overall_field (WINDOW * win, const char *s, int y, int x,
 
 /* Print out (terminal) an overall field value. e.g., '120 secs' */
 static void
-render_overall_value (WINDOW * win, const char *s, int y, int x,
-                      GColors * color)
-{
+render_overall_value (WINDOW * win, const char *s, int y, int x, GColors * color) {
   wattron (win, color->attr | COLOR_PAIR (color->pair->idx));
   mvwprintw (win, y, x, "%s", s);
   wattroff (win, color->attr | COLOR_PAIR (color->pair->idx));
@@ -424,36 +408,32 @@ render_overall_value (WINDOW * win, const char *s, int y, int x,
  *
  * On success, the number of excluded ips as a string is returned. */
 static char *
-get_str_excluded_ips (GLog * glog)
-{
-  return int2str (glog->excluded_ip, 0);
+get_str_excluded_ips (void) {
+  return int2str (ht_get_excluded_ips (), 0);
 }
 
 /* Convert the number of failed requests to a string.
  *
  * On success, the number of failed requests as a string is returned. */
 static char *
-get_str_failed_reqs (GLog * glog)
-{
-  return int2str (glog->invalid, 0);
+get_str_failed_reqs (void) {
+  return int2str (ht_get_invalid (), 0);
 }
 
 /* Convert the number of processed requests to a string.
  *
  * On success, the number of processed requests as a string is returned. */
 static char *
-get_str_processed_reqs (GLog * glog)
-{
-  return int2str (glog->processed, 0);
+get_str_processed_reqs (void) {
+  return int2str (ht_get_processed (), 0);
 }
 
 /* Convert the number of valid requests to a string.
  *
  * On success, the number of valid requests as a string is returned. */
 static char *
-get_str_valid_reqs (GLog * glog)
-{
-  return int2str (glog->valid, 0);
+get_str_valid_reqs (void) {
+  return int2str (ht_sum_valid (), 0);
 }
 
 /* Convert the number of not found requests to a string.
@@ -461,8 +441,7 @@ get_str_valid_reqs (GLog * glog)
  * On success, the number of not found requests as a string is
  * returned. */
 static char *
-get_str_notfound_reqs (void)
-{
+get_str_notfound_reqs (void) {
   return int2str (ht_get_size_datamap (NOT_FOUND), 0);
 }
 
@@ -470,8 +449,7 @@ get_str_notfound_reqs (void)
  *
  * On success, the number of referrers as a string is returned. */
 static char *
-get_str_ref_reqs (void)
-{
+get_str_ref_reqs (void) {
   return int2str (ht_get_size_datamap (REFERRERS), 0);
 }
 
@@ -479,8 +457,7 @@ get_str_ref_reqs (void)
  *
  * On success, the number of requests as a string is returned. */
 static char *
-get_str_reqs (void)
-{
+get_str_reqs (void) {
   return int2str (ht_get_size_datamap (REQUESTS), 0);
 }
 
@@ -488,8 +465,7 @@ get_str_reqs (void)
  *
  * On success, the number of static requests as a string is returned. */
 static char *
-get_str_static_reqs (void)
-{
+get_str_static_reqs (void) {
   return int2str (ht_get_size_datamap (REQUESTS_STATIC), 0);
 }
 
@@ -497,8 +473,7 @@ get_str_static_reqs (void)
  *
  * On success, the number of unique visitors as a string is returned. */
 static char *
-get_str_visitors (void)
-{
+get_str_visitors (void) {
   return int2str (ht_get_size_uniqmap (VISITORS), 0);
 }
 
@@ -507,18 +482,12 @@ get_str_visitors (void)
  * On success, the time taken to process the log as a string is
  * returned. */
 static char *
-get_str_proctime (void)
-{
+get_str_proctime (void) {
   char *s = NULL;
-  uint64_t secs = (long long) end_proc - start_proc;
+  uint32_t secs = ht_get_processing_time ();
 
-#ifdef TCB_BTREE
-  if (conf.store_accumulated_time)
-    secs = (uint64_t) ht_get_genstats ("accumulated_time");
-#endif
-
-  s = xmalloc (snprintf (NULL, 0, "%" PRIu64 "s", secs) + 1);
-  sprintf (s, "%" PRIu64 "s", secs);
+  s = xmalloc (snprintf (NULL, 0, "%us", secs) + 1);
+  sprintf (s, "%us", secs);
 
   return s;
 }
@@ -527,8 +496,7 @@ get_str_proctime (void)
  *
  * On success, the log file size as a string is returned. */
 static char *
-get_str_filesize (void)
-{
+get_str_filesize (void) {
   return filesize_str (get_log_sizes ());
 }
 
@@ -536,8 +504,7 @@ get_str_filesize (void)
  *
  * On success, the log file path as a string is returned. */
 static char *
-get_str_logfile (void)
-{
+get_str_logfile (void) {
   int col = getmaxx (stdscr), left_padding = 20;
   return get_log_source_str (col - left_padding);
 }
@@ -546,27 +513,8 @@ get_str_logfile (void)
  *
  * On success, the bandwidth as a string is returned. */
 static char *
-get_str_bandwidth (GLog * glog)
-{
-  return filesize_str ((float) glog->resp_size);
-}
-
-/* Iterate over the visitors module and sort date in an ascending
- * order.
- *
- * On success, an array of sorted dates is returned. */
-static char **
-get_visitors_dates (GHolder * h)
-{
-  char **dates = malloc (sizeof (char *) * h->holder_size);
-  int i;
-
-  for (i = 0; i < h->idx; i++) {
-    dates[i] = h->items[i].metrics->data;
-  }
-  qsort (dates, h->holder_size, sizeof (char *), strcmp_asc);
-
-  return dates;
+get_str_bandwidth (void) {
+  return filesize_str (ht_sum_bw ());
 }
 
 /* Get the overall statistics start and end dates.
@@ -575,20 +523,20 @@ get_visitors_dates (GHolder * h)
  * On success, 0 is returned and an string containing the overall
  * header is returned. */
 int
-get_start_end_parsing_dates (GHolder * h, char **start, char **end,
-                             const char *f)
-{
-  char **dates = NULL;
+get_start_end_parsing_dates (char **start, char **end, const char *f) {
+  uint32_t *dates = NULL;
+  uint32_t len = 0;
   const char *sndfmt = conf.spec_date_time_num_format;
+  char s[DATE_LEN];
+  char e[DATE_LEN];
 
-  if (h->idx == 0)
-    return 1;
-
-  dates = get_visitors_dates (h + VISITORS);
+  dates = get_sorted_dates (&len);
+  sprintf (s, "%u", dates[0]);
+  sprintf (e, "%u", dates[len - 1]);
 
   /* just display the actual dates - no specificity */
-  *start = get_visitors_date (dates[0], sndfmt, f);
-  *end = get_visitors_date (dates[h->idx - 1], sndfmt, f);
+  *start = get_visitors_date (s, sndfmt, f);
+  *end = get_visitors_date (e, sndfmt, f);
 
   free (dates);
 
@@ -599,12 +547,11 @@ get_start_end_parsing_dates (GHolder * h, char **start, char **end,
  *
  * On success, an string containing the overall header is returned. */
 char *
-get_overall_header (GHolder * h)
-{
+get_overall_header (GHolder * h) {
   const char *head = T_DASH_HEAD;
   char *hd = NULL, *start = NULL, *end = NULL;
 
-  if (h->idx == 0 || get_start_end_parsing_dates (h, &start, &end, "%d/%b/%Y"))
+  if (h->idx == 0 || get_start_end_parsing_dates (&start, &end, "%d/%b/%Y"))
     return xstrdup (head);
 
   hd = xmalloc (snprintf (NULL, 0, "%s (%s - %s)", head, start, end) + 1);
@@ -618,8 +565,7 @@ get_overall_header (GHolder * h)
 
 /* Print out (terminal dashboard) the overall statistics header. */
 static void
-render_overall_header (WINDOW * win, GHolder * h)
-{
+render_overall_header (WINDOW * win, GHolder * h) {
   char *hd = get_overall_header (h);
   int col = getmaxx (stdscr);
 
@@ -630,8 +576,7 @@ render_overall_header (WINDOW * win, GHolder * h)
 /* Render the overall statistics. This will attempt to determine the
  * right X and Y position given the current values. */
 static void
-render_overall_statistics (WINDOW * win, Field fields[], size_t n)
-{
+render_overall_statistics (WINDOW * win, Field fields[], size_t n) {
   GColors *color = NULL;
   int x_field = 2, x_value = 0;
   size_t i, j, k, max_field = 0, max_value = 0, mod_val, y;
@@ -657,16 +602,14 @@ render_overall_statistics (WINDOW * win, Field fields[], size_t n)
     max_field = 0;
     for (j = 0; j < n; j++) {
       size_t len = strlen (fields[j].field);
-      if (j % OVERALL_NUM_COLS == mod_val && len > max_field &&
-          !fields[j].oneliner)
+      if (j % OVERALL_NUM_COLS == mod_val && len > max_field && !fields[j].oneliner)
         max_field = len;
     }
     /* get max length of value in the same column */
     max_value = 0;
     for (j = 0; j < n; j++) {
       size_t len = strlen (fields[j].value);
-      if (j % OVERALL_NUM_COLS == mod_val && len > max_value &&
-          !fields[j].oneliner)
+      if (j % OVERALL_NUM_COLS == mod_val && len > max_value && !fields[j].oneliner)
         max_value = len;
     }
 
@@ -682,8 +625,7 @@ render_overall_statistics (WINDOW * win, Field fields[], size_t n)
 
 /* The entry point to render the overall statistics and free its data. */
 void
-display_general (WINDOW * win, GLog * glog, GHolder * h)
-{
+display_general (WINDOW * win, GHolder * h) {
   GColors *(*colorlbl) (void) = color_overall_lbls;
   GColors *(*colorpth) (void) = color_overall_path;
   GColors *(*colorval) (void) = color_overall_vals;
@@ -692,19 +634,19 @@ display_general (WINDOW * win, GLog * glog, GHolder * h)
 
   /* *INDENT-OFF* */
   Field fields[] = {
-    {T_REQUESTS        , get_str_processed_reqs (glog), colorlbl, colorval, 0},
-    {T_UNIQUE_VISITORS , get_str_visitors ()          , colorlbl, colorval, 0},
-    {T_UNIQUE_FILES    , get_str_reqs ()              , colorlbl, colorval, 0},
-    {T_REFERRER        , get_str_ref_reqs ()          , colorlbl, colorval, 0},
-    {T_VALID           , get_str_valid_reqs (glog)    , colorlbl, colorval, 0},
-    {T_GEN_TIME        , get_str_proctime ()          , colorlbl, colorval, 0},
-    {T_STATIC_FILES    , get_str_static_reqs ()       , colorlbl, colorval, 0},
-    {T_LOG             , get_str_filesize ()          , colorlbl, colorval, 0},
-    {T_FAILED          , get_str_failed_reqs (glog)   , colorlbl, colorval, 0},
-    {T_EXCLUDE_IP      , get_str_excluded_ips (glog)  , colorlbl, colorval, 0},
-    {T_UNIQUE404       , get_str_notfound_reqs ()     , colorlbl, colorval, 0},
-    {T_BW              , get_str_bandwidth (glog)     , colorlbl, colorval, 0},
-    {T_LOG_PATH        , get_str_logfile ()           , colorlbl, colorpth, 1}
+    {T_REQUESTS        , get_str_processed_reqs () , colorlbl , colorval , 0} ,
+    {T_UNIQUE_VISITORS , get_str_visitors ()       , colorlbl , colorval , 0} ,
+    {T_UNIQUE_FILES    , get_str_reqs ()           , colorlbl , colorval , 0} ,
+    {T_REFERRER        , get_str_ref_reqs ()       , colorlbl , colorval , 0} ,
+    {T_VALID           , get_str_valid_reqs ()     , colorlbl , colorval , 0} ,
+    {T_GEN_TIME        , get_str_proctime ()       , colorlbl , colorval , 0} ,
+    {T_STATIC_FILES    , get_str_static_reqs ()    , colorlbl , colorval , 0} ,
+    {T_LOG             , get_str_filesize ()       , colorlbl , colorval , 0} ,
+    {T_FAILED          , get_str_failed_reqs ()    , colorlbl , colorval , 0} ,
+    {T_EXCLUDE_IP      , get_str_excluded_ips ()   , colorlbl , colorval , 0} ,
+    {T_UNIQUE404       , get_str_notfound_reqs ()  , colorlbl , colorval , 0} ,
+    {T_BW              , get_str_bandwidth ()      , colorlbl , colorval , 0} ,
+    {T_LOG_PATH        , get_str_logfile ()        , colorlbl , colorpth , 1}
   };
   /* *INDENT-ON* */
 
@@ -724,8 +666,7 @@ display_general (WINDOW * win, GLog * glog, GHolder * h)
  * On success, the inputted string is returned. */
 char *
 input_string (WINDOW * win, int pos_y, int pos_x, size_t max_width,
-              const char *str, int enable_case, int *toggle_case)
-{
+              const char *str, int enable_case, int *toggle_case) {
   char *s = xmalloc (max_width + 1), *tmp;
   size_t i, c, pos = 0, x = 0, quit = 1, len = 0, size_x = 0, size_y = 0;
 
@@ -862,116 +803,93 @@ input_string (WINDOW * win, int pos_y, int pos_x, size_t max_width,
   return s;
 }
 
+/* Add the given user agent value into our array of GAgents.
+ *
+ * On error, 1 is returned.
+ * On success, the user agent is added to the array and 0 is returned. */
+static int
+set_agents (void *val, void *user_data) {
+  GAgents *agents = user_data;
+  GAgentItem *tmp = NULL;
+  char *agent = NULL;
+  int newlen = 0, i;
+
+  if (!(agent = ht_get_host_agent_val (*(uint32_t *) val)))
+    return 1;
+
+  if (agents->size - 1 == agents->idx) {
+    newlen = agents->size + 4;
+    if (!(tmp = realloc (agents->items, newlen * sizeof (GAgentItem))))
+      FATAL ("Unable to realloc agents");
+
+    agents->items = tmp;
+    agents->size = newlen;
+  }
+
+  for (i = 0; i < agents->idx; ++i) {
+    if (strcmp (agent, agents->items[i].agent) == 0) {
+      free (agent);
+      return 0;
+    }
+  }
+  agents->items[agents->idx++].agent = agent;
+
+  return 0;
+}
+
+/* Iterate over the list of agents */
+GAgents *
+load_host_agents (const char *addr) {
+  GAgents *agents = NULL;
+  GSLList *keys = NULL, *list = NULL;
+  void *data = NULL;
+  uint32_t items = 4;
+
+  keys = ht_get_keymap_list_from_key (HOSTS, addr);
+  if (!keys)
+    return NULL;
+
+  agents = new_gagents (items);
+
+  /* *INDENT-OFF* */
+  GSLIST_FOREACH (keys, data, {
+    if ((list = ht_get_host_agent_list (HOSTS, (*(uint32_t *) data)))) {
+      list_foreach (list, set_agents, agents);
+      list_remove_nodes (list);
+    }
+  });
+  /* *INDENT-ON* */
+  list_remove_nodes (keys);
+
+  return agents;
+}
+
 /* Fill the given terminal dashboard menu with user agent data.
  *
  * On error, the 1 is returned.
  * On success, 0 is returned. */
 static int
-fill_host_agents_gmenu (void *val, void *user_data)
-{
-  GMenu *menu = user_data;
-  char *agent = ht_get_host_agent_val ((*(int *) val));
+fill_host_agents_gmenu (GMenu * menu, GAgents * agents) {
+  int i;
 
-  if (agent == NULL)
+  if (agents == NULL)
     return 1;
 
-  menu->items[menu->size].name = agent;
-  menu->items[menu->size].checked = 0;
-  menu->size++;
-
-  return 0;
-}
-
-/* Iterate over the linked-list of user agents for the given host and
- * load its data into the given menu. */
-static void
-load_host_agents_gmenu (void *list, void *user_data, int count)
-{
-  GSLList *lst = list;
-  GMenu *menu = user_data;
-
-  menu->items = (GItem *) xcalloc (count, sizeof (GItem));
-  list_foreach (lst, fill_host_agents_gmenu, menu);
-}
-
-/* Set host data from a linked-list and load its data into a GMenu
- * structure.
- *
- * On error, the 1 is returned.
- * On success, 0 is returned. */
-#ifdef TCB_BTREE
-int
-set_host_agents (const char *addr, void (*func) (void *, void *, int),
-                 void *arr)
-{
-  TCLIST *tclist;
-  GSLList *list;
-  int key, count = 0;
-
-  key = ht_get_keymap (HOSTS, addr);
-  if (key == 0)
-    return 1;
-
-  tclist = ht_get_host_agent_tclist (HOSTS, key);
-  if (!tclist)
-    return 1;
-
-  list = tclist_to_gsllist (tclist);
-  if ((count = list_count (list)) == 0) {
-    free (list);
-    return 1;
+  menu->items = xcalloc (agents->idx, sizeof (GItem));
+  for (i = 0; i < agents->idx; ++i) {
+    menu->items[i].name = xstrdup (agents->items[i].agent);
+    menu->items[i].checked = 0;
+    menu->size++;
   }
 
-  func (list, arr, count);
-
-  list_remove_nodes (list);
-  tclistdel (tclist);
-
   return 0;
 }
-#endif
-
-/* Set host data from a linked-list and load its data into a GMenu
- * structure.
- *
- * On error, the 1 is returned.
- * On success, 0 is returned. */
-#ifndef TCB_BTREE
-int
-set_host_agents (const char *addr, void (*func) (void *, void *, int),
-                 void *arr)
-{
-  GSLList *list;
-  int data_nkey, count = 0;
-
-  data_nkey = ht_get_keymap (HOSTS, addr);
-  if (data_nkey == 0)
-    return 1;
-
-  list = ht_get_host_agent_list (HOSTS, data_nkey);
-  if (!list)
-    return 1;
-
-  if ((count = list_count (list)) == 0) {
-    free (list);
-    return 1;
-  }
-
-  func (list, arr, count);
-
-#ifdef TCB_MEMHASH
-  free (list);
-#endif
-
-  return 0;
-}
-#endif
 
 /* Render a list of agents if available for the selected host/IP. */
 void
-load_agent_list (WINDOW * main_win, char *addr)
-{
+load_agent_list (WINDOW * main_win, char *addr) {
   GMenu *menu;
+  GAgents *agents = NULL;
   WINDOW *win;
 
   char buf[256];
@@ -993,7 +911,9 @@ load_agent_list (WINDOW * main_win, char *addr)
 
   /* create a new instance of GMenu and make it selectable */
   menu = new_gmenu (win, menu_h, menu_w, AGENTS_MENU_Y, AGENTS_MENU_X);
-  if (set_host_agents (addr, load_host_agents_gmenu, menu) == 1)
+  if (!(agents = load_host_agents (addr)))
+    goto out;
+  if (fill_host_agents_gmenu (menu, agents) != 0)
     goto out;
 
   post_gmenu (menu);
@@ -1031,12 +951,12 @@ out:
   if (menu->items)
     free (menu->items);
   free (menu);
+  free_agents_array (agents);
 }
 
 /* Render the processing spinner. This runs within its own thread. */
 static void
-ui_spinner (void *ptr_data)
-{
+ui_spinner (void *ptr_data) {
   GSpinner *sp = (GSpinner *) ptr_data;
   GColors *color = NULL;
 
@@ -1052,8 +972,12 @@ ui_spinner (void *ptr_data)
   time (&begin);
   while (1) {
     pthread_mutex_lock (&sp->mutex);
-    if (sp->state == SPN_END)
+    if (sp->state == SPN_END) {
+      if (!sp->curses && !conf.no_progress)
+        fprintf (stderr, "\n");
+
       break;
+    }
 
     setlocale (LC_NUMERIC, "");
     if (conf.no_progress) {
@@ -1079,14 +1003,13 @@ ui_spinner (void *ptr_data)
     }
 
     pthread_mutex_unlock (&sp->mutex);
-    usleep (100000);
+    usleep (SPIN_UPDATE_INTERVAL);
   }
 }
 
 /* Create the processing spinner's thread */
 void
-ui_spinner_create (GSpinner * spinner)
-{
+ui_spinner_create (GSpinner * spinner) {
   if (conf.no_parsing_spinner)
     return;
 
@@ -1096,8 +1019,7 @@ ui_spinner_create (GSpinner * spinner)
 
 /* Initialize processing spinner data. */
 void
-set_curses_spinner (GSpinner * spinner)
-{
+set_curses_spinner (GSpinner * spinner) {
   int y, x;
   if (spinner == NULL)
     return;
@@ -1117,16 +1039,15 @@ set_curses_spinner (GSpinner * spinner)
  *
  * On success, the newly allocated GSpinner is returned. */
 GSpinner *
-new_gspinner (void)
-{
+new_gspinner (void) {
   GSpinner *spinner;
 
   spinner = xcalloc (1, sizeof (GSpinner));
   spinner->label = "Parsing...";
   spinner->state = SPN_RUN;
   spinner->curses = 0;
-  if (conf.load_from_disk)
-    conf.no_progress = 1;
+  //if (conf.load_from_disk)
+  //  conf.no_progress = 1;
 
   if (pthread_mutex_init (&(spinner->mutex), NULL))
     FATAL ("Failed init thread mutex");
@@ -1137,8 +1058,7 @@ new_gspinner (void)
 /* A wrapper call to clear the status bar on the config dialog
  * (terminal output). */
 static void
-clear_confdlg_status_bar (WINDOW * win, int y, int x, int w)
-{
+clear_confdlg_status_bar (WINDOW * win, int y, int x, int w) {
   draw_header (win, "", "%s", y, x, w + 1, color_default);
 }
 
@@ -1147,8 +1067,7 @@ clear_confdlg_status_bar (WINDOW * win, int y, int x, int w)
  * If no conf.date_format is given, NULL is returned.
  * On success, the newly escaped allocated string is returned. */
 static char *
-get_input_date_format (void)
-{
+get_input_date_format (void) {
   char *date_format = NULL;
 
   if (conf.date_format)
@@ -1161,8 +1080,7 @@ get_input_date_format (void)
  * If no conf.time_format is given, NULL is returned.
  * On success, the newly escaped allocated string is returned. */
 static char *
-get_input_time_format (void)
-{
+get_input_time_format (void) {
   char *time_format = NULL;
 
   if (conf.time_format)
@@ -1175,8 +1093,7 @@ get_input_time_format (void)
  * If no conf.log_format is given, NULL is returned.
  * On success, the newly escaped allocated string is returned. */
 static char *
-get_input_log_format (void)
-{
+get_input_log_format (void) {
   char *log_format = NULL;
 
   if (conf.log_format)
@@ -1185,8 +1102,7 @@ get_input_log_format (void)
 }
 
 static void
-draw_formats (WINDOW * win, int w2)
-{
+draw_formats (WINDOW * win, int w2) {
   char *date_format = NULL, *log_format = NULL, *time_format = NULL;
 
   draw_header (win, CONFDLG_HEAD, " %s", 1, 1, w2, color_panel_header);
@@ -1218,8 +1134,7 @@ draw_formats (WINDOW * win, int w2)
 }
 
 static const char *
-set_formats (char *date_format, char *log_format, char *time_format)
-{
+set_formats (char *date_format, char *log_format, char *time_format) {
   /* display status bar error messages */
   if (!time_format && !conf.time_format)
     return ERR_FORMAT_NO_TIME_FMT_DLG;
@@ -1250,8 +1165,7 @@ set_formats (char *date_format, char *log_format, char *time_format)
 
 /* Render the help dialog. */
 static void
-load_confdlg_error (WINDOW * parent_win, char **errors, int nerrors)
-{
+load_confdlg_error (WINDOW * parent_win, char **errors, int nerrors) {
   int c, quit = 1, i = 0;
   int y, x, h = ERR_WIN_HEIGHT, w = ERR_WIN_WIDTH;
   WINDOW *win;
@@ -1264,8 +1178,7 @@ load_confdlg_error (WINDOW * parent_win, char **errors, int nerrors)
   wborder (win, '|', '|', '-', '-', '+', '+', '+', '+');
 
   /* create a new instance of GMenu and make it selectable */
-  menu =
-    new_gmenu (win, ERR_MENU_HEIGHT, ERR_MENU_WIDTH, ERR_MENU_Y, ERR_MENU_X);
+  menu = new_gmenu (win, ERR_MENU_HEIGHT, ERR_MENU_WIDTH, ERR_MENU_Y, ERR_MENU_X);
   menu->size = nerrors;
 
   /* add items to GMenu */
@@ -1314,8 +1227,7 @@ load_confdlg_error (WINDOW * parent_win, char **errors, int nerrors)
  * On error, or if the selected format is invalid, 1 is returned.
  * On success, 0 is returned. */
 int
-render_confdlg (GLog * glog, GSpinner * spinner)
-{
+render_confdlg (GLog * glog, GSpinner * spinner) {
   GMenu *menu;
   WINDOW *win;
 
@@ -1541,8 +1453,7 @@ render_confdlg (GLog * glog, GSpinner * spinner)
 /* Given the name of the selected scheme, set it under our config
  * options. */
 static void
-scheme_chosen (const char *name)
-{
+scheme_chosen (const char *name) {
   int force = 0;
 
   free_color_lists ();
@@ -1562,8 +1473,7 @@ scheme_chosen (const char *name)
 }
 
 static const char **
-get_color_schemes (size_t * size)
-{
+get_color_schemes (size_t *size) {
   const char *choices[] = {
     "Monokai",
     "Monochrome",
@@ -1587,8 +1497,7 @@ get_color_schemes (size_t * size)
 
 /* Render the schemes dialog. */
 void
-load_schemes_win (WINDOW * main_win)
-{
+load_schemes_win (WINDOW * main_win) {
   GMenu *menu;
   WINDOW *win;
   int c, quit = 1;
@@ -1604,8 +1513,7 @@ load_schemes_win (WINDOW * main_win)
   wborder (win, '|', '|', '-', '-', '+', '+', '+', '+');
 
   /* create a new instance of GMenu and make it selectable */
-  menu =
-    new_gmenu (win, SCHEME_MENU_H, SCHEME_MENU_W, SCHEME_MENU_Y, SCHEME_MENU_X);
+  menu = new_gmenu (win, SCHEME_MENU_H, SCHEME_MENU_W, SCHEME_MENU_Y, SCHEME_MENU_X);
   /* remove custom color option if no custom scheme used */
   menu->size = n;
 
@@ -1664,8 +1572,7 @@ load_schemes_win (WINDOW * main_win)
 
 /* Render the sort dialog. */
 void
-load_sort_win (WINDOW * main_win, GModule module, GSort * sort)
-{
+load_sort_win (WINDOW * main_win, GModule module, GSort * sort) {
   GMenu *menu;
   WINDOW *win;
   GSortField opts[SORT_MAX_OPTS];
@@ -1903,8 +1810,7 @@ static const char *help_main[] = {
 
 /* Render the help dialog. */
 void
-load_help_popup (WINDOW * main_win)
-{
+load_help_popup (WINDOW * main_win) {
   int c, quit = 1;
   size_t i, n;
   int y, x, h = HELP_WIN_HEIGHT, w = HELP_WIN_WIDTH;
@@ -1920,9 +1826,7 @@ load_help_popup (WINDOW * main_win)
   wborder (win, '|', '|', '-', '-', '+', '+', '+', '+');
 
   /* create a new instance of GMenu and make it selectable */
-  menu =
-    new_gmenu (win, HELP_MENU_HEIGHT, HELP_MENU_WIDTH, HELP_MENU_Y,
-               HELP_MENU_X);
+  menu = new_gmenu (win, HELP_MENU_HEIGHT, HELP_MENU_WIDTH, HELP_MENU_Y, HELP_MENU_X);
   menu->size = n;
 
   /* add items to GMenu */
