@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -46,6 +46,7 @@
 
 /* string literals and translations */
 #include "labels.h"
+#include "commons.h"
 
 /* Global UI defaults */
 #define MIN_HEIGHT        8     /* minimum window height */
@@ -56,9 +57,11 @@
 
 /* Spinner Label Format */
 #define SPIN_FMT "%s"
-#define SPIN_FMTM "%s [%'d] [%'lld/s]"
+#define SPIN_FMTM "%s [%'u] [%'lld/s]"
 #define SPIN_LBL 50     /* max length of the progress spinner */
 
+#define SPIN_UPDATE_INTERVAL 100000     // in microseconds
+
 /* Module JSON keys */
 #define VISITORS_ID        "visitors"
 #define REQUESTS_ID        "requests"
@@ -66,6 +69,7 @@
 #define VISIT_TIMES_ID     "visit_time"
 #define VIRTUAL_HOSTS_ID   "vhosts"
 #define REMOTE_USER_ID     "remote_user"
+#define CACHE_STATUS_ID    "cache_status"
 #define NOT_FOUND_ID       "not_found"
 #define HOSTS_ID           "hosts"
 #define OS_ID              "os"
@@ -152,8 +156,7 @@
 #include "sort.h"
 
 /* Curses dashboard find */
-typedef struct GFind_
-{
+typedef struct GFind_ {
   GModule module;
   char *pattern;
   int next_idx;
@@ -165,15 +168,13 @@ typedef struct GFind_
 } GFind;
 
 /* Each panel contains its own scrolling and offset */
-typedef struct GScrollModule_
-{
+typedef struct GScrollModule_ {
   int scroll;
   int offset;
 } GScrollModule;
 
 /* Curses Scrolling */
-typedef struct GScroll_
-{
+typedef struct GScroll_ {
   GScrollModule module[TOTAL_MODULES];
   GModule current;
   int dash;
@@ -181,8 +182,7 @@ typedef struct GScroll_
 } GScroll;
 
 /* Spinner or Progress Indicator */
-typedef struct GSpinner_
-{
+typedef struct GSpinner_ {
   const char *label;
   GColors *(*color) (void);
   int curses;
@@ -194,8 +194,7 @@ typedef struct GSpinner_
   pthread_t thread;
   unsigned int *processed;
   WINDOW *win;
-  enum
-  {
+  enum {
     SPN_RUN,
     SPN_END
   } state;
@@ -203,8 +202,7 @@ typedef struct GSpinner_
 
 /* Controls metric output.
  * i.e., which metrics it should display */
-typedef struct GOutput_
-{
+typedef struct GOutput_ {
   GModule module;
   int8_t visitors;
   int8_t hits;
@@ -231,11 +229,11 @@ const char *module_to_desc (GModule module);
 const char *module_to_head (GModule module);
 const char *module_to_id (GModule module);
 const char *module_to_label (GModule module);
-int get_start_end_parsing_dates (GHolder * h, char **start, char **end, const char *f);
+int get_start_end_parsing_dates (char **start, char **end, const char *f);
 int render_confdlg (GLog * glog, GSpinner * spinner);
-int set_host_agents (const char *addr, void (*func) (void *, void *, int), void *arr);
 void close_win (WINDOW * w);
-void display_general (WINDOW * win, GLog * glog, GHolder *h);
+GAgents *load_host_agents (const char *addr);
+void display_general (WINDOW * win, GHolder *h);
 void draw_header (WINDOW * win, const char *s, const char *fmt, int y, int x, int w, GColors * (*func) (void));
 void end_spinner (void);
 void generate_time (void);
