@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -104,6 +104,7 @@ static const char *codes[][2] = {
   {"415", STATUS_CODE_415},
   {"416", STATUS_CODE_416},
   {"417", STATUS_CODE_417},
+  {"418", STATUS_CODE_418},
   {"421", STATUS_CODE_421},
   {"422", STATUS_CODE_422},
   {"423", STATUS_CODE_423},
@@ -137,8 +138,7 @@ static const char *codes[][2] = {
  * On error NULL is returned.
  * On success the extracted part of string is returned */
 char *
-substring (const char *str, int begin, int len)
-{
+substring (const char *str, int begin, int len) {
   char *buffer;
   if (str == NULL)
     return NULL;
@@ -164,8 +164,7 @@ substring (const char *str, int begin, int len)
  *
  * On success, a pointer to a new string is returned */
 char *
-alloc_string (const char *str)
-{
+alloc_string (const char *str) {
   char *new = xmalloc (strlen (str) + 1);
   strcpy (new, str);
   return new;
@@ -174,8 +173,7 @@ alloc_string (const char *str)
 /* A wrapper function to copy the first num characters of source to
  * destination. */
 void
-xstrncpy (char *dest, const char *source, const size_t dest_size)
-{
+xstrncpy (char *dest, const char *source, const size_t dest_size) {
   strncpy (dest, source, dest_size);
   if (dest_size > 0) {
     dest[dest_size - 1] = '\0';
@@ -186,11 +184,10 @@ xstrncpy (char *dest, const char *source, const size_t dest_size)
 
 /* A random string generator. */
 void
-genstr (char *dest, size_t len)
-{
+genstr (char *dest, size_t len) {
   char set[] = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
-  while (len-- > 0)
+  for (; len > 0; --len)
     *dest++ = set[rand () % (sizeof (set) - 1)];
   *dest = '\0';
 }
@@ -200,8 +197,7 @@ genstr (char *dest, size_t len)
  * If the character is not found, 0 is returned
  * On success, the number of characters found */
 int
-count_matches (const char *s1, char c)
-{
+count_matches (const char *s1, char c) {
   const char *ptr = s1;
   int n = 0;
   do {
@@ -216,8 +212,7 @@ count_matches (const char *s1, char c)
  * If no match found, 1 is returned.
  * If match found, 0 is returned. */
 static int
-wc_match (const char *wc, char *str)
-{
+wc_match (const char *wc, char *str) {
   while (*wc && *str) {
     if (*wc == '*') {
       while (*wc && *wc == '*')
@@ -245,8 +240,7 @@ wc_match (const char *wc, char *str)
  * On error, or the referrer is not found, 0 is returned
  * On success, or if the host needs to be ignored, 1 is returned */
 int
-ignore_referer (const char *host)
-{
+ignore_referer (const char *host) {
   char *needle = NULL;
   int i, ignore = 0;
 
@@ -277,8 +271,7 @@ out:
  * On error, or the referrer is not found, 0 is returned
  * On success, or if the host needs to be ignored, 1 is returned */
 int
-hide_referer (const char *host)
-{
+hide_referer (const char *host) {
   char *needle = NULL;
   int i, ignore = 0;
 
@@ -308,8 +301,7 @@ out:
  * On error, or not within the range, 0 is returned
  * On success, or if within the range, 1 is returned */
 static int
-within_range (const char *ip, const char *start, const char *end)
-{
+within_range (const char *ip, const char *start, const char *end) {
   struct in6_addr addr6, start6, end6;
   struct in_addr addr4, start4, end4;
 
@@ -350,8 +342,7 @@ within_range (const char *ip, const char *start, const char *end)
  * On error, or not within the range, 0 is returned
  * On success, or if within the range, 1 is returned */
 int
-ip_in_range (const char *ip)
-{
+ip_in_range (const char *ip) {
   char *start = NULL, *end, *dash;
   int i;
 
@@ -393,8 +384,7 @@ ip_in_range (const char *ip)
  * On success, the given filename is malloc'd and assigned and 0 is
  * returned. */
 int
-find_output_type (char **filename, const char *ext, int alloc)
-{
+find_output_type (char **filename, const char *ext, int alloc) {
   int i;
   const char *dot = NULL;
 
@@ -403,8 +393,7 @@ find_output_type (char **filename, const char *ext, int alloc)
     if (strcmp (conf.output_formats[i], ext) == 0)
       return 0;
 
-    if ((dot = strrchr (conf.output_formats[i], '.')) != NULL &&
-        strcmp (dot + 1, ext) == 0) {
+    if ((dot = strrchr (conf.output_formats[i], '.')) != NULL && strcmp (dot + 1, ext) == 0) {
       if (alloc)
         *filename = xstrdup (conf.output_formats[i]);
       return 0;
@@ -425,8 +414,7 @@ find_output_type (char **filename, const char *ext, int alloc)
  * -1: non-existent extension
  */
 int
-valid_output_type (const char *filename)
-{
+valid_output_type (const char *filename) {
   const char *ext = NULL;
   size_t sl;
 
@@ -457,8 +445,7 @@ valid_output_type (const char *filename)
  * On error, it outputs an error message and the program terminates.
  * On success, the path of HOME and the config file is returned. */
 char *
-get_home (void)
-{
+get_home (void) {
   char *user_home = NULL, *path = NULL;
 
   user_home = getenv ("HOME");
@@ -475,12 +462,11 @@ get_home (void)
  *
  * On success, the path of the global config file is returned. */
 char *
-get_global_config (void)
-{
+get_global_config (void) {
   char *path = NULL;
 
-  path = xmalloc (snprintf (NULL, 0, "%s/goaccess.conf", SYSCONFDIR) + 1);
-  sprintf (path, "%s/goaccess.conf", SYSCONFDIR);
+  path = xmalloc (snprintf (NULL, 0, "%s/goaccess/goaccess.conf", SYSCONFDIR) + 1);
+  sprintf (path, "%s/goaccess/goaccess.conf", SYSCONFDIR);
 
   return path;
 }
@@ -490,8 +476,7 @@ get_global_config (void)
  * On error, a newly malloc'd '---' string is returned.
  * On success, a malloc'd 'Ymd' date is returned. */
 char *
-get_visitors_date (const char *odate, const char *from, const char *to)
-{
+get_visitors_date (const char *odate, const char *from, const char *to) {
   char date[DATE_TIME] = "";    /* Ymd */
 
   memset (date, 0, sizeof *date);
@@ -509,8 +494,7 @@ get_visitors_date (const char *odate, const char *from, const char *to)
  * On success, 0 is returned. */
 #pragma GCC diagnostic ignored "-Wformat-nonliteral"
 int
-str_to_time (const char *str, const char *fmt, struct tm *tm)
-{
+str_to_time (const char *str, const char *fmt, struct tm *tm) {
   char *end = NULL, *sEnd = NULL;
   unsigned long long usecs = 0;
 
@@ -547,9 +531,7 @@ str_to_time (const char *str, const char *fmt, struct tm *tm)
  * On error, 1 is returned.
  * On success, 0 is returned. */
 int
-convert_date (char *res, const char *data, const char *from, const char *to,
-              int size)
-{
+convert_date (char *res, const char *data, const char *from, const char *to, int size) {
   struct tm tm;
 
   memset (&tm, 0, sizeof (tm));
@@ -576,10 +558,8 @@ convert_date (char *res, const char *data, const char *from, const char *to,
  * On error, 1 is returned.
  * On success, 0 is returned. */
 int
-invalid_ipaddr (char *str, int *ipvx)
-{
-  union
-  {
+invalid_ipaddr (char *str, int *ipvx) {
+  union {
     struct sockaddr addr;
     struct sockaddr_in6 addr6;
     struct sockaddr_in addr4;
@@ -606,8 +586,7 @@ invalid_ipaddr (char *str, int *ipvx)
  * On error, -1 is returned.
  * On success, the file size of the given filename. */
 off_t
-file_size (const char *filename)
-{
+file_size (const char *filename) {
   struct stat st;
 
   if (stat (filename, &st) == 0)
@@ -624,8 +603,7 @@ file_size (const char *filename)
  * If not found, "Unknown" is returned.
  * On success, the status code type/category is returned. */
 const char *
-verify_status_code_type (const char *str)
-{
+verify_status_code_type (const char *str) {
   size_t i;
   for (i = 0; i < ARRAY_SIZE (code_type); i++)
     if (strchr (code_type[i][0], str[0]) != NULL)
@@ -640,8 +618,7 @@ verify_status_code_type (const char *str)
  * If not found, "Unknown" is returned.
  * On success, the status code is returned. */
 const char *
-verify_status_code (char *str)
-{
+verify_status_code (char *str) {
   size_t i;
   for (i = 0; i < ARRAY_SIZE (codes); i++)
     if (strstr (str, codes[i][0]) != NULL)
@@ -655,8 +632,7 @@ verify_status_code (char *str)
  * If not found, -1 is returned.
  * If found, the key for needle in the array is returned. */
 int
-str_inarray (const char *s, const char *arr[], int size)
-{
+str_inarray (const char *s, const char *arr[], int size) {
   int i;
   for (i = 0; i < size; i++) {
     if (strcmp (arr[i], s) == 0)
@@ -670,8 +646,7 @@ str_inarray (const char *s, const char *arr[], int size)
  * On success, a string with whitespace stripped from the beginning of
  * the string is returned. */
 char *
-ltrim (char *s)
-{
+ltrim (char *s) {
   char *begin = s;
 
   while (isspace (*begin))
@@ -686,8 +661,7 @@ ltrim (char *s)
  * On success, a string with whitespace stripped from the end of the
  * string is returned. */
 char *
-rtrim (char *s)
-{
+rtrim (char *s) {
   char *end = s + strlen (s);
 
   while ((end != s) && isspace (*(end - 1)))
@@ -701,8 +675,7 @@ rtrim (char *s)
  *
  * On success, the trimmed string is returned. */
 char *
-trim_str (char *str)
-{
+trim_str (char *str) {
   return rtrim (ltrim (str));
 }
 
@@ -711,8 +684,7 @@ trim_str (char *str)
  * On error, the original size of the string in bytes is returned.
  * On success, the file size in a human readable format is returned. */
 char *
-filesize_str (unsigned long long log_size)
-{
+filesize_str (unsigned long long log_size) {
   char *size = xmalloc (sizeof (char) * 12);
   if (log_size >= (1ULL << 50))
     snprintf (size, 12, "%.2f PiB", (double) (log_size) / PIB (1ULL));
@@ -735,8 +707,7 @@ filesize_str (unsigned long long log_size)
  * On error, a malloc'd string in microseconds is returned.
  * On success, the time in a human readable format is returned. */
 char *
-usecs_to_str (unsigned long long usec)
-{
+usecs_to_str (unsigned long long usec) {
   char *size = xmalloc (sizeof (char) * 11);
   if (usec >= DAY)
     snprintf (size, 11, "%.2f  d", (double) (usec) / DAY);
@@ -759,33 +730,65 @@ usecs_to_str (unsigned long long usec)
  *
  * On success, the given number as a string is returned. */
 char *
-int2str (int d, int width)
-{
+int2str (int d, int width) {
   char *s = xmalloc (snprintf (NULL, 0, "%*d", width, d) + 1);
   sprintf (s, "%*d", width, d);
 
   return s;
 }
 
+/* Convert the given uint32_t to a string with the ability to add some
+ * padding.
+ *
+ * On success, the given number as a string is returned. */
+char *
+u322str (uint32_t d, int width) {
+  char *s = xmalloc (snprintf (NULL, 0, "%*u", width, d) + 1);
+  sprintf (s, "%*u", width, d);
+
+  return s;
+}
+
 /* Convert the given float to a string with the ability to add some
  * padding.
  *
  * On success, the given number as a string is returned. */
 char *
-float2str (float d, int width)
-{
+float2str (float d, int width) {
   char *s = xmalloc (snprintf (NULL, 0, "%*.2f", width, d) + 1);
   sprintf (s, "%*.2f", width, d);
 
   return s;
 }
 
+int
+ptr2int (char *ptr) {
+  char *sEnd = NULL;
+  int value = -1;
+
+  value = strtol (ptr, &sEnd, 10);
+  if (ptr == sEnd || *sEnd != '\0' || errno == ERANGE) {
+    LOG_DEBUG (("Invalid parse of integer value from pointer. \n"));
+    return -1;
+  }
+
+  return value;
+}
+
+int
+str2int (const char *date) {
+  char *sEnd = NULL;
+  int d = strtol (date, &sEnd, 10);
+  if (date == sEnd || *sEnd != '\0' || errno == ERANGE)
+    return -1;
+  return d;
+}
+
 /* Determine the length of an integer (number of digits).
  *
  * On success, the length of the number is returned. */
 int
-intlen (int num)
-{
+intlen (int num) {
   int l = 1;
   while (num > 9) {
     l++;
@@ -799,8 +802,7 @@ intlen (int num)
  *
  * On success, the newly allocated string is returned. */
 char *
-char_repeat (int n, char c)
-{
+char_repeat (int n, char c) {
   char *dest = xmalloc (n + 1);
   memset (dest, c, n);
   dest[n] = '\0';
@@ -814,8 +816,7 @@ char_repeat (int n, char c)
  * On error the original string is returned.
  * On success, a string with the replaced values is returned. */
 char *
-char_replace (char *str, char o, char n)
-{
+char_replace (char *str, char o, char n) {
   char *p = str;
 
   if (str == NULL || *str == '\0')
@@ -831,8 +832,7 @@ char_replace (char *str, char o, char n)
  *
  * On success, a string with the replaced new lines is returned. */
 void
-strip_newlines (char *str)
-{
+strip_newlines (char *str) {
   char *src, *dst;
   for (src = dst = str; *src != '\0'; src++) {
     *dst = *src;
@@ -846,8 +846,7 @@ strip_newlines (char *str)
  *
  * On success, a string without whitespace is returned. */
 char *
-deblank (char *str)
-{
+deblank (char *str) {
   char *out = str, *put = str;
 
   for (; *str != '\0'; ++str) {
@@ -864,8 +863,7 @@ deblank (char *str)
  * On error the original string is returned.
  * On success, the uppercased string is returned. */
 char *
-strtoupper (char *str)
-{
+strtoupper (char *str) {
   char *p = str;
   if (str == NULL || *str == '\0')
     return str;
@@ -882,8 +880,7 @@ strtoupper (char *str)
  *
  * On success, a left-padded string is returned. */
 char *
-left_pad_str (const char *s, int indent)
-{
+left_pad_str (const char *s, int indent) {
   char *buf = NULL;
 
   indent = strlen (s) + indent;
@@ -895,9 +892,8 @@ left_pad_str (const char *s, int indent)
 
 /* Append the source string to destination and reallocates and
  * updating the destination buffer appropriately. */
-void
-append_str (char **dest, const char *src)
-{
+size_t
+append_str (char **dest, const char *src) {
   size_t curlen = strlen (*dest);
   size_t srclen = strlen (src);
   size_t newlen = curlen + srclen;
@@ -905,6 +901,8 @@ append_str (char **dest, const char *src)
   char *str = xrealloc (*dest, newlen + 1);
   memcpy (str + curlen, src, srclen + 1);
   *dest = str;
+
+  return newlen;
 }
 
 /* Escapes the special characters, e.g., '\n', '\r', '\t', '\'
@@ -913,15 +911,14 @@ append_str (char **dest, const char *src)
  * On error NULL is returned.
  * On success the escaped string is returned */
 char *
-escape_str (const char *src)
-{
+escape_str (const char *src) {
   char *dest, *q;
   const unsigned char *p;
 
   if (src == NULL || *src == '\0')
     return NULL;
 
-  p = (unsigned char *) src;
+  p = (const unsigned char *) src;
   q = dest = xmalloc (strlen (src) * 4 + 1);
 
   while (*p) {
@@ -964,8 +961,7 @@ escape_str (const char *src)
  * On error NULL is returned.
  * On success the unescaped string is returned */
 char *
-unescape_str (const char *src)
-{
+unescape_str (const char *src) {
   char *dest, *q;
   const char *p = src;
 
