@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2016 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -40,8 +40,7 @@
 
 /* Self-checking wrapper to malloc() */
 void *
-xmalloc (size_t size)
-{
+xmalloc (size_t size) {
   void *ptr;
 
   if ((ptr = malloc (size)) == NULL)
@@ -51,8 +50,7 @@ xmalloc (size_t size)
 }
 
 char *
-xstrdup (const char *s)
-{
+xstrdup (const char *s) {
   char *ptr;
   size_t len;
 
@@ -65,8 +63,7 @@ xstrdup (const char *s)
 
 /* Self-checking wrapper to calloc() */
 void *
-xcalloc (size_t nmemb, size_t size)
-{
+xcalloc (size_t nmemb, size_t size) {
   void *ptr;
 
   if ((ptr = calloc (nmemb, size)) == NULL)
@@ -77,8 +74,7 @@ xcalloc (size_t nmemb, size_t size)
 
 /* Self-checking wrapper to realloc() */
 void *
-xrealloc (void *oldptr, size_t size)
-{
+xrealloc (void *oldptr, size_t size) {
   void *newptr;
 
   if ((newptr = realloc (oldptr, size)) == NULL)
